Class: Morpheus::Cli::Accounts

Inherits:
Object
  • Object
show all
Includes:
AccountsHelper, CliCommand
Defined in:
lib/morpheus/cli/accounts.rb

Instance Method Summary collapse

Methods included from AccountsHelper

#find_account_by_id, #find_account_by_name, #find_account_from_options, #find_role_by_id, #find_role_by_name, #find_user_by_id, #find_user_by_username, #format_role_type, #format_user_role_names, #get_access_string, included, #print_accounts_table, #print_roles_table, #print_users_table

Methods included from CliCommand

#build_common_options, included

Constructor Details

#initialize ⇒ Accounts

Returns a new instance of Accounts.



14
15
16
17
# File 'lib/morpheus/cli/accounts.rb', line 14

def initialize() 
	@appliance_name, @appliance_url = Morpheus::Cli::Remote.active_appliance
	#@active_groups = ::Morpheus::Cli::Groups.load_group_file
end

Instance Method Details

#add(args) ⇒ Object



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/morpheus/cli/accounts.rb', line 155

def add(args)
	usage = "Usage: morpheus accounts add [options]"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		build_common_options(opts, options, [:options, :json])
	end
	optparse.parse(args)

	connect(options)
	
	begin

		params = Morpheus::Cli::OptionTypes.prompt(, options[:options], @api_client, options[:params])

		#puts "parsed params is : #{params.inspect}"
		 = ['name', 'description', 'currency']
		 = params.select {|k,v| .include?(k) }
		['currency'] = ['currency'].to_s.empty? ? "USD" : ['currency'].upcase
		if !['instanceLimits']
			['instanceLimits'] = {}
			['instanceLimits']['maxStorage'] = params['instanceLimits.maxStorage'].to_i if params['instanceLimits.maxStorage'].to_s.strip != ''
			['instanceLimits']['maxMemory'] = params['instanceLimits.maxMemory'].to_i if params['instanceLimits.maxMemory'].to_s.strip != ''
			['instanceLimits']['maxCpu'] = params['instanceLimits.maxCpu'].to_i if params['instanceLimits.maxCpu'].to_s.strip != ''
		end
		if params['role'].to_s != ''
			role = find_role_by_name(nil, params['role'])
			exit 1 if role.nil?
			['role'] = {id: role['id']}
		end
		request_payload = {account: }
		json_response = @accounts_interface.create(request_payload)
		
		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			print_green_success "Account #{['name']} added"
			details([["name"]])
		end

	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end

#connect(opts) ⇒ Object



19
20
21
22
23
24
25
26
27
28
29
# File 'lib/morpheus/cli/accounts.rb', line 19

def connect(opts)
	@access_token = Morpheus::Cli::Credentials.new(@appliance_name,@appliance_url).request_credentials()
	if @access_token.empty?
		print_red_alert "Invalid Credentials. Unable to acquire access token. Please verify your credentials and try again."
		exit 1
	end
	@api_client = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url)
	@users_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).users
	@accounts_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).accounts
	@roles_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).roles
end

#details(args) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/morpheus/cli/accounts.rb', line 90

def details(args)
	usage = "Usage: morpheus accounts details [name] [options]"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		build_common_options(opts, options, [:json])
	end
	optparse.parse(args)

	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	name = args[0]

	connect(options)
	begin

		# todo: accounts_response = @accounts_interface.list({name: name})
		#       there may be response data outside of account that needs to be displayed

		 = nil
		if name.to_s =~ /\Aid:/
			id = name.sub('id:', '')
			 = (id)
		else
			 = (name)
		end
		exit 1 if .nil?

		if options[:json]
			print JSON.pretty_generate({account: })
			print "\n"
		else
			print "\n" ,cyan, bold, "Account Details\n","==================", reset, "\n\n"
			print cyan
			puts "ID: #{['id']}"
			puts "Name: #{['name']}"
			puts "Description: #{['description']}"
			puts "Currency: #{['currency']}"
			# puts "# Users: #{account['usersCount']}"
			# puts "# Instances: #{account['instancesCount']}"
			puts "Date Created: #{format_local_dt(['dateCreated'])}"
			puts "Last Updated: #{format_local_dt(['lastUpdated'])}"
			status_state = nil
			if ['active']
				status_state = "#{green}ACTIVE#{cyan}"
			else
				status_state = "#{red}INACTIVE#{cyan}"
			end
			puts "Status: #{status_state}"
			print "\n" ,cyan, bold, "Account Instance Limits\n","==================", reset, "\n\n"
			print cyan
			puts "Max Storage (bytes): #{['instanceLimits'] ? ['instanceLimits']['maxStorage'] : 0}"
			puts "Max Memory (bytes): #{['instanceLimits'] ? ['instanceLimits']['maxMemory'] : 0}"
			puts "CPU Count: #{['instanceLimits'] ? ['instanceLimits']['maxCpu'] : 0}"
			print cyan
			print reset,"\n\n"
		end
	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end

#handle(args) ⇒ Object



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/morpheus/cli/accounts.rb', line 31

def handle(args)
	usage = "Usage: morpheus accounts [list,details,add,update,remove] [name]"
	if args.empty?
		puts "\n#{usage}\n\n"
		exit 1
	end

	case args[0]
		when 'list'
			list(args[1..-1])
		when 'details'
			details(args[1..-1])
		when 'add'
			add(args[1..-1])
		when 'update'
			update(args[1..-1])
		when 'remove'
			remove(args[1..-1])
		else
			puts "\n#{usage}\n\n"
			exit 127
	end
end

#list(args) ⇒ Object



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/morpheus/cli/accounts.rb', line 55

def list(args)
	usage = "Usage: morpheus accounts list"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		build_common_options(opts, options, [:list, :json])
	end
	optparse.parse(args)
	connect(options)
	begin
		params = {}
		[:phrase, :offset, :max, :sort, :direction].each do |k|
			params[k] = options[k] unless options[k].nil?
		end

		json_response = @accounts_interface.list(params)
		accounts = json_response['accounts']
		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			print "\n" ,cyan, bold, "Morpheus Accounts\n","==================", reset, "\n\n"
			if accounts.empty?
				puts yellow,"No accounts found.",reset
			else
				print_accounts_table(accounts)
			end
			print reset,"\n\n"
		end
	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end

#remove(args) ⇒ Object



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/morpheus/cli/accounts.rb', line 273

def remove(args)
	usage = "Usage: morpheus accounts remove [name]"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		build_common_options(opts, options, [:auto_confirm, :json])
	end
	optparse.parse(args)

	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	name = args[0]

	connect(options)
	begin
		# allow finding by ID since name is not unique!
		 = ((name.to_s =~ /\A\d{1,}\Z/) ? (name) : (name) )
		exit 1 if .nil?
		unless options[:yes] || Morpheus::Cli::OptionTypes.confirm("Are you sure you want to delete the account #{['name']}?")
			exit
		end
		json_response = @accounts_interface.destroy(['id'])
		
		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			print_green_success "Account #{['name']} removed"
		end

	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end

#update(args) ⇒ Object



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/morpheus/cli/accounts.rb', line 202

def update(args)
	usage = "Usage: morpheus accounts update [name] [options]"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		build_common_options(opts, options, [:options, :json])
	end
	optparse.parse(args)

	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	name = args[0].strip

	connect(options)
	
	begin

		 = nil
		if name.to_s =~ /\Aid:/
			id = name.sub('id:', '').strip
			 = (id)
		else
			 = (name)
		end
		exit 1 if .nil?

		#params = Morpheus::Cli::OptionTypes.prompt(update_account_option_types, options[:options], @api_client, options[:params])
		params = options[:options] || {}

		if params.empty?
			puts "\n#{usage}\n\n"
			option_lines = .collect {|it| "\t-O #{it['fieldName']}=\"value\"" }.join("\n")
			puts "\nAvailable Options:\n#{option_lines}\n\n"
			exit 1
		end

		#puts "parsed params is : #{params.inspect}"
		 = ['name', 'description', 'currency', 'instanceLimits']
		 = params.select {|k,v| .include?(k) }
		['currency'] = ['currency'].upcase unless ['currency'].to_s.empty?
		if !['instanceLimits']
			['instanceLimits'] = {}
			['instanceLimits']['maxStorage'] = params['instanceLimits.maxStorage'].to_i if params['instanceLimits.maxStorage'].to_s.strip != ''
			['instanceLimits']['maxMemory'] = params['instanceLimits.maxMemory'].to_i if params['instanceLimits.maxMemory'].to_s.strip != ''
			['instanceLimits']['maxCpu'] = params['instanceLimits.maxCpu'].to_i if params['instanceLimits.maxCpu'].to_s.strip != ''
		end
		if params['role'].to_s != ''
			role = find_role_by_name(nil, params['role'])
			exit 1 if role.nil?
			['role'] = {id: role['id']}
		end
		request_payload = {account: }
		json_response = @accounts_interface.update(['id'], request_payload)

		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			 = ['name'] || ['name']
			print_green_success "Account #{} updated"
			details([])
		end
		
	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end