Module: Morpheus::Cli::AccountsHelper

Overview

Mixin for Morpheus::Cli command classes Provides common methods for fetching and printing accounts, roles, and users. The including class must establish @accounts_interface, @roles_interface, @users_interface

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.included(klass) ⇒ Object



8
9
10
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 8

def self.included(klass)
  klass.send :include, Morpheus::Cli::PrintHelper
end

Instance Method Details

#account_column_definitionsObject

Tenants (Accounts)



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 38

def ()
  {
    "ID" => 'id',
    "Name" => 'name',
    # "Name" => lambda {|it| it['name'].to_s + (it['master'] ? " (Master Tenant)" : '') },
    "Description" => 'description',
    "Subdomain" => 'subdomain',
    "# Instances" => 'stats.instanceCount',
    "# Users" => 'stats.userCount',
    "Role" => lambda {|it| it['role']['authority'] rescue nil },
    "Parent Tenant" => lambda {|it| it['parent']['name'] rescue nil },
    "Master" => lambda {|it| format_boolean(it['master']) },
    "Currency" => 'currency',
    "Status" => lambda {|it| 
      status_state = nil
      if it['active']
        status_state = "#{green}ACTIVE#{cyan}"
      else
        status_state = "#{red}INACTIVE#{cyan}"
      end
      status_state
    },
    "Created" => lambda {|it| format_local_dt(it['dateCreated']) },
    "Updated" => lambda {|it| format_local_dt(it['lastUpdated']) },
  }
end

#account_users_interfaceObject



18
19
20
21
22
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 18

def 
  # @api_client.users
  raise "#{self.class} has not defined @account_users_interface" if @account_users_interface.nil?
  @account_users_interface
end

#accounts_interfaceObject



12
13
14
15
16
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 12

def accounts_interface
  # @api_client.accounts
  raise "#{self.class} has not defined @accounts_interface" if @accounts_interface.nil?
  @accounts_interface
end

#find_account_by_id(id) ⇒ Object



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 82

def (id)
  begin
    json_response = accounts_interface.get(id.to_i)
    return json_response['account']
  rescue RestClient::Exception => e
    if e.response && e.response.code == 404
      print_red_alert "Tenant not found by id #{id}"
    else
      raise e
    end
  end
end

#find_account_by_name(name) ⇒ Object



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 95

def (name)
  accounts = accounts_interface.list({name: name.to_s})['accounts']
  if accounts.empty?
    print_red_alert "Tenant not found by name #{name}"
    return nil
  elsif accounts.size > 1
    print_red_alert "Found #{accounts.size} tenants by name '#{name}'. Try using ID instead: #{format_list(accounts.collect {|it| it['id']}, 'or', 3)}"
    print "\n"
    print as_pretty_table(accounts, [:id, :name, :description], {color: red, thin: true})
    print reset,"\n"
    return nil
  else
    return accounts[0]
  end
end

#find_account_by_name_or_id(val) ⇒ Object



74
75
76
77
78
79
80
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 74

def (val)
  if val.to_s =~ /\A\d{1,}\Z/
    return (val)
  else
    return (val)
  end
end

#find_account_from_options(options) ⇒ Object



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 111

def (options)
   = nil
  if options[:account]
     = (options[:account])
    exit 1 if .nil?
  elsif options[:account_name]
     = (options[:account_name])
    exit 1 if .nil?
  elsif options[:account_id]
     = (options[:account_id])
    exit 1 if .nil?
  else
     = nil # use current account
  end
  return 
end

#find_all_user_ids(account_id, usernames, params = {}) ⇒ Object



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 277

def find_all_user_ids(, usernames, params={})
  user_ids = []
  if usernames.is_a?(String)
    usernames = usernames.split(",").collect {|it| it.to_s.strip }.select {|it| it }.uniq
  else
    usernames = usernames.collect {|it| it.to_s.strip }.select {|it| it }.uniq
  end
  usernames.each do |username|
    # save a query
    #user = find_user_by_username_or_id(nil, username, params)
    if username.to_s =~ /\A\d{1,}\Z/
      user_ids << username.to_i
    else
      user = find_user_by_username(, username, params)
      if user.nil?
        return nil
      else
        user_ids << user['id']
      end
    end
  end
  user_ids
end

#find_role_by_id(account_id, id) ⇒ Object



168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 168

def find_role_by_id(, id)
  begin
    json_response = roles_interface.get(, id.to_i)
    return json_response['role']
  rescue RestClient::Exception => e
    if e.response && e.response.code == 404
      print_red_alert "Role not found by id #{id}"
    else
      raise e
    end
  end
end

#find_role_by_name(account_id, name) ⇒ Object Also known as: find_role_by_authority



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 181

def find_role_by_name(, name)
  roles = roles_interface.list(, {authority: name.to_s})['roles']
  if roles.empty?
    print_red_alert "Role not found by name #{name}"
    return nil
  elsif roles.size > 1
    print_red_alert "Found #{roles.size} roles by name '#{name}'. Try using ID instead: #{format_list(roles.collect {|it| it['id']}, 'or', 3)}"
    print "\n"
    # print as_pretty_table(accounts, [:id, :name, :description], {color: red, thin: true})
    print as_pretty_table(roles, {"ID" => 'id', "Name" => 'authority',"Description" => 'description'}.upcase_keys!, {color: red, thin: true})
    print reset,"\n"
    return nil
  else
    return roles[0]
  end
end

#find_role_by_name_or_id(account_id, val) ⇒ Object



160
161
162
163
164
165
166
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 160

def find_role_by_name_or_id(, val)
  if val.to_s =~ /\A\d{1,}\Z/
    return find_role_by_id(, val)
  else
    return find_role_by_name(, val)
  end
end

#find_user_by_id(account_id, id, params = {}) ⇒ Object



248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 248

def find_user_by_id(, id, params={})
  begin
    json_response = .get(, id.to_i, params)
    return json_response['user']
  rescue RestClient::Exception => e
    if e.response && e.response.code == 404
      print_red_alert "User not found by id #{id}"
    else
      raise e
    end
  end
end

#find_user_by_username(account_id, username, params = {}) ⇒ Object



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 261

def find_user_by_username(, username, params={})
  users = .list(, params.merge({username: username.to_s}))['users']
  if users.empty?
    print_red_alert "User not found by username #{username}"
    return nil
  elsif users.size > 1
    print_red_alert "Found #{users.size} users by username '#{username}'. Try using ID instead: #{format_list(users.collect {|it| it['id']}, 'or', 3)}"
    print_error "\n"
    print_error as_pretty_table(users, list_user_column_definitions({color: red}), {color: red, thin: true})
    print reset,"\n"
    return nil
  else
    return users[0]
  end
end

#find_user_by_username_or_id(account_id, val, params = {}) ⇒ Object



240
241
242
243
244
245
246
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 240

def find_user_by_username_or_id(, val, params={})
  if val.to_s =~ /\A\d{1,}\Z/
    return find_user_by_id(, val, params)
  else
    return find_user_by_username(, val, params)
  end
end

#find_user_group_by_id(account_id, id) ⇒ Object



335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 335

def find_user_group_by_id(, id)
  begin
    json_response = @user_groups_interface.get(, id.to_i)
    return json_response['userGroup']
  rescue RestClient::Exception => e
    if e.response && e.response.code == 404
      print_red_alert "User Group not found by id #{id}"
    else
      raise e
    end
  end
end

#find_user_group_by_name(account_id, name) ⇒ Object



348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 348

def find_user_group_by_name(, name)
  user_groups = @user_groups_interface.list(, {name: name.to_s})['userGroups']
  if user_groups.empty?
    print_red_alert "User Group not found by name #{name}"
    return nil
  elsif user_groups.size > 1
    print_red_alert "Found #{user_groups.size} user groups by name '#{name}'. Try using ID instead: #{format_list(user_groups.collect {|it| it['id']}, 'or', 3)}"
    print as_pretty_table(user_groups, [:id, :name, :description], {color: red, thin: true})
    print reset,"\n"
    return nil
  else
    return user_groups[0]
  end
end

#find_user_group_by_name_or_id(account_id, val) ⇒ Object



327
328
329
330
331
332
333
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 327

def find_user_group_by_name_or_id(, val)
  if val.to_s =~ /\A\d{1,}\Z/
    return find_user_group_by_id(, val)
  else
    return find_user_group_by_name(, val)
  end
end

#format_access_string(access, access_levels = nil, return_color = cyan) ⇒ Object

this outputs a string that matches the length of all available access levels for outputting in a grid that looks like this:

none
            full
            full
        user
    read
            full
none

Examples: format_permission_access(“read”)

format_permission_access("custom", "full,custom,none")


432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 432

def format_access_string(access, access_levels=nil, return_color=cyan)
  # nevermind all this, just colorized access level
  return get_access_string(access, return_color)
  
  access = access.to_s.downcase.strip
  if access.empty?
    access = "none"
  end

  if access_levels.nil?
    access_levels = ["none","read","user","full"]
  elsif access_levels.is_a?(Array)
    # access_levels = access_levels
  else
    # parse values like "full,custom,none"
    access_levels = [access_levels].flatten.collect {|it| it.strip.split(",") }.flatten.collect {|it| it.strip }.compact
  end
  # build padded string that contains access eg. 'full' or '    read'
  access_levels_string = access_levels.join(",")
  padded_value = ""
  access_levels.each do |a|
    # handle some unusual access values
    # print custom, and provision where 'user' normally is at index 1
    if (access == "custom" || access == "provision") && a == "user"
      padded_value << access
    else
      if access == a
        padded_value << access
      else
        padded_value << " " * a.size
      end
    end
  end
  # no matching access was found, so just print it in one slot
  if padded_value == ""
    padded_value = " " * access_levels[0].to_s.size
    padded_value << access
  end
  # strip any extra whitespace off the end
  if padded_value.size > access_levels_string.size
    padded_value = padded_value.rstrip
  end
  # ok build out string
  out = ""
  access_color = get_access_color(access || 'default')
  out << access_color if access_color
  out << padded_value
  out << reset if access_color
  out << return_color if return_color
  return out
end

#format_role_type(role) ⇒ Object



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 363

def format_role_type(role)
  str = ""
  if role['roleType'] == "account"
    str = "Account"
  elsif role['roleType'] == "user"
    str = "User"
  else
    if role['scope'] == 'Account'
      str = "Legacy"
    else
      str = "Admin" # System Admin
    end
  end
  # if role['scope'] && role['filterType'] != 'Account'
  #   str = "(System) #{str}"
  # end
  return str
end

#format_user_role_names(user) ⇒ Object

These user access formatted methods should probably move up to PrintHelper to be more ubiquitous.



384
385
386
387
388
389
390
391
392
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 384

def format_user_role_names(user)
  role_names = ""
  if user && user['roles']
    roles = user['roles']
    roles = roles.sort {|a,b| a['authority'].to_s.downcase <=> b['authority'].to_s.downcase }
    role_names = roles.collect {|r| r['authority'] }.join(', ')
  end
  role_names
end

#format_user_status(user, return_color = cyan) ⇒ Object



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 226

def format_user_status(user, return_color=cyan)
  if user["enabled"] != true
    red + "DISABLED" + return_color
  elsif user["accountLocked"]
    red + "ACCOUNT LOCKED" + return_color
  elsif user["accountExpired"]
    yellow + "ACCOUNT EXPIRED" + return_color
  elsif user["passwordExpired"]
    yellow + "PASSWORD EXPIRED" + return_color
  else
    green + "ACTIVE" + return_color
  end
end

#get_access_color(access) ⇒ Object



394
395
396
397
398
399
400
401
402
403
404
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 394

def get_access_color(access)
  access ||= 'default'
  if access == 'none'
    # maybe reset instead of white?
    white
  elsif access.include? 'full'
    green
  else
    cyan
  end
end

#get_access_string(access, return_color = cyan) ⇒ Object



406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 406

def get_access_string(access, return_color=cyan)
  access ||= 'default'
  get_access_color(access) + access.to_s + return_color.to_s
  # access ||= 'none'
  # if access == 'none'
  #   "#{white}#{access.to_s}#{return_color}"
  # elsif access == 'read'
  #   "#{cyan}#{access.to_s.capitalize}#{return_color}"
  # else
  #   "#{green}#{access.to_s}#{return_color}"
  # end
end

#list_account_column_definitionsObject



65
66
67
68
69
70
71
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 65

def ()
  columns = 
  columns.delete("Subdomain")
  columns.delete("Master")
  columns.delete("Currency")
  return columns.upcase_keys!
end

#list_user_column_definitions(opts = {}) ⇒ Object



220
221
222
223
224
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 220

def list_user_column_definitions(opts={})
  columns = user_column_definitions(opts)
  columns.delete("Notifications")
  return columns.upcase_keys!
end

#list_user_group_column_definitionsObject



319
320
321
322
323
324
325
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 319

def list_user_group_column_definitions()
  columns = user_group_column_definitions
  columns.delete("Sudo Access")
  columns.delete("Server Group")
  columns.delete("Updated")
  return columns.upcase_keys!
end

#role_column_definitions(options = {}) ⇒ Object

Roles



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 130

def role_column_definitions(options={})
  {
    "ID" => 'id',
    "Name" => 'authority',
    "Description" => 'description',
    "Landing URL" => 'landingUrl',
    #"Scope" => lambda {|it| it['scope'] },
    "Type" => lambda {|it| format_role_type(it) },
    "Multitenant" => lambda {|it| 
      format_boolean(it['multitenant']).to_s + (it['multitenantLocked'] ? " (LOCKED)" : "")
    },
    "Default Persona" => lambda {|it| it['defaultPersona'] ? it['defaultPersona']['name'] : '' },
    "Owner" => lambda {|it| it['owner'] ? it['owner']['name'] : '' },
    #"Tenant" => lambda {|it| it['account'] ? it['account']['name'] : '' },
    "Created" => lambda {|it| format_local_dt(it['dateCreated']) },
    "Updated" => lambda {|it| format_local_dt(it['lastUpdated']) }
  }
end

#roles_interfaceObject



30
31
32
33
34
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 30

def roles_interface
  # @api_client.roles
  raise "#{self.class} has not defined @roles_interface" if @roles_interface.nil?
  @roles_interface
end

#subtenant_role_column_definitions(options = {}) ⇒ Object



149
150
151
152
153
154
155
156
157
158
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 149

def subtenant_role_column_definitions(options={})
  {
    "ID" => 'id',
    "Name" => 'authority',
    "Description" => 'description',
    "Landing URL" => 'landingUrl',
    "Created" => lambda {|it| format_local_dt(it['dateCreated']) },
    "Updated" => lambda {|it| format_local_dt(it['lastUpdated']) }
  }
end

#user_column_definitions(opts = {}) ⇒ Object

Users



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 203

def user_column_definitions(opts={})
  {
    "ID" => 'id',
    "Tenant" => lambda {|it| it['account'] ? it['account']['name'] : '' },
    "First Name" => 'firstName',
    "Last Name" => 'lastName',
    "Username" => 'username',
    "Email" => 'email',
    "Role" => lambda {|it| format_user_role_names(it) },
    "Notifications" => lambda {|it| it['receiveNotifications'].nil? ? '' : format_boolean(it['receiveNotifications']) },
    "Status" => lambda {|it| format_user_status(it, opts[:color] || cyan) },
    "Last Login" => lambda {|it| format_duration_ago(it['lastLoginDate']) },
    "Created" => lambda {|it| format_local_dt(it['dateCreated']) },
    "Updated" => lambda {|it| format_local_dt(it['lastUpdated']) },
  }
end

#user_group_column_definitionsObject

User Groups



304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 304

def user_group_column_definitions()
  {
    "ID" => lambda {|it| it['id'] },
    #"Account" => lambda {|it| it['account'] ? it['account']['name'] : '' },
    "Name" => lambda {|it| it['name'] },
    "Description" => lambda {|it| it['description'] },
    "Server Group" => lambda {|it| it['serverGroup'] },
    "Sudo Access" => lambda {|it| format_boolean it['sudoAccess'] },
    # "Shared User" => lambda {|it| format_boolean it['sharedUser'] },
    "# Users" => lambda {|it| it['users'].size rescue nil },
    "Created" => lambda {|it| format_local_dt(it['dateCreated']) },
    "Updated" => lambda {|it| format_local_dt(it['lastUpdated']) }
  }
end

#user_groups_interfaceObject



24
25
26
27
28
# File 'lib/morpheus/cli/mixins/accounts_helper.rb', line 24

def user_groups_interface
  # @api_client.users
  raise "#{self.class} has not defined @user_groups_interface" if @user_groups_interface.nil?
  @user_groups_interface
end