Class: Morpheus::Cli::BackupsCommand

Inherits:
Object
  • Object
show all
Includes:
BackupsHelper, CliCommand, OptionSourceHelper, ProvisioningHelper
Defined in:
lib/morpheus/cli/commands/backups_command.rb

Instance Attribute Summary

Attributes included from CliCommand

#no_prompt

Instance Method Summary collapse

Methods included from OptionSourceHelper

#find_available_user_option, #find_cloud_option, #find_group_option, #find_tenant_option, #get_available_user_options, #get_cloud_options, #get_group_options, #get_tenant_options, included, #load_option_source_data, #options_interface, #parse_cloud_id_list, #parse_group_id_list, #parse_option_source_id_list, #parse_project_id_list, #parse_tenant_id_list, #parse_user_id_list

Methods included from ProvisioningHelper

#accounts_interface, #add_perms_options, #api_client, #apps_interface, #cloud_datastores_interface, #clouds_interface, #datastores_interface, #find_app_by_id, #find_app_by_name, #find_app_by_name_or_id, #find_cloud_by_id_for_provisioning, #find_cloud_by_name_for_provisioning, #find_cloud_by_name_or_id_for_provisioning, #find_cloud_resource_pool_by_name_or_id, #find_group_by_id_for_provisioning, #find_group_by_name_for_provisioning, #find_group_by_name_or_id_for_provisioning, #find_host_by_id, #find_host_by_name, #find_host_by_name_or_id, #find_instance_by_id, #find_instance_by_name, #find_instance_by_name_or_id, #find_instance_type_by_code, #find_instance_type_by_id, #find_instance_type_by_name, #find_instance_type_by_name_or_id, #find_instance_type_layout_by_id, #find_server_by_id, #find_server_by_name, #find_server_by_name_or_id, #find_workflow_by_id, #find_workflow_by_name, #find_workflow_by_name_or_id, #format_app_status, #format_blueprint_type, #format_container_connection_string, #format_container_status, #format_instance_connection_string, #format_instance_container_display_name, #format_instance_status, #format_metadata, #format_snapshot_status, #get_available_accounts, #get_available_clouds, #get_available_environments, #get_available_groups, #get_available_plans, #get_provision_type_for_zone_type, #get_static_environments, included, #instance_type_layouts_interface, #instance_types_interface, #instances_interface, #load_balance_protocols_dropdown, #options_interface, #parse_blueprint_type, #parse_host_id_list, #parse_instance_id_list, #parse_metadata, #parse_resource_id_list, #parse_server_id_list, #print_permissions, #prompt_evars, #prompt_exposed_ports, #prompt_instance_load_balancer, #prompt_metadata, #prompt_network_interfaces, #prompt_new_instance, #prompt_permissions, #prompt_permissions_v2, #prompt_resize_volumes, #prompt_security_groups, #prompt_service_plan_options, #prompt_volumes, #provision_types_interface, #reject_service_plan_option_types, #servers_interface

Methods included from BackupsHelper

#backup_job_list_key, #backup_job_object_key, #backup_jobs_interface, #backup_list_key, #backup_object_key, #backups_interface, #find_backup_by_id, #find_backup_by_name, #find_backup_by_name_or_id, #find_backup_job_by_id, #find_backup_job_by_name, #find_backup_job_by_name_or_id, included

Methods included from CliCommand

#add_query_parameter, #apply_options, #build_common_options, #build_get_options, #build_list_options, #build_option_type_options, #build_payload, #build_standard_add_options, #build_standard_api_options, #build_standard_delete_options, #build_standard_get_options, #build_standard_list_options, #build_standard_post_options, #build_standard_put_options, #build_standard_remove_options, #build_standard_update_options, #command_description, #command_name, #confirm, #confirm!, #default_refresh_interval, #default_sigdig, #default_subcommand, #establish_remote_appliance_connection, #find_all, #find_all_json, #find_by_id, #find_by_name, #find_by_name_or_id, #find_record, #find_record_json, #full_command_usage, #get_interface, #get_list_key, #get_object_key, #get_subcommand_description, #handle_subcommand, included, #interactive?, #my_help_command, #my_terminal, #my_terminal=, #parse_array, #parse_bytes_param, #parse_get_options!, #parse_id_list, #parse_labels, #parse_list_options, #parse_list_options!, #parse_list_subtitles, #parse_parameter_as_resource_id!, #parse_passed_options, #parse_payload, #parse_payloads, #parse_query_options, #print, #print_error, #println, #process_payloads, #prog_name, #puts, #puts_error, #raise_args_error, #raise_command_error, #render_response, #run_command_for_each_arg, #subcommand_aliases, #subcommand_description, #subcommand_usage, #subcommands, #usage, #validate_outfile, #verify_args!, #visible_subcommands

Instance Method Details

#_get(id, params, options) ⇒ Object



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/morpheus/cli/commands/backups_command.rb', line 83

def _get(id, params, options)
  if id.to_s !~ /\A\d{1,}\Z/
    record = find_by_name(:backup, id)
    if record.nil?
      return 1, "Backup not found for '#{id}'"
    end
    id = record['id']
  end
  @backups_interface.setopts(options)
  if options[:dry_run]
    print_dry_run @backups_interface.dry.get(id, params)
    return
  end
  json_response = @backups_interface.get(id, params)
  backup = json_response['backup']
  render_response(json_response, options, 'backup') do
    print_h1 "Backup Details", [], options
    print cyan
    columns = backup_column_definitions
    columns.delete("Instance") if backup['instance'].nil?
    columns.delete("Container ID") if backup['containerId'].nil?
    columns.delete("Host") if backup['server'].nil?
    print_description_list(columns, backup, options)
    print reset,"\n"
  end
  return 0, nil
end

#add(args) ⇒ Object



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/morpheus/cli/commands/backups_command.rb', line 111

def add(args)
  options = {}
  params = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[name] [options]")
    # build_option_type_options(opts, options, add_backup_option_types)
    opts.on('--source VALUE', String, "Backup Source: instance, host or provider") do |val|
      options[:options]['source'] = val
    end
    opts.on('--instance VALUE', String, "Instance Name or ID") do |val|
      options[:options]['source'] = 'instance'
      options[:options]['instanceId'] = val
    end
    opts.on('--host VALUE', String, "Host Name or ID") do |val|
      options[:options]['source'] = 'server'
      options[:options]['serverId'] = val
    end
    opts.on('--server VALUE', String, "alias for --host") do |val|
      options[:options]['source'] = 'server'
      options[:options]['serverId'] = val
    end
    opts.add_hidden_option('--server')
    opts.on('--name VALUE', String, "Name") do |val|
      options[:options]['name'] = val
    end
    build_standard_add_options(opts, options)
    opts.footer = <<-EOT
Create a new backup.
EOT
  end
  optparse.parse!(args)
  verify_args!(args:args, optparse:optparse, min:0, max:1)
  options[:options]['name'] = args[0] if args[0]
  connect(options)
  payload = {}
  if options[:payload]
    payload = options[:payload]
    payload.deep_merge!({'backup' => parse_passed_options(options)})
  else
    payload.deep_merge!({'backup' => parse_passed_options(options)})

    location_type = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'source', 'fieldLabel' => 'Source', 'type' => 'select', 'selectOptions' => [{'name' => 'Instance', 'value' => 'instance'}, {'name' => 'Host', 'value' => 'server'}, {'name' => 'Provider', 'value' => 'provider'}], 'defaultValue' => 'instance', 'required' => true, 'description' => 'Where is the backup located?'}], options[:options], @api_client)['source']
    params['locationType'] = location_type
    if location_type == 'instance'
      # Instance
      avail_instances = @instances_interface.list({max:10000})['instances'].collect {|it| {'name' => it['name'], 'value' => it['id']}}
      params['instanceId'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'instanceId', 'fieldLabel' => 'Instance', 'type' => 'select', 'selectOptions' => avail_instances, 'required' => true}], options[:options], @api_client)['instanceId']
      # Name
      params['name'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'name', 'fieldLabel' => 'Name', 'type' => 'text', 'required' => true, 'description' => 'Backup Name'}], options[:options], @api_client)['name']
    elsif location_type == 'server'
      # Server
      avail_servers = @servers_interface.list({max:10000, 'vmHypervisor' => nil, 'containerHypervisor' => nil})['servers'].collect {|it| {'name' => it['name'], 'value' => it['id']}}
      params['serverId'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'serverId', 'fieldLabel' => 'Host', 'type' => 'select', 'selectOptions' => avail_servers, 'required' => true}], options[:options], @api_client)['serverId']
      # Name
      params['name'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'name', 'fieldLabel' => 'Name', 'type' => 'text', 'required' => true, 'description' => 'Backup Name'}], options[:options], @api_client)['name']
    elsif location_type == 'provider'
      # todo: prompt for provider inputs
      # sourceProviderId
      # storageProvider
    end
    # POST to /create to get available option info for containers, backupTypes, backupProviderTypes, etc.
    payload['backup'].deep_merge!(params)
    create_results = @backups_interface.create_options(payload)

    if location_type == 'instance' || location_type == 'server'
      if location_type == 'instance'
        # Container
        avail_containers = (create_results['containers'] || []).collect {|it| {'name' => it['name'], 'value' => it['id']} }
        if avail_containers.empty?
          raise_command_error "No available containers found for selected instance"
        else
          params['containerId'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'containerId', 'fieldLabel' => 'Container', 'type' => 'select', 'selectOptions' => avail_containers, 'defaultValue' => avail_containers[0] ? avail_containers[0]['name'] : nil, 'required' => true}], options[:options], @api_client)['containerId']
        end
      elsif location_type == 'server'
        
        
      end
      # Backup Type
      avail_backup_types = (create_results['backupTypes'] || []).collect {|it| {'name' => it['name'], 'value' => it['code']} }
      if avail_backup_types.empty?
        raise_command_error "No available backup types found"
      else
        params['backupType'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'backupType', 'fieldLabel' => 'Backup Type', 'type' => 'select', 'selectOptions' => avail_backup_types, 'defaultValue' => avail_backup_types[0] ? avail_backup_types[0]['name'] : nil, 'required' => true}], options[:options], @api_client)['backupType']  
      end

      # Job / Schedule
      params['jobAction'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'jobAction', 'fieldLabel' => 'Backup Job Type', 'type' => 'select', 'optionSource' => 'backupJobActions', 'required' => true, 'defaultValue' => 'new'}], options[:options], @api_client)['jobAction']
      if params['jobAction'] == 'new'
        params['jobName'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'jobName', 'fieldLabel' => 'Job Name', 'type' => 'text', 'required' => false, 'defaultValue' => nil}], options[:options], @api_client)['jobName']
        default_retention_count = create_results['backup'] ? create_results['backup']['retentionCount'] : nil
        params['retentionCount'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'retentionCount', 'fieldLabel' => 'Retention Count', 'type' => 'number', 'required' => false, 'defaultValue' => default_retention_count}], options[:options], @api_client)['retentionCount']
        params['jobSchedule'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'jobSchedule', 'fieldLabel' => 'Backup Schedule', 'type' => 'select', 'optionSource' => 'executeSchedules', 'required' => true}], options[:options], @api_client)['jobSchedule']
      elsif params['jobAction'] == 'clone'
        params['jobId'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'jobId', 'fieldLabel' => 'Backup Job', 'type' => 'select', 'optionSource' => lambda { |api_client, api_params| 
          @backup_jobs_interface.list({max:10000})['jobs'].collect {|backup_job|
            {'name' => backup_job['name'], 'value' => backup_job['id'], 'id' => backup_job['id']}
          }
        }, 'required' => true}], options[:options], @api_client)['jobId']
        params['jobName'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'jobName', 'fieldLabel' => 'Job Name', 'type' => 'text', 'required' => false, 'defaultValue' => nil}], options[:options], @api_client)['jobName']
      elsif params['jobAction'] == 'addTo'
        params['jobId'] = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'jobId', 'fieldLabel' => 'Backup Job', 'type' => 'select', 'optionSource' => lambda { |api_client, api_params| 
          @backup_jobs_interface.list({max:10000})['jobs'].collect {|backup_job|
            {'name' => backup_job['name'], 'value' => backup_job['id'], 'id' => backup_job['id']}
          }
        }, 'required' => true}], options[:options], @api_client)['jobId']
      end
    end

    payload['backup'].deep_merge!(params)
  end
  @backups_interface.setopts(options)
  if options[:dry_run]
    print_dry_run @backups_interface.dry.create(payload)
    return 0, nil
  end
  json_response = @backups_interface.create(payload)
  backup = json_response['backup']
  render_response(json_response, options, 'backup') do
    print_green_success "Added backup #{backup['name']}"
    return _get(backup["id"], {}, options)
  end
  return 0, nil
end

#connect(opts) ⇒ Object



15
16
17
18
19
20
21
# File 'lib/morpheus/cli/commands/backups_command.rb', line 15

def connect(opts)
  @api_client = establish_remote_appliance_connection(opts)
  @backups_interface = @api_client.backups
  @backup_jobs_interface = @api_client.backup_jobs
  @instances_interface = @api_client.instances
  @servers_interface = @api_client.servers
end

#get(args) ⇒ Object



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/morpheus/cli/commands/backups_command.rb', line 63

def get(args)
  params = {}
  options = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[backup]")
    build_standard_get_options(opts, options)
    opts.footer = <<-EOT
Get details about a specific backup.
[backup] is required. This is the name or id of a backup.
EOT
  end
  optparse.parse!(args)
  verify_args!(args:args, optparse:optparse, min:1)
  connect(options)
  id_list = parse_id_list(args)
  return run_command_for_each_arg(id_list) do |arg|
    _get(arg, params, options)
  end
end

#handle(args) ⇒ Object



23
24
25
# File 'lib/morpheus/cli/commands/backups_command.rb', line 23

def handle(args)
  handle_subcommand(args)
end

#list(args) ⇒ Object



27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/morpheus/cli/commands/backups_command.rb', line 27

def list(args)
  options = {}
  params = {}
  ref_ids = []
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[search]")
    build_standard_list_options(opts, options)
    opts.footer = "List backups."
  end
  optparse.parse!(args)
  connect(options)
  # verify_args!(args:args, optparse:optparse, count:0)
  if args.count > 0
    options[:phrase] = args.join(" ")
  end
  params.merge!(parse_list_options(options))
  @backups_interface.setopts(options)
  if options[:dry_run]
    print_dry_run @backups_interface.dry.list(params)
    return
  end
  json_response = @backups_interface.list(params)
  backups = json_response['backups']
  render_response(json_response, options, 'backups') do
    print_h1 "Morpheus Backups", parse_list_subtitles(options), options
    if backups.empty?
      print cyan,"No backups found.",reset,"\n"
    else
      print as_pretty_table(backups, backup_list_column_definitions.upcase_keys!, options)
      print_results_pagination(json_response)
    end
    print reset,"\n"
  end
  return 0, nil
end

#remove(args) ⇒ Object



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/morpheus/cli/commands/backups_command.rb', line 286

def remove(args)
  options = {}
  params = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[backup] [options]")
    build_standard_remove_options(opts, options)
    opts.footer = <<-EOT
Delete a backup.
[backup] is required. This is the name or id of a backup.
EOT
  end
  optparse.parse!(args)
  verify_args!(args:args, optparse:optparse, count:1)
  connect(options)
  backup = find_backup_by_name_or_id(args[0])
  return 1 if backup.nil?
  @backups_interface.setopts(options)
  if options[:dry_run]
    print_dry_run @backups_interface.dry.destroy(backup['id'], params)
    return
  end
  unless options[:yes] || Morpheus::Cli::OptionTypes.confirm("Are you sure you want to delete the backup #{backup['name']}?")
    return 9, "aborted command"
  end
  json_response = @backups_interface.destroy(backup['id'], params)
  render_response(json_response, options) do
    print_green_success "Removed backup #{backup['name']}"
  end
  return 0, nil
end

#update(args) ⇒ Object



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/morpheus/cli/commands/backups_command.rb', line 235

def update(args)
  options = {}
  params = {}
  payload = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[backup] [options]")
    build_option_type_options(opts, options, update_backup_option_types)
    build_option_type_options(opts, options, update_backup_advanced_option_types)
    build_standard_update_options(opts, options)
    opts.footer = <<-EOT
Update a backup.
[backup] is required. This is the name or id of a backup.
EOT
  end
  optparse.parse!(args)
  verify_args!(args:args, optparse:optparse, count:1)
  connect(options)
  backup = find_backup_by_name_or_id(args[0])
  return 1 if backup.nil?
  payload = {}
  if options[:payload]
    payload = options[:payload]
    payload.deep_merge!({'backup' => parse_passed_options(options)})
  else
    payload.deep_merge!({'backup' => parse_passed_options(options)})
    # do not prompt on update
    v_prompt = Morpheus::Cli::OptionTypes.no_prompt(update_backup_option_types, options[:options], @api_client, options[:params])
    v_prompt.deep_compact!
    params.deep_merge!(v_prompt)
    advanced_config = Morpheus::Cli::OptionTypes.no_prompt(update_backup_advanced_option_types, options[:options], @api_client, options[:params])
    advanced_config.deep_compact!
    params.deep_merge!(advanced_config)
    payload.deep_merge!({'backup' => params})
    if payload['backup'].empty? # || options[:no_prompt]
      raise_command_error "Specify at least one option to update.\n#{optparse}"
    end
  end
  @backups_interface.setopts(options)
  if options[:dry_run]
    print_dry_run @backups_interface.dry.update(backup['id'], payload)
    return
  end
  json_response = @backups_interface.update(backup['id'], payload)
  backup = json_response['backup']
  render_response(json_response, options, 'backup') do
    print_green_success "Updated backup #{backup['name']}"
    return _get(backup["id"], {}, options)
  end
  return 0, nil
end