Class: Morpheus::Cli::ClientsCommand

Inherits:
Object
  • Object
show all
Includes:
CliCommand
Defined in:
lib/morpheus/cli/commands/clients_command.rb

Instance Attribute Summary

Attributes included from CliCommand

#no_prompt

Instance Method Summary collapse

Methods included from CliCommand

#add_query_parameter, #apply_options, #build_common_options, #build_get_options, #build_list_options, #build_option_type_options, #build_standard_add_many_options, #build_standard_add_options, #build_standard_api_options, #build_standard_delete_options, #build_standard_get_options, #build_standard_list_options, #build_standard_post_options, #build_standard_put_options, #build_standard_remove_options, #build_standard_update_options, #command_description, #command_name, #confirm, #confirm!, #default_refresh_interval, #default_sigdig, #default_subcommand, #establish_remote_appliance_connection, #execute_api, #execute_api_payload, #execute_api_request, #find_all, #find_all_json, #find_by_id, #find_by_name, #find_by_name_or_id, #find_record, #find_record_json, #full_command_usage, #get_interface, #get_list_key, #get_object_key, #get_subcommand_description, #handle_each_payload, #handle_subcommand, included, #interactive?, #my_help_command, #my_terminal, #my_terminal=, #parse_array, #parse_bytes_param, #parse_get_options!, #parse_id_list, #parse_labels, #parse_list_options, #parse_list_options!, #parse_list_subtitles, #parse_options, #parse_parameter_as_resource_id!, #parse_passed_options, #parse_payload, #parse_query_options, #print, #print_error, #println, #prog_name, #puts, #puts_error, #raise_args_error, #raise_command_error, #render_response, #run_command_for_each_arg, #subcommand_aliases, #subcommand_description, #subcommand_usage, #subcommands, #usage, #validate_outfile, #verify_args!, #visible_subcommands

Constructor Details

#initializeClientsCommand

Returns a new instance of ClientsCommand.



10
11
12
# File 'lib/morpheus/cli/commands/clients_command.rb', line 10

def initialize()
  #@appliance_name, @appliance_url = Morpheus::Cli::Remote.active_appliance
end

Instance Method Details

#add(args) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/morpheus/cli/commands/clients_command.rb', line 90

def add(args)
  options = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[clientId] [options]")
    build_option_type_options(opts, options, add_client_option_types)
    build_standard_add_options(opts, options)
    opts.footer = "Add New Oauth Client Record."
  end
  optparse.parse!(args)
  if args.count > 1
    raise_command_error "wrong number of arguments, expected 0-1 and got (#{args.count}) #{args}\n#{optparse}"
  end
  if args[0]
    options[:options] ||= {}
    options[:options]['clientId'] ||= args[0]
  end
  connect(options)
  begin
     # construct payload
    passed_options = options[:options] ? options[:options].reject {|k,v| k.is_a?(Symbol) } : {}
    payload = nil
    if options[:payload]
      payload = options[:payload]
      payload.deep_merge!({'client' => passed_options}) unless passed_options.empty?
    else
      payload = {
        'client' => {
        }
      }
      # allow arbitrary -O options
      payload.deep_merge!({'client' => passed_options}) unless passed_options.empty?
      # prompt for options
      params = Morpheus::Cli::OptionTypes.prompt(add_client_option_types, options[:options], @api_client, options[:params])
      params.booleanize!
      if params['redirectUris'] && params['redirectUris'].is_a?(String)
        params['redirectUris'] = params['redirectUris'].split(',').collect {|it| it.strip}.reject {|it| it.empty?}
      end
      payload.deep_merge!({'client' => params}) unless params.empty?
    end

    @clients_interface.setopts(options)
    if options[:dry_run]
      print_dry_run @clients_interface.dry.create(payload)
      return
    end
    json_response = @clients_interface.create(payload)
    if options[:json]
      print JSON.pretty_generate(json_response)
      print "\n"
    else
      display_name = json_response['client']  ? json_response['client']['clientId'] : ''
      print_green_success "Client #{display_name} added"
      get([json_response['client']['id']] + (options[:remote] ? ["-r",options[:remote]] : []))
    end
    return 0
  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    exit 1
  end
end

#connect(opts) ⇒ Object



14
15
16
17
# File 'lib/morpheus/cli/commands/clients_command.rb', line 14

def connect(opts)
  @api_client = establish_remote_appliance_connection(opts)
  @clients_interface = @api_client.clients
end

#get(args) ⇒ Object



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/morpheus/cli/commands/clients_command.rb', line 54

def get(args)
  params = {}
  options = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[client]")
    build_standard_get_options(opts, options)
    opts.footer = "Get details about an oath client.\n" + 
                  "[client] is required. This is the name or id of a client."

  end
  optparse.parse!(args)
  verify_args!(args:args, optparse:optparse, count:1)
  connect(options)
  id = args[0]
  if id.to_s !~ /\A\d{1,}\Z/
    client = find_client_by_client_id(id)
    return 1 if client.nil?
    id = client['id']
  else
    id = id.to_i
  end
  @clients_interface.setopts(options)
  if options[:dry_run]
    print_dry_run @clients_interface.dry.get(id, params)
    return
  end
  json_response = @clients_interface.get(id, params)
  render_response(json_response, options, 'client') do
    client = json_response['client']
    print_h1 "Client Details", [], options
    print cyan
    print_description_list(client_columns, client)
    print reset,"\n"
  end
end

#handle(args) ⇒ Object



19
20
21
# File 'lib/morpheus/cli/commands/clients_command.rb', line 19

def handle(args)
  handle_subcommand(args)
end

#list(args) ⇒ Object



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/morpheus/cli/commands/clients_command.rb', line 23

def list(args)
  options = {}
  params = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage()
    build_standard_list_options(opts, options)
    opts.footer = "List Oauth Clients."
  end
  optparse.parse!(args)
  connect(options)
  # verify_args!(args:args, optparse:optparse, count:0)
  if args.count > 0
    options[:phrase] = args.join(" ")
  end
  params.merge!(parse_list_options(options))
  @clients_interface.setopts(options)
  if options[:dry_run]
    print_dry_run @clients_interface.dry.list(params)
    return 0
  end
  json_response = @clients_interface.list(params)
  render_response(json_response, options, "clients") do 
    clients = json_response['clients']
    print_h1 "Morpheus Clients", [], options
    print as_pretty_table(clients, client_columns.upcase_keys!, options)
    print reset
    print_results_pagination(json_response)
    print reset,"\n"
  end
end

#remove(args) ⇒ Object



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/morpheus/cli/commands/clients_command.rb', line 218

def remove(args)
  options = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[clientId]")
    build_common_options(opts, options, [:auto_confirm, :json, :dry_run, :remote])
    opts.footer = "Deletes Oauth Client."
  end
  optparse.parse!(args)

  if args.count != 1
    raise_command_error "wrong number of arguments, expected 1 and got (#{args.count}) #{args}\n#{optparse}"
  end

  connect(options)
  begin
    client = find_client_by_name_or_id(args[0])
    return 1 if client.nil?

    unless options[:yes] || Morpheus::Cli::OptionTypes.confirm("Are you sure you want to delete the client #{client['clientId']}?")
      return 9, "aborted command"
    end
    @clients_interface.setopts(options)
    if options[:dry_run]
      print_dry_run @clients_interface.dry.destroy(client['id'])
      return
    end
    json_response = @clients_interface.destroy(client['id'])
    if options[:json]
      print JSON.pretty_generate(json_response)
      print "\n"
    else
      print_green_success "Client #{client['clientId']} removed"
      # list([] + (options[:remote] ? ["-r",options[:remote]] : []))
    end
    return 0
  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    exit 1
  end
end

#update(args) ⇒ Object



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/morpheus/cli/commands/clients_command.rb', line 151

def update(args)
  options = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[clientId] [options]")
    build_option_type_options(opts, options, update_client_option_types)
    build_standard_update_options(opts, options)
    opts.footer = "Update Oauth Client Record."
  end
  optparse.parse!(args)

  if args.count != 1
    raise_command_error "wrong number of arguments, expected 1 and got (#{args.count}) #{args}\n#{optparse}"
  end

  connect(options)
  begin

    client = find_client_by_name_or_id(args[0])
    return 1 if client.nil?

    # construct payload
    passed_options = options[:options] ? options[:options].reject {|k,v| k.is_a?(Symbol) } : {}
    payload = nil
    if options[:payload]
      payload = options[:payload]
      payload.deep_merge!({'client' => passed_options}) unless passed_options.empty?
    else
      payload = {
        'client' => {
        }
      }
      # allow arbitrary -O options
      payload.deep_merge!({'client' => passed_options}) unless passed_options.empty?
      # prompt for options
      #params = Morpheus::Cli::OptionTypes.no_prompt(update_client_option_types, options[:options], @api_client, options[:params])
      params = passed_options
      params.booleanize!
      if params['redirectUris'] && params['redirectUris'].is_a?(String)
        params['redirectUris'] = params['redirectUris'].split(',').collect {|it| it.strip}.reject {|it| it.empty?}
      end
      if params.empty?
        raise_command_error "Specify at least one option to update.\n#{optparse}"
      end

      payload.deep_merge!({'client' => params}) unless params.empty?
    end
    @clients_interface.setopts(options)
    if options[:dry_run]
      print_dry_run @clients_interface.dry.update(client['id'], payload)
      return
    end
    json_response = @clients_interface.update(client['id'], payload)
    if options[:json]
      print JSON.pretty_generate(json_response)
      print "\n"
    else
      display_name = json_response['client'] ? json_response['client']['clientId'] : ''
      print_green_success "Client #{display_name} updated"
      get([json_response['client']['id']] + (options[:remote] ? ["-r",options[:remote]] : []))
    end
    return 0
  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    exit 1
  end
end