Class: Morpheus::Cli::Tasks
- Inherits:
-
Object
- Object
- Morpheus::Cli::Tasks
- Includes:
- CliCommand
- Defined in:
- lib/morpheus/cli/tasks.rb
Instance Attribute Summary
Attributes included from CliCommand
Instance Method Summary collapse
- #_get(id, options) ⇒ Object
- #add(args) ⇒ Object
- #connect(opts) ⇒ Object
- #execute(args) ⇒ Object
- #get(args) ⇒ Object
- #handle(args) ⇒ Object
- #list(args) ⇒ Object
- #remove(args) ⇒ Object
- #task_types(args) ⇒ Object
- #update(args) ⇒ Object
Methods included from CliCommand
#build_common_options, #build_option_type_options, #command_name, #default_refresh_interval, #default_subcommand, #establish_remote_appliance_connection, #full_command_usage, #handle_subcommand, included, #interactive?, #my_help_command, #my_terminal, #my_terminal=, #parse_bytes_param, #parse_id_list, #parse_list_options, #parse_list_subtitles, #parse_payload, #parse_query_options, #print, #print_error, #puts, #puts_error, #raise_command_error, #render_with_format, #run_command_for_each_arg, #subcommand_aliases, #subcommand_usage, #subcommands, #usage, #verify_access_token!
Instance Method Details
#_get(id, options) ⇒ Object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/morpheus/cli/tasks.rb', line 96 def _get(id, ) task_name = id begin @tasks_interface.setopts() if [:dry_run] if task_name.to_s =~ /\A\d{1,}\Z/ print_dry_run @tasks_interface.dry.get(task_name.to_i) else print_dry_run @tasks_interface.dry.get({name: task_name}) end return end task = find_task_by_name_or_id(task_name) exit 1 if task.nil? # refetch it json_response = {'task' => task} unless task_name.to_s =~ /\A\d{1,}\Z/ json_response = @tasks_interface.get(task['id']) end if [:json] puts as_json(json_response, , "task") return 0 elsif [:yaml] puts as_yaml(json_response, , "task") return 0 elsif [:csv] puts records_as_csv([json_response['task']], ) return 0 else # load task type to know which options to display task_type = task['taskType'] ? find_task_type_by_name(task['taskType']['name']) : nil #print "\n", cyan, "Task #{task['name']} - #{task['taskType']['name']}\n\n" print_h1 "Task Details" print cyan description_cols = { "ID" => 'id', "Name" => 'name', "Code" => 'code', "Type" => lambda {|it| it['taskType']['name'] }, "Execute Target" => lambda {|it| if it['executeTarget'] == 'local' git_info = [] if it['taskOptions'] if it['taskOptions']['localScriptGitId'] git_info << "Git Repo: #{it['taskOptions']['localScriptGitId']}" end if it['taskOptions']['localScriptGitRef'] git_info << "Git Ref: #{it['taskOptions']['localScriptGitRef']}" end end "Local #{git_info.join(', ')}" elsif it['executeTarget'] == 'remote' remote_url = "" if it['taskOptions'] remote_url = "#{it['taskOptions']['username']}@#{it['taskOptions']['host']}:#{it['taskOptions']['port']}" end "Remote #{remote_url}" elsif it['executeTarget'] == 'resource' "Resource" else it['executeTarget'] end }, "Result Type" => 'resultType', "Retryable" => lambda {|it| if it['retryable'] format_boolean(it['retryable']).to_s + " Count: #{it['retryCount']}, Delay: #{it['retryDelaySeconds']}" else format_boolean(it['retryable']) end }, "Allow Custom Config" => lambda {|it| format_boolean(it['allowCustomConfig']) }, "Created" => lambda {|it| format_local_dt(it['dateCreated']) }, "Updated" => lambda {|it| format_local_dt(it['lastUpdated']) } } print_description_list(description_cols, task) # JD: uhh, the api should NOT be returning passwords!! if task_type task_type['optionTypes'].sort { |x,y| x['displayOrder'].to_i <=> y['displayOrder'].to_i }.each do |optionType| if optionType['fieldLabel'].to_s.downcase == 'script' print_h2 "Script" print reset,bright_black,"#{task['taskOptions'][optionType['fieldName']]}","\n",reset else print cyan,("#{optionType['fieldLabel']} : " + (optionType['type'] == 'password' ? "#{task['taskOptions'][optionType['fieldName']] ? '************' : ''}" : "#{task['taskOptions'][optionType['fieldName']] || optionType['defaultValue']}")),"\n" end end else print yellow,"Task type not found.",reset,"\n" end print reset,"\n" return 0 end rescue RestClient::Exception => e print_rest_exception(e, ) exit 1 end end |
#add(args) ⇒ Object
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/morpheus/cli/tasks.rb', line 299 def add(args) params = {} = {:options => {}} task_name = nil task_code = nil task_type_name = nil optparse = Morpheus::Cli::OptionParser.new do |opts| opts. = subcommand_usage("[name] -t TASK_TYPE") opts.on( '-t', '--type TASK_TYPE', "Task Type" ) do |val| task_type_name = val end opts.on('--name NAME', String, "Task Name" ) do |val| task_name = val end opts.on('--code CODE', String, "Task Code" ) do |val| task_code = val end opts.on('--result-type VALUE', String, "Result Type" ) do |val| [:options]['resultType'] = val end opts.on('--result-type VALUE', String, "Result Type" ) do |val| [:options]['executeTarget'] = val end opts.on('--execute-target VALUE', String, "Execute Target" ) do |val| [:options]['executeTarget'] = val end opts.on('--target-host VALUE', String, "Target Host" ) do |val| [:options]['taskOptions'] ||= {} [:options]['taskOptions']['host'] = val end opts.on('--target-port VALUE', String, "Target Port" ) do |val| [:options]['taskOptions'] ||= {} [:options]['taskOptions']['port'] = val end opts.on('--target-username VALUE', String, "Target Username" ) do |val| [:options]['taskOptions'] ||= {} [:options]['taskOptions']['username'] = val end opts.on('--target-password VALUE', String, "Target Password" ) do |val| [:options]['taskOptions'] ||= {} [:options]['taskOptions']['password'] = val end opts.on('--git-repo VALUE', String, "Git Repo ID" ) do |val| [:options]['taskOptions'] ||= {} [:options]['taskOptions']['localScriptGitId'] = val end opts.on('--git-ref VALUE', String, "Git Ref" ) do |val| [:options]['taskOptions'] ||= {} [:options]['taskOptions']['localScriptGitRef'] = val end opts.on('--retryable [on|off]', String, "Retryable" ) do |val| [:options]['retryable'] = val.to_s == 'on' || val.to_s == 'true' || val == '' || val.nil? end opts.on('--retry-count COUNT', String, "Retry Count" ) do |val| [:options]['retryCount'] = val.to_i end opts.on('--retry-delay SECONDS', String, "Retry Delay Seconds" ) do |val| [:options]['retryDelaySeconds'] = val.to_i end opts.on('--allow-custom-config [on|off]', String, "Allow Custom Config") do |val| [:options]['allowCustomConfig'] = val.to_s == 'on' || val.to_s == 'true' || val.to_s == '' end opts.on('--file FILE', "File containing the script. This can be used instead of --O taskOptions.script" ) do |filename| full_filename = File.(filename) if File.exists?(full_filename) [:options]['taskOptions'] ||= {} [:options]['taskOptions']['script'] = File.read(full_filename) # params['script'] = File.read(full_filename) else print_red_alert "File not found: #{full_filename}" exit 1 end # use the filename as the name by default. if ![:options]['name'] [:options]['name'] = File.basename(full_filename) end end (opts, , [:options, :payload, :json, :dry_run, :quiet, :remote]) end optparse.parse!(args) if args.count > 1 raise_command_error "wrong number of arguments, expected 1 and got (#{args.count}) #{args.join(' ')}\n#{optparse}" end if args[0] task_name = args[0] end # if task_name.nil? || task_type_name.nil? # puts optparse # exit 1 # end connect() begin = [:options] ? [:options].reject {|k,v| k.is_a?(Symbol) } : {} if ['type'] task_type_name = .delete('type') end payload = nil if [:payload] payload = [:payload] payload.deep_merge!({'task' => }) unless .empty? else # construct payload payload = { "task" => { #"name" => task_name, #"code" => task_code, #"taskType" {"id" => task_type['id'], "code" => task_type['code']}, #"taskOptions" => {} } } payload.deep_merge!({'task' => }) unless .empty? # Name if task_name payload['task']['name'] = task_name else v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'name', 'fieldLabel' => 'Name', 'type' => 'text', 'required' => true, 'description' => 'Name'}], [:options], @api_client) payload['task']['name'] = v_prompt['name'] unless v_prompt['name'].to_s.empty? end # Code if task_code payload['task']['code'] = task_code else v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'code', 'fieldLabel' => 'Code', 'type' => 'text', 'description' => 'Code'}], [:options], @api_client) payload['task']['code'] = v_prompt['code'] unless v_prompt['code'].to_s.empty? end # Task Type @all_task_types ||= @tasks_interface.task_types({max:1000})['taskTypes'] task_types_dropdown = @all_task_types.collect {|it| {"name" => it["name"], "value" => it["code"]}} if task_type_name #payload['task']['taskType'] = task_type_name else v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'type', 'fieldLabel' => 'Type', 'type' => 'select', 'selectOptions' => task_types_dropdown, 'required' => true}], [:options], @api_client) task_type_name = v_prompt['type'] end task_type = find_task_type_by_name(task_type_name) if task_type.nil? print_red_alert "Task Type not found by code '#{task_type_name}'" return 1 end payload['task']['taskType'] = {"id" => task_type['id'], "code" => task_type['code']} # Result Type if [:options]['resultType'] payload['task']['resultType'] = [:options]['resultType'] else result_types_dropdown = [{"name" => "Value", "value" => "value"}, {"name" => "Exit Code", "value" => "exitCode"}, {"name" => "Key Value", "value" => "keyValue"}, {"name" => "JSON", "value" => "json"}] v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'resultType', 'fieldLabel' => 'Result Type', 'type' => 'select', 'selectOptions' => result_types_dropdown}], [:options], @api_client) payload['task']['resultType'] = v_prompt['resultType'] unless v_prompt['resultType'].to_s.empty? end # Task Type Option Types # JD: uhh some of these are missing a fieldContext? # containerScript just points to a library script via Id now?? task_option_types = task_type['optionTypes'] || [] task_option_types.each do |it| if it['fieldContext'].nil? || it['fieldContext'] == '' it['fieldContext'] = 'taskOptions' end end = Morpheus::Cli::OptionTypes.prompt(task_option_types, [:options],@api_client, [:params]) payload.deep_merge!({'task' => }) unless .empty? # Target Options if [:options]['executeTarget'] != nil payload['task']['executeTarget'] = [:options]['executeTarget'] else default_target = nil execute_targets_dropdown = [] if task_type['allowExecuteLocal'] default_target = 'local' execute_targets_dropdown << {"name" => "Local", "value" => "local"} end if task_type['allowExecuteRemote'] default_target = 'remote' execute_targets_dropdown << {"name" => "Remote", "value" => "remote"} end if task_type['allowExecuteResource'] default_target = 'resource' execute_targets_dropdown << {"name" => "Resource", "value" => "resource"} end if !execute_targets_dropdown.empty? v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'executeTarget', 'fieldLabel' => 'Execute Target', 'type' => 'select', 'selectOptions' => execute_targets_dropdown, 'defaultValue' => default_target, 'required' => true}], [:options], @api_client) payload['task']['executeTarget'] = v_prompt['executeTarget'].to_s unless v_prompt['executeTarget'].to_s.empty? end end if payload['task']['executeTarget'] == 'local' # Git Repo v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldContext' => 'taskOptions', 'fieldName' => 'localScriptGitId', 'fieldLabel' => 'Git Repo', 'type' => 'text', 'description' => 'Git Repo ID'}], [:options], @api_client) if v_prompt['taskOptions'] && !v_prompt['taskOptions']['localScriptGitId'].to_s.empty? payload['task']['taskOptions'] ||= {} payload['task']['taskOptions']['localScriptGitId'] = v_prompt['taskOptions']['localScriptGitId'] end # Git Ref v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldContext' => 'taskOptions', 'fieldName' => 'localScriptGitRef', 'fieldLabel' => 'Git Ref', 'type' => 'text', 'description' => 'Git Ref eg. master'}], [:options], @api_client) if v_prompt['taskOptions'] && !v_prompt['taskOptions']['localScriptGitRef'].to_s.empty? payload['task']['taskOptions'] ||= {} payload['task']['taskOptions']['localScriptGitRef'] = v_prompt['taskOptions']['localScriptGitRef'] end elsif payload['task']['executeTarget'] == 'remote' # Host v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldContext' => 'taskOptions', 'fieldName' => 'host', 'fieldLabel' => 'IP Address', 'type' => 'text', 'description' => 'IP Address / Host for remote execution'}], [:options], @api_client) if v_prompt['taskOptions'] && !v_prompt['taskOptions']['host'].to_s.empty? payload['task']['taskOptions'] ||= {} payload['task']['taskOptions']['host'] = v_prompt['taskOptions']['host'] end # Port v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldContext' => 'taskOptions', 'fieldName' => 'port', 'fieldLabel' => 'Port', 'type' => 'text', 'description' => 'Port for remote execution', 'defaultValue' => '22'}], [:options], @api_client) if v_prompt['taskOptions'] && !v_prompt['taskOptions']['port'].to_s.empty? payload['task']['taskOptions'] ||= {} payload['task']['taskOptions']['port'] = v_prompt['taskOptions']['port'] end # Host v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldContext' => 'taskOptions', 'fieldName' => 'username', 'fieldLabel' => 'Username', 'type' => 'text', 'description' => 'Username for remote execution'}], [:options], @api_client) if v_prompt['taskOptions'] && !v_prompt['taskOptions']['username'].to_s.empty? payload['task']['taskOptions'] ||= {} payload['task']['taskOptions']['username'] = v_prompt['taskOptions']['username'] end # Host v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldContext' => 'taskOptions', 'fieldName' => 'password', 'fieldLabel' => 'Password', 'type' => 'password', 'description' => 'Password for remote execution'}], [:options], @api_client) if v_prompt['taskOptions'] && !v_prompt['taskOptions']['password'].to_s.empty? payload['task']['taskOptions'] ||= {} payload['task']['taskOptions']['password'] = v_prompt['taskOptions']['password'] end end # Retryable if [:options]['retryable'] != nil payload['task']['retryable'] = [:options]['retryable'] else v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'retryable', 'fieldLabel' => 'Retryable', 'type' => 'checkbox', 'defaultValue' => false}], [:options], @api_client) payload['task']['retryable'] = ['true','on'].include?(v_prompt['retryable'].to_s) unless v_prompt['retryable'].nil? end if payload['task']['retryable'] # Retry Count if [:options]['retryCount'] payload['task']['retryCount'] = [:options]['retryCount'].to_i else v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'retryCount', 'fieldLabel' => 'Retry Count', 'type' => 'number', 'defaultValue' => 5}], [:options], @api_client) payload['task']['retryCount'] = v_prompt['retryCount'].to_i unless v_prompt['retryCount'].nil? end # Retry Delay if [:options]['retryDelay'] payload['task']['retryDelay'] = [:options]['retryDelay'].to_i else v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'retryDelay', 'fieldLabel' => 'Retry Delay', 'type' => 'number', 'defaultValue' => 10}], [:options], @api_client) payload['task']['retryDelay'] = v_prompt['retryDelay'].to_i unless v_prompt['retryDelay'].nil? end end # Allow Custom Config if [:options]['allowCustomConfig'] != nil payload['task']['allowCustomConfig'] = [:options]['allowCustomConfig'] else v_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'allowCustomConfig', 'fieldLabel' => 'Allow Custom Config', 'type' => 'checkbox', 'defaultValue' => false}], [:options], @api_client) payload['task']['allowCustomConfig'] = ['true','on'].include?(v_prompt['allowCustomConfig'].to_s) unless v_prompt['allowCustomConfig'].nil? end end @tasks_interface.setopts() if [:dry_run] print_dry_run @tasks_interface.dry.create(payload) return end json_response = @tasks_interface.create(payload) task = json_response['task'] if [:json] print JSON.pretty_generate(json_response),"\n" elsif ![:quiet] task = json_response['task'] print_green_success "Task #{task['name']} created" get([task['id']]) end rescue RestClient::Exception => e print_rest_exception(e, ) exit 1 end end |
#connect(opts) ⇒ Object
15 16 17 18 19 20 21 |
# File 'lib/morpheus/cli/tasks.rb', line 15 def connect(opts) @api_client = establish_remote_appliance_connection(opts) @tasks_interface = @api_client.tasks @task_sets_interface = @api_client.task_sets @instances_interface = @api_client.instances @servers_interface = @api_client.servers end |
#execute(args) ⇒ Object
636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 |
# File 'lib/morpheus/cli/tasks.rb', line 636 def execute(args) params = {} = {} target_type = nil instance_ids = [] instances = [] server_ids = [] servers = [] optparse = Morpheus::Cli::OptionParser.new do |opts| opts. = subcommand_usage("[task] --instance [instance] [options]") opts.on('--instance INSTANCE', String, "Instance name or id to execute the task on. This option can be passed more than once.") do |val| target_type = 'instance' instance_ids << val end opts.on('--instances [LIST]', Array, "Instances, comma separated list of instance names or IDs.") do |list| target_type = 'instance' instance_ids = list.collect {|it| it.to_s.strip.empty? ? nil : it.to_s.strip }.compact.uniq end opts.on('--host HOST', String, "Host name or id to execute the task on. This option can be passed more than once.") do |val| target_type = 'server' server_ids << val end opts.on('--hosts [LIST]', Array, "Hosts, comma separated list of host names or IDs.") do |list| target_type = 'server' server_ids = list.collect {|it| it.to_s.strip.empty? ? nil : it.to_s.strip }.compact.uniq end opts.on('--server HOST', String, "alias for --host") do |val| target_type = 'server' server_ids << val end opts.on('--servers [LIST]', Array, "alias for --hosts") do |list| target_type = 'server' server_ids = list.collect {|it| it.to_s.strip.empty? ? nil : it.to_s.strip }.compact.uniq end opts.add_hidden_option('--server') opts.add_hidden_option('--servers') opts.on('--config [TEXT]', String, "Custom config") do |val| params['customConfig'] = val.to_s end (opts, , [:options, :json, :dry_run, :remote]) end optparse.parse!(args) if args.count != 1 raise_command_error "wrong number of arguments, expected 1 and got (#{args.count}) #{args.join(' ')}\n#{optparse}" end task_name = args[0] connect() begin task = find_task_by_name_or_id(task_name) return 1 if task.nil? = [:options] ? [:options].reject {|k,v| k.is_a?(Symbol) } : {} payload = nil if [:payload] payload = [:payload] payload.deep_merge!({'job' => }) unless .empty? else if instance_ids.size > 0 && server_ids.size > 0 raise_command_error "Pass --instance or --host, not both.\n#{optparse}" elsif instance_ids.size > 0 instance_ids.each do |instance_id| instance = find_instance_by_name_or_id(instance_id) return 1 if instance.nil? instances << instance end params['instances'] = instances.collect {|it| it['id'] } elsif server_ids.size > 0 server_ids.each do |server_id| server = find_server_by_name_or_id(server_id) return 1 if server.nil? servers << server end params['servers'] = servers.collect {|it| it['id'] } else raise_command_error "missing required option: --instance or --host\n#{optparse}" end # todo: prompt to task optionTypes for customOptions if task['optionTypes'] end params['targetType'] = target_type job_payload = {} job_payload.deep_merge!(params) job_payload.deep_merge!() unless .empty? payload = {'job' => job_payload} end @tasks_interface.setopts() if [:dry_run] print_dry_run @tasks_interface.dry.run(task['id'], payload) return end response = @tasks_interface.run(task['id'], payload) if [:json] print JSON.pretty_generate(json_response) if !response['success'] return 1 end else target_desc = "" if instances.size() > 0 target_desc = (instances.size() == 1) ? "instance #{instances[0]['name']}" : "#{instances.size()} instances" elsif servers.size() > 0 target_desc = (servers.size() == 1) ? "host #{servers[0]['name']}" : "#{servers.size()} hosts" end print_green_success "Executing task #{task['name']} on #{target_desc}" # todo: load job/execution # get([task['id']]) end return 0 rescue RestClient::Exception => e print_rest_exception(e, ) return 1 end end |
#get(args) ⇒ Object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/morpheus/cli/tasks.rb', line 78 def get(args) = {} optparse = Morpheus::Cli::OptionParser.new do |opts| opts. = subcommand_usage("[workflow]") (opts, , [:json, :yaml, :csv, :fields, :dry_run, :remote]) end optparse.parse!(args) if args.count < 1 puts optparse return 1 end connect() id_list = parse_id_list(args) return run_command_for_each_arg(id_list) do |arg| _get(arg, ) end end |
#handle(args) ⇒ Object
23 24 25 |
# File 'lib/morpheus/cli/tasks.rb', line 23 def handle(args) handle_subcommand(args) end |
#list(args) ⇒ Object
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/morpheus/cli/tasks.rb', line 27 def list(args) params = {} = {} optparse = Morpheus::Cli::OptionParser.new do |opts| opts. = subcommand_usage() opts.on('--types x,y,z', Array, "Filter by task type code(s)") do |val| params['taskTypeCodes'] = val end (opts, , [:list, :query, :json, :yaml, :csv, :fields, :dry_run, :remote]) end optparse.parse!(args) connect() begin params.merge!(()) @tasks_interface.setopts() if [:dry_run] print_dry_run @tasks_interface.dry.get(params) return end json_response = @tasks_interface.get(params) # print result and return output if [:json] puts as_json(json_response, , "tasks") return 0 elsif [:csv] puts records_as_csv(json_response['tasks'], ) return 0 elsif [:yaml] puts as_yaml(json_response, , "tasks") return 0 else title = "Morpheus Tasks" subtitles = [] subtitles += parse_list_subtitles() print_h1 title, subtitles tasks = json_response['tasks'] if tasks.empty? print cyan,"No tasks found.",reset,"\n" else print cyan print_tasks_table(tasks, ) print_results_pagination(json_response) end print reset,"\n" end rescue RestClient::Exception => e print_rest_exception(e, ) exit 1 end end |
#remove(args) ⇒ Object
596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 |
# File 'lib/morpheus/cli/tasks.rb', line 596 def remove(args) params = {} task_name = args[0] = {} optparse = Morpheus::Cli::OptionParser.new do |opts| opts. = subcommand_usage("[task]") (opts, , [:auto_confirm, :json, :dry_run, :quiet, :remote]) opts.on( '-f', '--force', "Force Delete" ) do params[:force] = true end end optparse.parse!(args) if args.count < 1 puts optparse exit 1 end connect() begin task = find_task_by_name_or_id(task_name) exit 1 if task.nil? unless [:yes] || Morpheus::Cli::OptionTypes.confirm("Are you sure you want to delete the task #{task['name']}?") exit end @tasks_interface.setopts() if [:dry_run] print_dry_run @tasks_interface.dry.destroy(task['id'], params) return end json_response = @tasks_interface.destroy(task['id'], params) if [:json] print JSON.pretty_generate(json_response),"\n" elsif ![:quiet] print_green_success "Task #{task['name']} removed" end rescue RestClient::Exception => e print_rest_exception(e, ) exit 1 end end |
#task_types(args) ⇒ Object
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/morpheus/cli/tasks.rb', line 261 def task_types(args) = {} optparse = Morpheus::Cli::OptionParser.new do |opts| opts. = subcommand_usage() (opts, , [:json, :dry_run, :remote]) end optparse.parse!(args) connect() begin @tasks_interface.setopts() if [:dry_run] print_dry_run @tasks_interface.dry.task_types() return end json_response = @tasks_interface.task_types() if [:json] print JSON.pretty_generate(json_response),"\n" else task_types = json_response['taskTypes'] print_h1 "Morpheus Task Types" if task_types.nil? || task_types.empty? print yellow,"No task types currently exist on this appliance. This could be a seed issue.",reset,"\n" else print cyan rows = task_types.collect do |task_type| {name: task_type['name'], id: task_type['id'], code: task_type['code'], description: task_type['description']} end puts as_pretty_table(rows, [:id, :name, :code], ) end print reset,"\n" end rescue RestClient::Exception => e print_rest_exception(e, ) exit 1 end end |
#update(args) ⇒ Object
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/morpheus/cli/tasks.rb', line 195 def update(args) = {} account_name = nil optparse = Morpheus::Cli::OptionParser.new do |opts| opts. = subcommand_usage("[task] [options]") (opts, , [:options, :json, :dry_run, :remote]) end optparse.parse!(args) if args.count < 1 puts optparse exit 1 end task_name = args[0] connect() begin task = find_task_by_name_or_id(task_name) exit 1 if task.nil? task_type = find_task_type_by_name(task['taskType']['name']) #params = Morpheus::Cli::OptionTypes.prompt(add_user_option_types, options[:options], @api_client, options[:params]) # options[:params] is mysterious params = [:options] || {} if params.empty? puts optparse. option_lines = update_task_option_types(task_type).collect {|it| "\t-O #{it['fieldContext'] ? (it['fieldContext'] + '.') : ''}#{it['fieldName']}=\"value\"" }.join("\n") puts "\nAvailable Options:\n#{option_lines}\n\n" exit 1 end #puts "parsed params is : #{params.inspect}" task_keys = ['name'] changes_payload = (params.select {|k,v| task_keys.include?(k) }) task_payload = task if changes_payload task_payload.merge!(changes_payload) end if params['taskOptions'] task_payload['taskOptions'].merge!(params['taskOptions']) end payload = {task: task_payload} @tasks_interface.setopts() if [:dry_run] print_dry_run @tasks_interface.dry.update(task['id'], payload) return 0 end response = @tasks_interface.update(task['id'], payload) if [:json] print JSON.pretty_generate(json_response) if !response['success'] return 1 end else print_green_success "Task #{response['task']['name']} updated" get([task['id']]) end return 0 rescue RestClient::Exception => e print_rest_exception(e, ) return 1 end end |