Class: Morpheus::Cli::Users

Inherits:
Object
  • Object
show all
Includes:
AccountsHelper, CliCommand, WhoamiHelper
Defined in:
lib/morpheus/cli/users.rb

Instance Attribute Summary

Attributes included from CliCommand

#no_prompt

Instance Method Summary collapse

Methods included from WhoamiHelper

#current_account, #current_user, #current_user_permissions, included, #is_master_account, #load_whoami

Methods included from AccountsHelper

#accounts_interface, #find_account_by_id, #find_account_by_name, #find_account_by_name_or_id, #find_account_from_options, #find_all_user_ids, #find_role_by_id, #find_role_by_name, #find_role_by_name_or_id, #find_user_by_id, #find_user_by_username, #find_user_by_username_or_id, #find_user_group_by_id, #find_user_group_by_name, #find_user_group_by_name_or_id, #format_access_string, #format_role_type, #format_user_role_names, #get_access_color, #get_access_string, included, #print_accounts_table, #print_roles_table, #print_users_table, #roles_interface, #user_groups_interface, #users_interface

Methods included from CliCommand

#apply_options, #build_common_options, #build_option_type_options, #build_standard_add_options, #build_standard_delete_options, #build_standard_get_options, #build_standard_list_options, #build_standard_post_options, #build_standard_put_options, #build_standard_remove_options, #build_standard_update_options, #command_name, #default_refresh_interval, #default_subcommand, #establish_remote_appliance_connection, #full_command_usage, #handle_subcommand, included, #interactive?, #my_help_command, #my_terminal, #my_terminal=, #parse_bytes_param, #parse_id_list, #parse_list_options, #parse_list_subtitles, #parse_passed_options, #parse_payload, #parse_query_options, #print, #print_error, #println, #puts, #puts_error, #raise_args_error, #raise_command_error, #render_response, #render_with_format, #run_command_for_each_arg, #subcommand_aliases, #subcommand_usage, #subcommands, #usage, #verify_args!, #visible_subcommands

Constructor Details

#initializeUsers

todo: TOO_SIMPL_REGEX = //i TOO_SIMPLE_ERROR = "Password too simple. Password must contain at least one uppercase letter, one lowercase letter, a number, and a symbol."



22
23
24
# File 'lib/morpheus/cli/users.rb', line 22

def initialize()
  # @appliance_name, @appliance_url = Morpheus::Cli::Remote.active_appliance
end

Instance Method Details

#add(args) ⇒ Object



411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/morpheus/cli/users.rb', line 411

def add(args)
  options = {}
  params = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[username] [email] [first] [last] [options]")
    build_option_type_options(opts, options, add_user_option_types)
    build_common_options(opts, options, [:account, :options, :payload, :json, :dry_run])
    opts.footer = "Create a new user.\n[username] is required. Username of the new user\n[email] is required. Email address\n[first] is optional. First Name\n[last] is optional. Last Name\n"
  end
  optparse.parse!(args)
  verify_args!(args:args, optparse:optparse, min:0, max:4)
  options[:options]['username'] = args[0] if args[0]
  options[:options]['email'] = args[1] if args[1]
  options[:options]['firstName'] = args[2] if args[2]
  options[:options]['lastName'] = args[3] if args[3]
  connect(options)
  begin

     = (options)
     =  ? ['id'] : nil

    payload = {}
    if options[:payload]
      payload = options[:payload]
      payload.deep_merge!(parse_passed_options(options))
    else
      # merge -O options into normally parsed options
      payload.deep_merge!(parse_passed_options(options))
      # remove role option_type, it is just for help display, the role prompt is separate down below
      prompt_option_types = add_user_option_types().reject {|it| 'role' == it['fieldName'] }
      v_prompt = Morpheus::Cli::OptionTypes.prompt(prompt_option_types, options[:options], @api_client, options[:params])
      params.deep_merge!(v_prompt)

      # prompt for roles
      selected_roles = []
      selected_roles += params.delete('role').split(',').collect {|r| r.strip.empty? ? nil : r.strip}.uniq if params['role']
      selected_roles += params.delete('roles').split(',').collect {|r| r.strip.empty? ? nil : r.strip}.uniq if params['roles']
      roles = prompt_user_roles(, nil, selected_roles, options)
      if !roles.empty?
        params['roles'] = roles.collect {|r| {id: r['id']} }
      end      
      payload = {'user' => params}
    end
    if options[:dry_run] && options[:json]
      puts as_json(payload, options)
      return 0
    end
    @users_interface.setopts(options)
    if options[:dry_run]
      print_dry_run @users_interface.dry.create(, payload)
      return
    end
    json_response = @users_interface.create(, payload)
    if options[:json]
      print JSON.pretty_generate(json_response)
      print "\n"
    else
    username = "" # json_response['user']['username']
    username = payload['user']['username'] if payload['user'] && payload['user']['username']
    if 
      print_green_success "Added user #{username} to account #{account['name']}"
    else
      print_green_success "Added user #{username}"
    end
    details_options = [username]
    if 
      details_options.push "--account-id", ['id'].to_s
    end
    get(details_options + (options[:remote] ? ["-r",options[:remote]] : []))
  end
    

  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    return 1
  end
end

#change_password(args) ⇒ Object



567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
# File 'lib/morpheus/cli/users.rb', line 567

def change_password(args)
  options = {}
  new_password = nil
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[username] [password] [options]")
    # opts.on('--password VALUE', String, "New password") do |val|
    #   new_password = val
    # end
    build_standard_update_options(opts, options, [:account])
  end
  optparse.parse!(args)
  verify_args!(args:args, optparse:optparse, min:1,max:2) # [username] [password]
  connect(options)
  exit_code, err = 0, nil

  # user can be scoped to account (tenant)
   = (options)
   =  ? ['id'] : nil

  # fetch the user to update
  user = find_user_by_username_or_id(, args[0])
  return 1 if user.nil?
  
  new_password = args[1] if args[1]

  # print a warning or important info
  if !options[:quiet]
    print cyan, "Changing password for #{user['username']}", reset, "\n"
  end
  # construct change_password payload
  
  # use --payload
  if options[:payload]
    payload = options[:payload]
    payload.deep_merge!(parse_passed_options(options))
  else
    # inject -O key=value options
    payload.deep_merge!(parse_passed_options(options))

    # prompt for password input
    current_input_attempt = 1
    still_prompting = new_password ? false : true
    while still_prompting do
      # New Password
      password_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'password', 'fieldLabel' => 'New Password', 'type' => 'password', 'required' => true}], options[:options], @api_client)
      new_password = password_prompt['password']
        
      # could validate password is "strong"
      # Confirm New Password
      confirm_prompt = Morpheus::Cli::OptionTypes.prompt([{'fieldName' => 'passwordConfirmation', 'fieldLabel' => 'Confirm Password', 'type' => 'password', 'required' => true}], options[:options], @api_client)
      confirm_password = confirm_prompt['passwordConfirmation']
      if confirm_password != new_password
        print_red_alert "Confirm password did not match."
        new_password = nil
        unless ::Morpheus::Cli::OptionTypes::confirm("Would you like to try again?", options.merge({default: true}))
          return 9, "aborted login"
        end
      end
      still_prompting = !!new_password
    end
    payload = {
      'user' => {
        'password' => new_password
      } 
    }

  end
  @users_interface.setopts(options)
  if options[:dry_run]
    print_dry_run @users_interface.dry.update(, user['id'], payload)
    return
  end
  json_response = @users_interface.update(, user['id'], payload)
  render_response(json_response, optparse, "user") do
    print_green_success "Updated password for user #{user['username']}"
  end
  return exit_code, err
end

#connect(opts) ⇒ Object



26
27
28
29
30
31
# File 'lib/morpheus/cli/users.rb', line 26

def connect(opts)
  @api_client = establish_remote_appliance_connection(opts)
  @users_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).users
  @accounts_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).accounts
  @roles_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).roles
end

#count(args) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/morpheus/cli/users.rb', line 85

def count(args)
  options = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[options]")
    build_common_options(opts, options, [:account, :query, :remote, :dry_run])
    opts.footer = "Get the number of users."
  end
  optparse.parse!(args)
  connect(options)
  begin
     = (options)
     =  ? ['id'] : nil
    params = {}
    params.merge!(parse_list_options(options))
    @users_interface.setopts(options)
    if options[:dry_run]
      print_dry_run @users_interface.dry.list(, params)
      return
    end
    json_response = @users_interface.list(, params)
    # print number only
    if json_response['meta'] && json_response['meta']['total']
      print cyan, json_response['meta']['total'], reset, "\n"
    else
      print yellow, "unknown", reset, "\n"
    end
  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    exit 1
  end
end

#get(args) ⇒ Object



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/morpheus/cli/users.rb', line 117

def get(args)
  options = {}
  params = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[username]")
    opts.on('-p','--permissions', "Display Permissions") do |val|
      options[:include_features_access] = true
      params['includeAccess'] = true
    end
    opts.on(nil,'--feature-access', "Display Permissions") do |val|
      options[:include_features_access] = true
      params['includeAccess'] = true
    end
    opts.add_hidden_option('--feature-access')
    opts.on(nil,'--group-access', "Display Group Access") do
      options[:include_sites_access] = true
      params['includeAccess'] = true
    end
    opts.on(nil,'--cloud-access', "Display Cloud Access") do
      options[:include_zones_access] = true
      params['includeAccess'] = true
    end
    opts.on(nil,'--instance-type-access', "Display Instance Type Access") do
      options[:include_instance_types_access] = true
      params['includeAccess'] = true
    end
    opts.on(nil,'--blueprint-access', "Display Blueprint Access") do
      options[:include_app_templates_access] = true
      params['includeAccess'] = true
    end
    opts.on(nil,'--all', "Display All Access Lists") do
      options[:include_features_access] = true
      options[:include_sites_access] = true
      options[:include_zones_access] = true
      options[:include_instance_types_access] = true
      options[:include_app_templates_access] = true
      params['includeAccess'] = true
    end
    opts.on('-i', '--include-none-access', "Include Items with 'None' Access in Access List") do
      options[:display_none_access] = true
    end
    build_common_options(opts, options, [:account, :json, :yaml, :csv, :fields, :dry_run, :remote])
    opts.footer = "Get details about a user." + "\n" +
                  "[username] is required. This is the username or id of a user."
  end
  optparse.parse!(args)

  if args.count < 1
    puts optparse
    return 1
  end

  connect(options)
  begin
     = (options)
     =  ? ['id'] : nil
    @users_interface.setopts(options)
    if options[:dry_run]
      if args[0].to_s =~ /\A\d{1,}\Z/
        print_dry_run @users_interface.dry.get(, args[0].to_i, params)
      else
        print_dry_run @users_interface.dry.get(, {username: args[0]}, params)
      end
      return
    end

    if args[0].to_s =~ /\A\d{1,}\Z/
      user_id = args[0].to_i
    else
      user = find_user_by_username(, args[0])

      if user.nil?
        print_red_alert "User #{args[0]} not found"
        exit 1
      end
      user_id = user['id']
    end

    user = @users_interface.get(, user_id, params)['user']

    if user.nil?
      print_red_alert "User #{args[0]} not found"
      exit 1
    end

     = ['id'] != user['account']['id']

    json_response =  {'user' => user}

    if options[:json]
      puts as_json(json_response, options, "user")
      return 0
    elsif options[:yaml]
      puts as_yaml(json_response, options, "user")
      return 0
    elsif options[:csv]
      puts records_as_csv([user], options)
      return 0
    end

    print_h1 "User Details", options
    print cyan
    description_cols = {
        "ID" => 'id',
        "Account" => lambda {|it| it['account'] ? it['account']['name'] : '' },
        "First Name" => 'firstName',
        "Last Name" => 'lastName',
        # "Name" => 'displayName',
        #"Name" => lambda {|it| it['firstName'] ? it['displayName'] : '' },
        "Username" => 'username',
        "Email" => 'email',
        "Notifications" => lambda {|it| it['receiveNotifications'].nil? ? '' : format_boolean(it['receiveNotifications']) },
        "Role" => lambda {|it| format_user_role_names(it) },
        "Created" => lambda {|it| format_local_dt(it['dateCreated']) },
        "Updated" => lambda {|it| format_local_dt(it['lastUpdated']) }
    }
    print_description_list(description_cols, user)

    # backward compatibility
    if user['access'].nil? && options[:include_features_access]
      user_feature_permissions_json = @users_interface.feature_permissions(, user['id'])
      user_feature_permissions = user_feature_permissions_json['permissions'] || user_feature_permissions_json['featurePermissions']

      if user_feature_permissions
        print_h2 "Feature Permissions", options
        print cyan
        if user_feature_permissions.is_a?(Array)
          rows = user_feature_permissions.collect do |it|
            {name: it['name'], code: it['code'], access: format_access_string(it['access']) }
          end
          print as_pretty_table(rows, [:name, :code, :access], options)
        else
          rows = user_feature_permissions.collect do |code, access|
            {code: code, access: format_access_string(access) }
          end
          print as_pretty_table(rows, [:code, :access], options)
        end
      else
        puts yellow,"No permissions found.",reset
      end
    else
      available_field_options = {'features' => 'Feature', 'sites' => 'Group', 'zones' => 'Cloud', 'instance_types' => 'Instance Type', 'app_templates' => 'Blueprint'}
      available_field_options.each do |field, label|
        if !(field == 'sites' && ) && options["include_#{field}_access".to_sym]
          access = user['access'][field.split('_').enum_for(:each_with_index).collect {|word, idx| idx == 0 ? word : word.capitalize}.join]
          access = access.reject {|it| it['access'] == 'none'} if !options[:display_none_access]

          if field == "features"
            # print_h2 "Permissions", options
            print_h2 "#{label} Access", options
          else
            print_h2 "#{label} Access", options
          end
          print cyan

          # access levels vary, default is none,read,user,full
          available_access_levels = ["none","read","user","full"]
          if field == 'sites' || field == 'zones' || field == 'instance_types' || field == 'app_templates'
            available_access_levels = ["none","read","full"]
          end
          if access.count > 0
            access.each {|it| it['access'] = format_access_string(it['access'], available_access_levels)}

            if ['features', 'instance_types'].include?(field)
              print as_pretty_table(access, [:name, :code, :access], options)
            else
              print as_pretty_table(access, [:name, :access], options)
            end
          else
            println yellow,"No #{label} Access Found.",reset
          end
        end
      end
    end
    print cyan
    print reset,"\n"
  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    return 1
  end
end

#handle(args) ⇒ Object



33
34
35
# File 'lib/morpheus/cli/users.rb', line 33

def handle(args)
  handle_subcommand(args)
end

#list(args) ⇒ Object



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/morpheus/cli/users.rb', line 37

def list(args)
  options = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage()
    build_common_options(opts, options, [:account, :list, :query, :json, :yaml, :csv, :fields, :json, :dry_run, :remote])
    opts.footer = "List users."
  end
  optparse.parse!(args)
  connect(options)
  begin

     = (options)
     =  ? ['id'] : nil

    params = {}
    params.merge!(parse_list_options(options))
    @users_interface.setopts(options)
    if options[:dry_run]
      print_dry_run @users_interface.dry.list(, params)
      return
    end
    json_response = @users_interface.list(, params)
    render_result = render_with_format(json_response, options, 'users')
    return 0 if render_result
    users = json_response['users']

    title = "Morpheus Users"
    subtitles = []
    if 
      subtitles << "Account: #{account['name']}".strip
    end
    subtitles += parse_list_subtitles(options)
    print_h1 title, subtitles, options
    if users.empty?
      print cyan,"No users found.",reset,"\n"
    else
      print_users_table(users, options)
      print_results_pagination(json_response)
    end
    print reset,"\n"
    return 0
    
  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    return 1
  end
end

#permissions(args) ⇒ Object



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/morpheus/cli/users.rb', line 299

def permissions(args)
  options = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[username]")
    build_common_options(opts, options, [:account, :json, :yaml, :csv, :fields, :dry_run, :remote])
    opts.on('-i', '--include-none-access', "Include Items with 'None' Access in Access List") do
      options[:display_none_access] = true
    end
    opts.footer = "Display Access for a user." + "\n" +
                  "[username] is required. This is the username or id of a user."
  end
  optparse.parse!(args)
  verify_args!(args:args, optparse:optparse, count:1)

  connect(options)
  begin
     = (options)
     =  ? ['id'] : nil
    user = find_user_by_username_or_id(, args[0])
    return 1 if user.nil?
    @users_interface.setopts(options)
    if options[:dry_run]
      print_dry_run @users_interface.dry.permissions(, user['id'])
      return
    end

     = ['id'] != user['account']['id']

    json_response = @users_interface.permissions(, user['id'])

    # backward compatibility
    if !json_response['permissions'].nil?
      if options[:json]
        puts as_json(json_response, options, 'permissions')
        return 0
      elsif options[:yaml]
        puts as_yaml(json_response, options, 'permissions')
        return 0
      elsif options[:csv]
        puts records_as_csv(json_response['permissions'], options)
        return 0
      else
        user_feature_permissions = nil
        # permissions (Array) has replaced featurePermissions (map)
        user_feature_permissions = json_response['permissions'] || json_response['featurePermissions']
        print_h1 "User Permissions: #{user['username']}", options
        if user_feature_permissions
          print cyan
          if user_feature_permissions.is_a?(Array)
            rows = user_feature_permissions.collect do |it|
              {name: it['name'], code: it['code'], access: format_access_string(it['access']) }
            end
            print as_pretty_table(rows, [:name, :code, :access], options)
          else
            rows = user_feature_permissions.collect do |code, access|
              {code: code, access: format_access_string(access) }
            end
            print as_pretty_table(rows, [:code, :access], options)
          end

        else
          print yellow,"No permissions found.",reset,"\n"
        end
      end
    else
      if options[:json]
        puts as_json(json_response, options, 'access')
        return 0
      elsif options[:yaml]
        puts as_yaml(json_response, options, 'access')
        return 0
      elsif options[:csv]
        puts records_as_csv(json_response['access'], options)
        return 0
      end

      print_h1 "User Permissions: #{user['username']}", options

      available_field_options = {'features' => 'Feature', 'sites' => 'Group', 'zones' => 'Cloud', 'instance_types' => 'Instance Type', 'app_templates' => 'Blueprint'}
      available_field_options.each do |field, label|
        if !(field == 'sites' && )
          access = json_response['access'][field.split('_').enum_for(:each_with_index).collect {|word, idx| idx == 0 ? word : word.capitalize}.join]
          access = access.reject {|it| it['access'] == 'none'} if !options[:display_none_access]

          print_h2 "#{label} Access", options
          print cyan
          available_access_levels = ["full","user","read","none"]
          if field == 'sites' || field == 'zones' || field == 'instance_types' || field == 'app_templates'
            available_access_levels = ["full","custom","none"]
          end
          if access.count > 0
            access.each {|it| it['access'] = format_access_string(it['access'], available_access_levels)}

            if ['features', 'instance_types'].include?(field)
              print as_pretty_table(access, [:name, :code, :access], options)
            else
              print as_pretty_table(access, [:name, :access], options)
            end
          else
            println cyan,"No #{label} Access Found.",reset
          end
        end
      end
    end
    print cyan
    print reset,"\n"
  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    return 1
  end
end

#remove(args) ⇒ Object



646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
# File 'lib/morpheus/cli/users.rb', line 646

def remove(args)
  options = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[username]")
    build_common_options(opts, options, [:account, :auto_confirm, :json, :dry_run])
  end
  optparse.parse!(args)

  if args.count < 1
    puts optparse
    return 1
  end

  connect(options)
  begin

     = (options)
     =  ? ['id'] : nil

    user = find_user_by_username_or_id(, args[0])
    return 1 if user.nil?
    unless options[:yes] || Morpheus::Cli::OptionTypes.confirm("Are you sure you want to delete the user #{user['username']}?")
      exit
    end
    @users_interface.setopts(options)
    if options[:dry_run]
      print_dry_run @users_interface.dry.destroy(, user['id'])
      return
    end
    json_response = @users_interface.destroy(, user['id'])

    if options[:json]
      print JSON.pretty_generate(json_response)
      print "\n"
    else
      print_green_success "User #{user['username']} removed"
      # list([])
    end
  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    return 1
  end
end

#update(args) ⇒ Object



495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'lib/morpheus/cli/users.rb', line 495

def update(args)
  options = {}
  params = {}
  payload = {}
  optparse = Morpheus::Cli::OptionParser.new do |opts|
    opts.banner = subcommand_usage("[username] [options]")
    build_option_type_options(opts, options, update_user_option_types)
    build_common_options(opts, options, [:account, :options, :payload, :json, :dry_run])
  end
  optparse.parse!(args)
  verify_args!(args:args, optparse:optparse, count:1)
  connect(options)
  begin

     = (options)
     =  ? ['id'] : nil

    user = find_user_by_username_or_id(, args[0])
    return 1 if user.nil?

    # use --payload
    if options[:payload]
      payload = options[:payload]
      payload.deep_merge!(parse_passed_options(options))
    else
      # inject -O key=value options
      # payload.deep_merge!(parse_passed_options(options))
      params.deep_merge!(parse_passed_options(options))
      # user_prompt_output = Morpheus::Cli::OptionTypes.prompt(prompt_option_types, payload['user'], @api_client)
      selected_roles = []
      selected_roles += params.delete('role').split(',').collect {|r| r.strip.empty? ? nil : r.strip}.uniq if params['role']
      selected_roles += params.delete('roles').split(',').collect {|r| r.strip.empty? ? nil : r.strip}.uniq if params['roles']
      roles = prompt_user_roles(, user['id'], selected_roles, options.merge(no_prompt: true))
      # should it allow [] (no roles) ?
      if !roles.empty?
        params['roles'] = roles.collect {|r| {id: r['id']} }
      end
      payload.deep_merge!({'user' => params})
      if payload['user'].empty? # || options[:no_prompt]
        raise_command_error "Specify at least one option to update.\n#{optparse}"
      end
    end

    @users_interface.setopts(options)
    if options[:dry_run]
      print_dry_run @users_interface.dry.update(, user['id'], payload)
      return
    end
    json_response = @users_interface.update(, user['id'], payload)

    if options[:json]
      print JSON.pretty_generate(json_response)
      print "\n"
    else
      username = user['username'] # json_response['user']['username']
      if payload['user'] && payload['user']['username']
        username = payload['user']['username']
      end
      print_green_success "Updated user #{username}"
      details_options = [username]
      if 
        details_options.push "--account-id", ['id'].to_s
      end
      get(details_options + (options[:remote] ? ["-r",options[:remote]] : []))
    end

  rescue RestClient::Exception => e
    print_rest_exception(e, options)
    return 1
  end
end