Class: Morpheus::APIClient

Inherits:
Object
  • Object
show all
Defined in:
lib/morpheus/api/api_client.rb

Direct Known Subclasses

AccountGroupsInterface, AccountsInterface, ActivityInterface, ApplianceSettingsInterface, ApprovalsInterface, AppsInterface, ArchiveBucketsInterface, ArchiveFilesInterface, AuthInterface, BackupSettingsInterface, BillingInterface, BlueprintsInterface, BudgetsInterface, CloudDatastoresInterface, CloudFoldersInterface, CloudPoliciesInterface, CloudResourcePoolsInterface, CloudsInterface, ClustersInterface, ContainersInterface, CustomInstanceTypesInterface, CypherInterface, DashboardInterface, DatastoresInterface, DeployInterface, DocInterface, EnvironmentsInterface, ExecuteSchedulesInterface, ExecutionRequestInterface, FileCopyRequestInterface, ForgotPasswordInterface, GroupPoliciesInterface, GroupsInterface, GuidanceInterface, HealthInterface, ImageBuilderBootScriptsInterface, ImageBuilderImageBuildsInterface, ImageBuilderInterface, ImageBuilderPreseedScriptsInterface, InstanceTypesInterface, InstancesInterface, InvoiceLineItemsInterface, InvoicesInterface, JobsInterface, KeyPairsInterface, LibraryClusterLayoutsInterface, LibraryContainerScriptsInterface, LibraryContainerTemplatesInterface, LibraryContainerTypesInterface, LibraryContainerUpgradesInterface, LibraryInstanceTypesInterface, LibraryLayoutsInterface, LibrarySpecTemplateTypesInterface, LibrarySpecTemplatesInterface, LicenseInterface, LoadBalancersInterface, LogSettingsInterface, LogsInterface, MonitoringAlertsInterface, MonitoringAppsInterface, MonitoringChecksInterface, MonitoringContactsInterface, MonitoringGroupsInterface, MonitoringIncidentsInterface, MonitoringInterface, NetworkDomainRecordsInterface, NetworkDomainsInterface, NetworkGroupsInterface, NetworkPoolIpsInterface, NetworkPoolServersInterface, NetworkPoolsInterface, NetworkProxiesInterface, NetworkRoutersInterface, NetworkSecurityServersInterface, NetworkServicesInterface, NetworkSubnetsInterface, NetworkTypesInterface, NetworksInterface, OptionTypeListsInterface, OptionTypesInterface, OptionsInterface, PackagesInterface, PingInterface, PoliciesInterface, PowerSchedulesInterface, PriceSetsInterface, PricesInterface, ProcessesInterface, ProjectsInterface, ProvisionTypesInterface, ProvisioningLicenseTypesInterface, ProvisioningLicensesInterface, ProvisioningSettingsInterface, ReadInterface, ReportsInterface, RestInterface, RolesInterface, SearchInterface, SecurityGroupRulesInterface, SecurityGroupsInterface, ServerTypesInterface, ServersInterface, ServiceCatalogInterface, ServicePlansInterface, SetupInterface, StorageProvidersInterface, SubnetTypesInterface, SubnetsInterface, TaskSetsInterface, TasksInterface, UsageInterface, UserGroupsInterface, UserSettingsInterface, UserSourcesInterface, UsersInterface, VdiInterface, VirtualImagesInterface, WhitelabelSettingsInterface, WhoamiInterface, WikiInterface

Constant Summary collapse

CLIENT_ID =
'morph-cli'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_token, refresh_token = nil, expires_in = nil, base_url = nil, verify_ssl = true, options = {}) ⇒ APIClient

Initialize a new APIClient client = APIClient.new(url:"https://morpheus.yourcompany.com", verify_ssl:false) This old method signature is being deprecated:

client = APIClient.new(access_token, refresh_token, expires_in, base_url, verify_ssl, options={})

def initialize(attrs={}, options={})



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/morpheus/api/api_client.rb', line 16

def initialize(access_token, refresh_token=nil,expires_in = nil, base_url=nil, verify_ssl=true, options={})
  self.client_id = CLIENT_ID
  attrs = {}
  if access_token.is_a?(Hash)
    attrs = access_token.clone()
    access_token = attrs[:access_token]
    refresh_token = attrs[:refresh_token]
    base_url = attrs[:url] || attrs[:base_url]
    expires_in = attrs[:expires_in]
    verify_ssl = attrs.key?(:verify_ssl) ? attrs[:verify_ssl] : true
    self.client_id = attrs[:client_id] ? attrs[:client_id] : CLIENT_ID
    if attrs[:client_id]
      self.client_id = attrs[:client_id]
    end
    options = refresh_token.is_a?(Hash) ? refresh_token.clone() : {}
  end
  @access_token = access_token
  @refresh_token = refresh_token
  @base_url = base_url
  if @base_url.to_s.empty?
    raise "#{self.class} initialized without a required option :url"
  end
  @base_url = @base_url.chomp("/")
  # todo: validate URI
  if expires_in != nil
    @expires_at = Time.now + expires_in
  end
  set_ssl_verification_enabled(verify_ssl)
  setopts(options)
end

Instance Attribute Details

#client_id ⇒ Object

Returns the value of attribute client_id.



9
10
11
# File 'lib/morpheus/api/api_client.rb', line 9

def client_id
  @client_id
end

Instance Method Details

#account_groups ⇒ Object



383
384
385
# File 'lib/morpheus/api/api_client.rb', line 383

def 
  Morpheus::AccountGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#accounts ⇒ Object



515
516
517
# File 'lib/morpheus/api/api_client.rb', line 515

def accounts
  Morpheus::AccountsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#activity ⇒ Object



371
372
373
# File 'lib/morpheus/api/api_client.rb', line 371

def activity
  Morpheus::ActivityInterface.new(common_interface_options).setopts(@options)
end

#appliance_settings ⇒ Object



415
416
417
# File 'lib/morpheus/api/api_client.rb', line 415

def appliance_settings
  Morpheus::ApplianceSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#approvals ⇒ Object



519
520
521
# File 'lib/morpheus/api/api_client.rb', line 519

def approvals
  Morpheus::ApprovalsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#apps ⇒ Object



487
488
489
# File 'lib/morpheus/api/api_client.rb', line 487

def apps
  Morpheus::AppsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#archive_buckets ⇒ Object



657
658
659
# File 'lib/morpheus/api/api_client.rb', line 657

def archive_buckets
  Morpheus::ArchiveBucketsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#archive_files ⇒ Object



661
662
663
# File 'lib/morpheus/api/api_client.rb', line 661

def archive_files
  Morpheus::ArchiveFilesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#auth ⇒ Object



346
347
348
349
# File 'lib/morpheus/api/api_client.rb', line 346

def auth
  # Morpheus::AuthInterface.new(common_interface_options).setopts(@options)
  Morpheus::AuthInterface.new({url: @base_url, client_id: @client_id}).setopts(@options)
end

#authorization_required? ⇒ Boolean

Authorization is required, except for a couple commands like Ping and Setup

Returns:

  • (Boolean)


91
92
93
# File 'lib/morpheus/api/api_client.rb', line 91

def authorization_required?
  true
end

#backup_jobs ⇒ Object



785
786
787
# File 'lib/morpheus/api/api_client.rb', line 785

def backup_jobs
  Morpheus::BackupJobsInterface.new(common_interface_options).setopts(@options)
end

#backup_settings ⇒ Object



741
742
743
# File 'lib/morpheus/api/api_client.rb', line 741

def backup_settings
  Morpheus::BackupSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#backups ⇒ Object



781
782
783
# File 'lib/morpheus/api/api_client.rb', line 781

def backups
  Morpheus::BackupsInterface.new(common_interface_options).setopts(@options)
end

#billing ⇒ Object



801
802
803
# File 'lib/morpheus/api/api_client.rb', line 801

def billing
  Morpheus::BillingInterface.new(common_interface_options).setopts(@options)
end

#blueprints ⇒ Object



491
492
493
# File 'lib/morpheus/api/api_client.rb', line 491

def blueprints
  Morpheus::BlueprintsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#budgets ⇒ Object



757
758
759
# File 'lib/morpheus/api/api_client.rb', line 757

def budgets
  Morpheus::BudgetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#catalog ⇒ Object



793
794
795
# File 'lib/morpheus/api/api_client.rb', line 793

def catalog
  Morpheus::ServiceCatalogInterface.new(common_interface_options).setopts(@options)
end

#catalog_item_types ⇒ Object



789
790
791
# File 'lib/morpheus/api/api_client.rb', line 789

def catalog_item_types
  Morpheus::CatalogItemTypesInterface.new(common_interface_options).setopts(@options)
end

#certificate_types ⇒ Object



551
552
553
# File 'lib/morpheus/api/api_client.rb', line 551

def certificate_types
  Morpheus::CertificateTypesInterface.new(common_interface_options).setopts(@options)
end

#certificates ⇒ Object



547
548
549
# File 'lib/morpheus/api/api_client.rb', line 547

def certificates
  Morpheus::CertificatesInterface.new(common_interface_options).setopts(@options)
end

#cloud_datastores ⇒ Object



391
392
393
# File 'lib/morpheus/api/api_client.rb', line 391

def cloud_datastores
  Morpheus::CloudDatastoresInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#cloud_folders ⇒ Object



399
400
401
# File 'lib/morpheus/api/api_client.rb', line 399

def cloud_folders
  Morpheus::CloudFoldersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#cloud_policies ⇒ Object



597
598
599
# File 'lib/morpheus/api/api_client.rb', line 597

def cloud_policies
  Morpheus::CloudPoliciesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#cloud_resource_pools ⇒ Object



395
396
397
# File 'lib/morpheus/api/api_client.rb', line 395

def cloud_resource_pools
  Morpheus::CloudResourcePoolsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#clouds ⇒ Object



387
388
389
# File 'lib/morpheus/api/api_client.rb', line 387

def clouds
  Morpheus::CloudsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#clusters ⇒ Object



511
512
513
# File 'lib/morpheus/api/api_client.rb', line 511

def clusters
  Morpheus::ClustersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#common_interface_options ⇒ Object



324
325
326
327
328
329
330
331
332
# File 'lib/morpheus/api/api_client.rb', line 324

def common_interface_options
  {
    url: @base_url, 
    access_token: @access_token, 
    refresh_token: @refresh_token, 
    expires_at: @expires_at, 
    client_id: @client_id
  }
end

#containers ⇒ Object



431
432
433
# File 'lib/morpheus/api/api_client.rb', line 431

def containers
  Morpheus::ContainersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#cypher ⇒ Object



713
714
715
# File 'lib/morpheus/api/api_client.rb', line 713

def cypher
  Morpheus::CypherInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#dashboard ⇒ Object



367
368
369
# File 'lib/morpheus/api/api_client.rb', line 367

def dashboard
  Morpheus::DashboardInterface.new(common_interface_options).setopts(@options)
end

#datastores ⇒ Object



403
404
405
# File 'lib/morpheus/api/api_client.rb', line 403

def datastores
  Morpheus::DatastoresInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#default_content_type ⇒ Object

set this in your interface, eg. to 'application/json' or let it it default to json when payload is present.



78
79
80
# File 'lib/morpheus/api/api_client.rb', line 78

def default_content_type
  nil
end

#default_timeout ⇒ Object

set default seconds for interface to timeout after or let it use system default? none, it should not timeout by default.. I think execute() may use 30 seconds for get by default. and it should remove timeout when method is post, put, or delete



86
87
88
# File 'lib/morpheus/api/api_client.rb', line 86

def default_timeout
  nil
end

#deploy ⇒ Object



495
496
497
# File 'lib/morpheus/api/api_client.rb', line 495

def deploy
  Morpheus::DeployInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#deployments ⇒ Object



499
500
501
# File 'lib/morpheus/api/api_client.rb', line 499

def deployments
  Morpheus::DeploymentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#doc ⇒ Object



334
335
336
# File 'lib/morpheus/api/api_client.rb', line 334

def doc
  Morpheus::DocInterface.new(common_interface_options).setopts(@options)
end

#dry ⇒ Object



64
65
66
# File 'lib/morpheus/api/api_client.rb', line 64

def dry()
  dry_run(true)
end

#dry_run(val = true) ⇒ Object



59
60
61
62
# File 'lib/morpheus/api/api_client.rb', line 59

def dry_run(val=true)
  @dry_run = !!val
  self
end

#environments ⇒ Object



737
738
739
# File 'lib/morpheus/api/api_client.rb', line 737

def environments
  Morpheus::EnvironmentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#execute(opts, options = {}) ⇒ Object

Execute an HTTP request with this client. opts - Hash of options for HTTP Request. :url - The full url :method - The default method is :get (GET) :headers - Hash of headers to include in the request. eg. => 'application/json'. :params is a special key for query parameters. :params - query parameters :payload - The body of the request. :timeout - A custom timeout in seconds for api requests. The default is 30. todo: separate timeout options options - Hash of common global options that commands parse. eg. :headers, :timeout, :dry_run, :curl, etc :headers - Extra headers to add. This expects a Hash like => 'application/json'. :timeout - A custom timeout in seconds for api requests. The default is 30. todo: separate timeout options



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/morpheus/api/api_client.rb', line 148

def execute(opts, options={})
  # Morpheus::Logging::DarkPrinter.puts "Morpheus::RestClient.execute(#{opts})" if Morpheus::Logging.debug?
  # ok, always prepend @base_url, let the caller specify it exactly or leave it off.
  # this allows the Interface definition be lazy and not specify the base_url in every call to execute()
    # it will be used though...
  if opts[:url]
    if !opts[:url].include?(@base_url)
      opts[:url] = "#{@base_url}#{opts[:url]}"
    end
  end
  # merge in common global @options
  if @options
    options = options.merge(@options)
  else
    options = options.clone
  end

  # determine HTTP method
  if opts[:method].nil?
    opts[:method] = :get
  else
    # convert to lowercase Symbol like :get, :post, :put, or :delete
    opts[:method] = opts[:method].to_s.downcase.to_sym
  end
  
  # could validate method here...

  # apply default headers
  opts[:headers] ||= {}

  is_multipart = (opts[:payload].is_a?(Hash) && opts[:payload][:multipart] == true)

  # Authorization: apply our access token
  if authorization_required?
    if @access_token
      if opts[:headers][:authorization].nil? && opts[:headers]['Authorization'].nil?
        opts[:headers][:authorization] = "Bearer #{@access_token}"
      else
        # authorization header has already been set.
      end
    end
  end

  # POST and PUT requests default Content-Type is application/json
  # set Content-Type or pass :form_data => true if you want application/x-www-form-urlencoded
  # or use opts[:payload][:multipart] = true if you need multipart/form-data
  if opts[:method] == :post || opts[:method] == :put
    if opts[:headers]['Content-Type'].nil? && opts[:payload] && is_multipart != true && opts[:form_data] != true
      opts[:headers]['Content-Type'] = (default_content_type || 'application/json')
    end

    # Auto encode payload as JSON, just to be nice
    if opts[:headers]['Content-Type'] == 'application/json' && !opts[:payload].is_a?(String)
      opts[:payload] = opts[:payload].to_json
    end

  end

  # always use custom timeout eg. from --timeout option
  # or use default_timeout for GET requests only.
  if opts[:timeout].nil?
    if options[:timeout]
      opts[:timeout] = options[:timeout].to_f
    elsif default_timeout && opts[:method] == :get
      opts[:timeout] = default_timeout.to_f
    end
  end

  # add extra headers, eg. from --header option
  # headers should be a Hash and not an Array, dont make me split you here!
  if options[:headers]
    opts[:headers] = opts[:headers].merge(options[:headers])
  end

  # this is confusing, but RestClient expects :params inside the headers...?
  # move/copy params to headers.params for simplification.
  # remove this if issues arise
  # if opts[:params] && (opts[:headers][:params].nil? || opts[:headers][:params].empty?)
  #   opts[:headers][:params] = opts.delete(:params) # .delete(:params) maybe?
  # end

  # :command_options for these
  # if options[:curl]
  #   opts[:curl] = options[:curl]
  # end
  # if options.key?(:pretty_json)
  #   opts[:pretty_json] = options[:pretty_json]
  # end
  # if options.key?(:scrub)
  #   opts[:scrub] = options[:scrub]
  # end

  # @verify_ssl is not used atm
  # todo: finish this and use it instead of the global variable RestClient.ssl_verification_enabled?
  # gotta clean up all APIClient subclasses new() methods to support this
  # the CliCommand subclasses should be changed to @users_interface = @api_client.users
  # also.. Credentials.new()
  if @verify_ssl == false
    opts[:verify_ssl] = OpenSSL::SSL::VERIFY_NONE
  end

  if @dry_run
    # JD: could return a Request object instead...
    # print_dry_run needs options somehow...
    opts[:command_options] = options # trash this..we got @options with setopts now
    return opts
  end

  # uhh can't use LIST at the moment
  # fix it!
  # if opts[:method] == :list
  #   opts[:method]
  # end

  # Morpheus::Logging::DarkPrinter.puts "Morpheus::RestClient.execute(#{opts})" if Morpheus::Logging.debug?
  # instead, using ::RestClient.log = STDOUT 
  response = Morpheus::RestClient.execute(opts)
  if opts[:parse_json] != false && options[:parse_json] != false
    return JSON.parse(response.to_s)
  else
    return response
  end
end

#execute_schedules ⇒ Object



571
572
573
# File 'lib/morpheus/api/api_client.rb', line 571

def execute_schedules
  Morpheus::ExecuteSchedulesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#execution_request ⇒ Object



721
722
723
# File 'lib/morpheus/api/api_client.rb', line 721

def execution_request
  Morpheus::ExecutionRequestInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#file_copy_request ⇒ Object



725
726
727
# File 'lib/morpheus/api/api_client.rb', line 725

def file_copy_request
  Morpheus::FileCopyRequestInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#forgot ⇒ Object



351
352
353
# File 'lib/morpheus/api/api_client.rb', line 351

def forgot
  Morpheus::ForgotPasswordInterface.new(common_interface_options).setopts(@options)
end

#group_policies ⇒ Object



593
594
595
# File 'lib/morpheus/api/api_client.rb', line 593

def group_policies
  Morpheus::GroupPoliciesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#groups ⇒ Object



379
380
381
# File 'lib/morpheus/api/api_client.rb', line 379

def groups
  Morpheus::GroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#guidance ⇒ Object



773
774
775
# File 'lib/morpheus/api/api_client.rb', line 773

def guidance
  Morpheus::GuidanceInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#health ⇒ Object



761
762
763
# File 'lib/morpheus/api/api_client.rb', line 761

def health
  Morpheus::HealthInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#image_builder ⇒ Object



665
666
667
# File 'lib/morpheus/api/api_client.rb', line 665

def image_builder
  Morpheus::ImageBuilderInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#inspect ⇒ Object



55
56
57
# File 'lib/morpheus/api/api_client.rb', line 55

def inspect
  to_s
end

#instance_types ⇒ Object



435
436
437
# File 'lib/morpheus/api/api_client.rb', line 435

def instance_types
  Morpheus::InstanceTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#instances ⇒ Object



411
412
413
# File 'lib/morpheus/api/api_client.rb', line 411

def instances
  Morpheus::InstancesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#integration_types ⇒ Object



443
444
445
# File 'lib/morpheus/api/api_client.rb', line 443

def integration_types
  Morpheus::IntegrationTypesInterface.new(common_interface_options).setopts(@options)
end

#integrations ⇒ Object



439
440
441
# File 'lib/morpheus/api/api_client.rb', line 439

def integrations
  Morpheus::IntegrationsInterface.new(common_interface_options).setopts(@options)
end

#invoice_line_items ⇒ Object



769
770
771
# File 'lib/morpheus/api/api_client.rb', line 769

def invoice_line_items
  Morpheus::InvoiceLineItemsInterface.new(common_interface_options).setopts(@options)
end

#invoices ⇒ Object



765
766
767
# File 'lib/morpheus/api/api_client.rb', line 765

def invoices
  Morpheus::InvoicesInterface.new(common_interface_options).setopts(@options)
end

#jobs ⇒ Object



447
448
449
# File 'lib/morpheus/api/api_client.rb', line 447

def jobs
  Morpheus::JobsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#key_pairs ⇒ Object



543
544
545
# File 'lib/morpheus/api/api_client.rb', line 543

def key_pairs
  Morpheus::KeyPairsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_cluster_layouts ⇒ Object



697
698
699
# File 'lib/morpheus/api/api_client.rb', line 697

def library_cluster_layouts
  Morpheus::LibraryClusterLayoutsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_container_scripts ⇒ Object



689
690
691
# File 'lib/morpheus/api/api_client.rb', line 689

def library_container_scripts
  Morpheus::LibraryContainerScriptsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_container_templates ⇒ Object



693
694
695
# File 'lib/morpheus/api/api_client.rb', line 693

def library_container_templates
  Morpheus::LibraryContainerTemplatesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_container_types ⇒ Object



685
686
687
# File 'lib/morpheus/api/api_client.rb', line 685

def library_container_types
  Morpheus::LibraryContainerTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_container_upgrades ⇒ Object



681
682
683
# File 'lib/morpheus/api/api_client.rb', line 681

def library_container_upgrades
  Morpheus::LibraryContainerUpgradesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_instance_types ⇒ Object



673
674
675
# File 'lib/morpheus/api/api_client.rb', line 673

def library_instance_types
  Morpheus::LibraryInstanceTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_layouts ⇒ Object



677
678
679
# File 'lib/morpheus/api/api_client.rb', line 677

def library_layouts
  Morpheus::LibraryLayoutsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_spec_template_types ⇒ Object



705
706
707
# File 'lib/morpheus/api/api_client.rb', line 705

def library_spec_template_types
  Morpheus::LibrarySpecTemplateTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_spec_templates ⇒ Object



701
702
703
# File 'lib/morpheus/api/api_client.rb', line 701

def library_spec_templates
  Morpheus::LibrarySpecTemplatesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#license ⇒ Object



555
556
557
# File 'lib/morpheus/api/api_client.rb', line 555

def license
  Morpheus::LicenseInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#load_balancers ⇒ Object



471
472
473
# File 'lib/morpheus/api/api_client.rb', line 471

def load_balancers
  Morpheus::LoadBalancersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#log_settings ⇒ Object



745
746
747
# File 'lib/morpheus/api/api_client.rb', line 745

def log_settings
  Morpheus::LogSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#logged_in? ⇒ Boolean

Returns:

  • (Boolean)


272
273
274
# File 'lib/morpheus/api/api_client.rb', line 272

def logged_in?
  !!@access_token
end

#login(username, password, use_client_id = nil) ⇒ Object



284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/morpheus/api/api_client.rb', line 284

def (username, password, use_client_id=nil)
  if use_client_id
    self.client_id = use_client_id
  end
  @access_token, @refresh_token, @expires_at = nil, nil, nil
  response = auth.(username, password, self.client_id)
  @access_token = response['access_token']
  @refresh_token = response['refresh_token']
  if response['expires_in'] != nil
    @expires_at = Time.now + response['expires_in']
  end
  # return response
  return self
end

#logout ⇒ Object



317
318
319
320
321
322
# File 'lib/morpheus/api/api_client.rb', line 317

def logout
  @access_token = nil
  @refresh_token = nil
  @expires_at = nil
  return self
end

#logs ⇒ Object



535
536
537
# File 'lib/morpheus/api/api_client.rb', line 535

def logs
  Morpheus::LogsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#monitoring ⇒ Object



575
576
577
# File 'lib/morpheus/api/api_client.rb', line 575

def monitoring
  Morpheus::MonitoringInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_domain_records ⇒ Object



649
650
651
# File 'lib/morpheus/api/api_client.rb', line 649

def network_domain_records
  Morpheus::NetworkDomainRecordsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_domains ⇒ Object



645
646
647
# File 'lib/morpheus/api/api_client.rb', line 645

def network_domains
  Morpheus::NetworkDomainsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_groups ⇒ Object



617
618
619
# File 'lib/morpheus/api/api_client.rb', line 617

def network_groups
  Morpheus::NetworkGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_pool_ips ⇒ Object



625
626
627
# File 'lib/morpheus/api/api_client.rb', line 625

def network_pool_ips
  Morpheus::NetworkPoolIpsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_pool_servers ⇒ Object



641
642
643
# File 'lib/morpheus/api/api_client.rb', line 641

def network_pool_servers
  Morpheus::NetworkPoolServersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_pools ⇒ Object



621
622
623
# File 'lib/morpheus/api/api_client.rb', line 621

def network_pools
  Morpheus::NetworkPoolsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_proxies ⇒ Object



653
654
655
# File 'lib/morpheus/api/api_client.rb', line 653

def network_proxies
  Morpheus::NetworkProxiesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_routers ⇒ Object



629
630
631
# File 'lib/morpheus/api/api_client.rb', line 629

def network_routers
  Morpheus::NetworkRoutersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_security_servers ⇒ Object



637
638
639
# File 'lib/morpheus/api/api_client.rb', line 637

def network_security_servers
  Morpheus::NetworkSecurityServersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_services ⇒ Object



633
634
635
# File 'lib/morpheus/api/api_client.rb', line 633

def network_services
  Morpheus::NetworkServicesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_types ⇒ Object



605
606
607
# File 'lib/morpheus/api/api_client.rb', line 605

def network_types
  Morpheus::NetworkTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#networks ⇒ Object



601
602
603
# File 'lib/morpheus/api/api_client.rb', line 601

def networks
  Morpheus::NetworksInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#old_cypher ⇒ Object



717
718
719
# File 'lib/morpheus/api/api_client.rb', line 717

def old_cypher
  Morpheus::OldCypherInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#option_type_lists ⇒ Object



563
564
565
# File 'lib/morpheus/api/api_client.rb', line 563

def option_type_lists
  Morpheus::OptionTypeListsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#option_types ⇒ Object



559
560
561
# File 'lib/morpheus/api/api_client.rb', line 559

def option_types
  Morpheus::OptionTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#options ⇒ Object



375
376
377
# File 'lib/morpheus/api/api_client.rb', line 375

def options
  Morpheus::OptionsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#packages ⇒ Object



709
710
711
# File 'lib/morpheus/api/api_client.rb', line 709

def packages
  Morpheus::PackagesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#ping ⇒ Object



338
339
340
# File 'lib/morpheus/api/api_client.rb', line 338

def ping
  Morpheus::PingInterface.new(common_interface_options).setopts(@options)
end

#policies ⇒ Object

def incidents

Morpheus::MonitoringIncidentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)

monitoring.incidents end



589
590
591
# File 'lib/morpheus/api/api_client.rb', line 589

def policies
  Morpheus::PoliciesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#power_schedules ⇒ Object



567
568
569
# File 'lib/morpheus/api/api_client.rb', line 567

def power_schedules
  Morpheus::PowerSchedulesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#price_sets ⇒ Object



463
464
465
# File 'lib/morpheus/api/api_client.rb', line 463

def price_sets
  Morpheus::PriceSetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#prices ⇒ Object



467
468
469
# File 'lib/morpheus/api/api_client.rb', line 467

def prices
  Morpheus::PricesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#processes ⇒ Object



729
730
731
# File 'lib/morpheus/api/api_client.rb', line 729

def processes
  Morpheus::ProcessesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#projects ⇒ Object



777
778
779
# File 'lib/morpheus/api/api_client.rb', line 777

def projects
  Morpheus::ProjectsInterface.new(common_interface_options).setopts(@options)
end

#provision_types ⇒ Object



455
456
457
# File 'lib/morpheus/api/api_client.rb', line 455

def provision_types
  Morpheus::ProvisionTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#provisioning_license_types ⇒ Object



427
428
429
# File 'lib/morpheus/api/api_client.rb', line 427

def provisioning_license_types
  Morpheus::ProvisioningLicenseTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#provisioning_licenses ⇒ Object



423
424
425
# File 'lib/morpheus/api/api_client.rb', line 423

def provisioning_licenses
  Morpheus::ProvisioningLicensesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#provisioning_settings ⇒ Object



419
420
421
# File 'lib/morpheus/api/api_client.rb', line 419

def provisioning_settings
  Morpheus::ProvisioningSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#reports ⇒ Object



733
734
735
# File 'lib/morpheus/api/api_client.rb', line 733

def reports
  Morpheus::ReportsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#roles ⇒ Object



539
540
541
# File 'lib/morpheus/api/api_client.rb', line 539

def roles
  Morpheus::RolesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#search ⇒ Object



359
360
361
# File 'lib/morpheus/api/api_client.rb', line 359

def search
  Morpheus::SearchInterface.new(common_interface_options).setopts(@options)
end

#security_group_rules ⇒ Object



507
508
509
# File 'lib/morpheus/api/api_client.rb', line 507

def security_group_rules
  Morpheus::SecurityGroupRulesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#security_groups ⇒ Object



503
504
505
# File 'lib/morpheus/api/api_client.rb', line 503

def security_groups
  Morpheus::SecurityGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#server_types ⇒ Object



451
452
453
# File 'lib/morpheus/api/api_client.rb', line 451

def server_types
  Morpheus::ServerTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#servers ⇒ Object



407
408
409
# File 'lib/morpheus/api/api_client.rb', line 407

def servers
  Morpheus::ServersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#service_plans ⇒ Object



459
460
461
# File 'lib/morpheus/api/api_client.rb', line 459

def service_plans
  Morpheus::ServicePlansInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#set_ssl_verification_enabled(val) ⇒ Object



72
73
74
# File 'lib/morpheus/api/api_client.rb', line 72

def set_ssl_verification_enabled(val)
  @verify_ssl = !!val
end

#setopts(new_options) ⇒ Object Also known as: set_options

set common global @options for use with all requests meant for inline use just like dry(), set_options(dry_run:true) can be used in place of dry() Example: Prints curl -XGET .../whoami -H "Bearer" instead of actually request APIClient.new(token).whoami.setopts(curl:true).get({})

Parameters:

  • opts (Hash) —

    globally supported options like :dry_run, :json, :curl, :headers, :timeout, etc



111
112
113
114
115
116
117
# File 'lib/morpheus/api/api_client.rb', line 111

def setopts(new_options)
  @options = new_options
  if @options[:dry_run]
    dry_run(true)
  end
  self
end

#setup ⇒ Object



342
343
344
# File 'lib/morpheus/api/api_client.rb', line 342

def setup
  Morpheus::SetupInterface.new(common_interface_options).setopts(@options)
end

#ssl_verification_enabled? ⇒ Boolean

Returns:

  • (Boolean)


68
69
70
# File 'lib/morpheus/api/api_client.rb', line 68

def ssl_verification_enabled?
  @verify_ssl
end

#storage_providers ⇒ Object



669
670
671
# File 'lib/morpheus/api/api_client.rb', line 669

def storage_providers
  Morpheus::StorageProvidersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#subnet_types ⇒ Object



613
614
615
# File 'lib/morpheus/api/api_client.rb', line 613

def subnet_types
  Morpheus::SubnetTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#subnets ⇒ Object



609
610
611
# File 'lib/morpheus/api/api_client.rb', line 609

def subnets
  Morpheus::SubnetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#task_sets ⇒ Object



479
480
481
# File 'lib/morpheus/api/api_client.rb', line 479

def task_sets
  Morpheus::TaskSetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#tasks ⇒ Object



475
476
477
# File 'lib/morpheus/api/api_client.rb', line 475

def tasks
  Morpheus::TasksInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#to_s ⇒ Object



51
52
53
# File 'lib/morpheus/api/api_client.rb', line 51

def to_s
  "<##{self.class}:#{self.object_id.to_s(8)} @url=#{@base_url} @verify_ssl=#{@verify_ssl} @access_token=#{@access_token ? '************' : nil} @refresh_token=#{@access_token ? '************' : nil} @expires_at=#{@expires_at} @client_id=#{@client_id} @options=#{@options}>"
end

#url ⇒ Object



47
48
49
# File 'lib/morpheus/api/api_client.rb', line 47

def url
  @base_url
end

#usage ⇒ Object



797
798
799
# File 'lib/morpheus/api/api_client.rb', line 797

def usage
  Morpheus::UsageInterface.new(common_interface_options).setopts(@options)
end

#use_refresh_token(t = nil) ⇒ Object



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/morpheus/api/api_client.rb', line 299

def use_refresh_token(t=nil)
  if t.nil?
    t = @refresh_token
  end
  if t.nil?
    raise "#{self.class} does not currently have a refresh_token"
  end
  response = auth.use_refresh_token(t, self.client_id)
  @access_token = response['access_token']
  @refresh_token = response['refresh_token']
  if response['expires_in'] != nil
    @expires_at = Time.now + response['expires_in']
  end
  @access_token = response['access_token']
  # return response
  return self
end

#user_groups ⇒ Object



527
528
529
# File 'lib/morpheus/api/api_client.rb', line 527

def user_groups
  Morpheus::UserGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#user_settings ⇒ Object



363
364
365
# File 'lib/morpheus/api/api_client.rb', line 363

def 
  Morpheus::UserSettingsInterface.new(common_interface_options).setopts(@options)
end

#user_sources ⇒ Object



531
532
533
# File 'lib/morpheus/api/api_client.rb', line 531

def user_sources
  Morpheus::UserSourcesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#users ⇒ Object



523
524
525
# File 'lib/morpheus/api/api_client.rb', line 523

def users
  Morpheus::UsersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#vdi ⇒ Object



805
806
807
# File 'lib/morpheus/api/api_client.rb', line 805

def vdi
  Morpheus::VdiInterface.new(common_interface_options).setopts(@options)
end

#vdi_allocations ⇒ Object



813
814
815
# File 'lib/morpheus/api/api_client.rb', line 813

def vdi_allocations
  Morpheus::VdiAllocationsInterface.new(common_interface_options).setopts(@options)
end

#vdi_apps ⇒ Object



817
818
819
# File 'lib/morpheus/api/api_client.rb', line 817

def vdi_apps
  Morpheus::VdiAppsInterface.new(common_interface_options).setopts(@options)
end

#vdi_gateways ⇒ Object



821
822
823
# File 'lib/morpheus/api/api_client.rb', line 821

def vdi_gateways
  Morpheus::VdiGatewaysInterface.new(common_interface_options).setopts(@options)
end

#vdi_pools ⇒ Object



809
810
811
# File 'lib/morpheus/api/api_client.rb', line 809

def vdi_pools
  Morpheus::VdiPoolsInterface.new(common_interface_options).setopts(@options)
end

#virtual_images ⇒ Object



483
484
485
# File 'lib/morpheus/api/api_client.rb', line 483

def virtual_images
  Morpheus::VirtualImagesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#whitelabel_settings ⇒ Object



749
750
751
# File 'lib/morpheus/api/api_client.rb', line 749

def whitelabel_settings
  Morpheus::WhitelabelSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#whoami ⇒ Object



355
356
357
# File 'lib/morpheus/api/api_client.rb', line 355

def whoami
  Morpheus::WhoamiInterface.new(common_interface_options).setopts(@options)
end

#wiki ⇒ Object



753
754
755
# File 'lib/morpheus/api/api_client.rb', line 753

def wiki
  Morpheus::WikiInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#withopts(tmp_options, &block) ⇒ Object Also known as: with_options

with_options sets common global @options for the duration of the block only then returns the options to their prior values

Parameters:

  • opts (Hash) —

    globally supported options like :dry_run, :json, :curl, :headers, :timeout, etc

Returns:

  • result of block, usually the a result Hash from client.execute({})



123
124
125
126
127
128
129
130
131
132
# File 'lib/morpheus/api/api_client.rb', line 123

def withopts(tmp_options, &block)
  @_old_options = @options
  begin
    @options = tmp_options
    result = block.call()
  ensure
    @options = @_old_options
  end
  return result
end