Class: Morpheus::APIClient

Inherits:
Object
  • Object
show all
Defined in:
lib/morpheus/api/api_client.rb

Direct Known Subclasses

AccountGroupsInterface, AccountsInterface, ActivityInterface, ApplianceSettingsInterface, ApprovalsInterface, AppsInterface, ArchiveBucketsInterface, ArchiveFilesInterface, AuthInterface, BackupSettingsInterface, BillingInterface, BlueprintsInterface, BudgetsInterface, CloudDatastoresInterface, CloudFoldersInterface, CloudPoliciesInterface, CloudResourcePoolsInterface, CloudsInterface, ClustersInterface, ContainersInterface, CustomInstanceTypesInterface, CypherInterface, DashboardInterface, DatastoresInterface, DeployInterface, DocInterface, EnvironmentsInterface, ExecuteSchedulesInterface, ExecutionRequestInterface, FileCopyRequestInterface, ForgotPasswordInterface, GroupPoliciesInterface, GroupsInterface, GuidanceInterface, HealthInterface, ImageBuilderBootScriptsInterface, ImageBuilderImageBuildsInterface, ImageBuilderInterface, ImageBuilderPreseedScriptsInterface, InstanceTypesInterface, InstancesInterface, IntegrationsInterface, InvoiceLineItemsInterface, InvoicesInterface, JobsInterface, KeyPairsInterface, LibraryClusterLayoutsInterface, LibraryContainerScriptsInterface, LibraryContainerTemplatesInterface, LibraryContainerTypesInterface, LibraryContainerUpgradesInterface, LibraryInstanceTypesInterface, LibraryLayoutsInterface, LibrarySpecTemplateTypesInterface, LibrarySpecTemplatesInterface, LicenseInterface, LoadBalancersInterface, LogSettingsInterface, LogsInterface, MonitoringAlertsInterface, MonitoringAppsInterface, MonitoringChecksInterface, MonitoringContactsInterface, MonitoringGroupsInterface, MonitoringIncidentsInterface, MonitoringInterface, NetworkDomainRecordsInterface, NetworkDomainsInterface, NetworkGroupsInterface, NetworkPoolIpsInterface, NetworkPoolServersInterface, NetworkPoolsInterface, NetworkProxiesInterface, NetworkRoutersInterface, NetworkSecurityServersInterface, NetworkServicesInterface, NetworkSubnetsInterface, NetworkTypesInterface, NetworksInterface, OptionTypeListsInterface, OptionTypesInterface, OptionsInterface, PackagesInterface, PingInterface, PoliciesInterface, PowerSchedulesInterface, PriceSetsInterface, PricesInterface, ProcessesInterface, ProjectsInterface, ProvisionTypesInterface, ProvisioningLicenseTypesInterface, ProvisioningLicensesInterface, ProvisioningSettingsInterface, ReportsInterface, RestInterface, RolesInterface, SearchInterface, SecurityGroupRulesInterface, SecurityGroupsInterface, ServerTypesInterface, ServersInterface, ServiceCatalogInterface, ServicePlansInterface, SetupInterface, StorageProvidersInterface, SubnetTypesInterface, SubnetsInterface, TaskSetsInterface, TasksInterface, UsageInterface, UserGroupsInterface, UserSettingsInterface, UserSourcesInterface, UsersInterface, VirtualImagesInterface, WhitelabelSettingsInterface, WhoamiInterface, WikiInterface

Constant Summary collapse

CLIENT_ID =
'morph-cli'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(access_token, refresh_token = nil, expires_in = nil, base_url = nil, verify_ssl = true, options = {}) ⇒ APIClient

Initialize a new APIClient client = APIClient.new(url:"https://morpheus.yourcompany.com", verify_ssl:false) This old method signature is being deprecated:

client = APIClient.new(access_token, refresh_token, expires_in, base_url, verify_ssl, options={})

def initialize(attrs={}, options={})



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/morpheus/api/api_client.rb', line 16

def initialize(access_token, refresh_token=nil,expires_in = nil, base_url=nil, verify_ssl=true, options={})
  self.client_id = CLIENT_ID
  attrs = {}
  if access_token.is_a?(Hash)
    attrs = access_token.clone()
    access_token = attrs[:access_token]
    refresh_token = attrs[:refresh_token]
    base_url = attrs[:url] || attrs[:base_url]
    expires_in = attrs[:expires_in]
    verify_ssl = attrs.key?(:verify_ssl) ? attrs[:verify_ssl] : true
    self.client_id = attrs[:client_id] ? attrs[:client_id] : CLIENT_ID
    if attrs[:client_id]
      self.client_id = attrs[:client_id]
    end
    options = refresh_token.is_a?(Hash) ? refresh_token.clone() : {}
  end
  @access_token = access_token
  @refresh_token = refresh_token
  @base_url = base_url
  if @base_url.to_s.empty?
    raise "#{self.class} initialized without a required option :url"
  end
  @base_url = @base_url.chomp("/")
  # todo: validate URI
  if expires_in != nil
    @expires_at = Time.now + expires_in
  end
  set_ssl_verification_enabled(verify_ssl)
  setopts(options)
end

Instance Attribute Details

#client_id ⇒ Object

Returns the value of attribute client_id.



9
10
11
# File 'lib/morpheus/api/api_client.rb', line 9

def client_id
  @client_id
end

Instance Method Details

#account_groups ⇒ Object



377
378
379
# File 'lib/morpheus/api/api_client.rb', line 377

def 
  Morpheus::AccountGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#accounts ⇒ Object



505
506
507
# File 'lib/morpheus/api/api_client.rb', line 505

def accounts
  Morpheus::AccountsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#activity ⇒ Object



365
366
367
# File 'lib/morpheus/api/api_client.rb', line 365

def activity
  Morpheus::ActivityInterface.new(common_interface_options).setopts(@options)
end

#appliance_settings ⇒ Object



409
410
411
# File 'lib/morpheus/api/api_client.rb', line 409

def appliance_settings
  Morpheus::ApplianceSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#approvals ⇒ Object



509
510
511
# File 'lib/morpheus/api/api_client.rb', line 509

def approvals
  Morpheus::ApprovalsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#apps ⇒ Object



477
478
479
# File 'lib/morpheus/api/api_client.rb', line 477

def apps
  Morpheus::AppsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#archive_buckets ⇒ Object



643
644
645
# File 'lib/morpheus/api/api_client.rb', line 643

def archive_buckets
  Morpheus::ArchiveBucketsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#archive_files ⇒ Object



647
648
649
# File 'lib/morpheus/api/api_client.rb', line 647

def archive_files
  Morpheus::ArchiveFilesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#auth ⇒ Object



340
341
342
343
# File 'lib/morpheus/api/api_client.rb', line 340

def auth
  # Morpheus::AuthInterface.new(common_interface_options).setopts(@options)
  Morpheus::AuthInterface.new({url: @base_url, client_id: @client_id}).setopts(@options)
end

#authorization_required? ⇒ Boolean

Authorization is required, except for a couple commands like Ping and Setup

Returns:

  • (Boolean)


91
92
93
# File 'lib/morpheus/api/api_client.rb', line 91

def authorization_required?
  true
end

#backup_jobs ⇒ Object



771
772
773
# File 'lib/morpheus/api/api_client.rb', line 771

def backup_jobs
  Morpheus::BackupJobsInterface.new(common_interface_options).setopts(@options)
end

#backup_settings ⇒ Object



727
728
729
# File 'lib/morpheus/api/api_client.rb', line 727

def backup_settings
  Morpheus::BackupSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#backups ⇒ Object



767
768
769
# File 'lib/morpheus/api/api_client.rb', line 767

def backups
  Morpheus::BackupsInterface.new(common_interface_options).setopts(@options)
end

#billing ⇒ Object



787
788
789
# File 'lib/morpheus/api/api_client.rb', line 787

def billing
  Morpheus::BillingInterface.new(common_interface_options).setopts(@options)
end

#blueprints ⇒ Object



481
482
483
# File 'lib/morpheus/api/api_client.rb', line 481

def blueprints
  Morpheus::BlueprintsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#budgets ⇒ Object



743
744
745
# File 'lib/morpheus/api/api_client.rb', line 743

def budgets
  Morpheus::BudgetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#catalog ⇒ Object



779
780
781
# File 'lib/morpheus/api/api_client.rb', line 779

def catalog
  Morpheus::ServiceCatalogInterface.new(common_interface_options).setopts(@options)
end

#catalog_item_types ⇒ Object



775
776
777
# File 'lib/morpheus/api/api_client.rb', line 775

def catalog_item_types
  Morpheus::CatalogItemTypesInterface.new(common_interface_options).setopts(@options)
end

#cloud_datastores ⇒ Object



385
386
387
# File 'lib/morpheus/api/api_client.rb', line 385

def cloud_datastores
  Morpheus::CloudDatastoresInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#cloud_folders ⇒ Object



393
394
395
# File 'lib/morpheus/api/api_client.rb', line 393

def cloud_folders
  Morpheus::CloudFoldersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#cloud_policies ⇒ Object



583
584
585
# File 'lib/morpheus/api/api_client.rb', line 583

def cloud_policies
  Morpheus::CloudPoliciesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#cloud_resource_pools ⇒ Object



389
390
391
# File 'lib/morpheus/api/api_client.rb', line 389

def cloud_resource_pools
  Morpheus::CloudResourcePoolsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#clouds ⇒ Object



381
382
383
# File 'lib/morpheus/api/api_client.rb', line 381

def clouds
  Morpheus::CloudsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#clusters ⇒ Object



501
502
503
# File 'lib/morpheus/api/api_client.rb', line 501

def clusters
  Morpheus::ClustersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#common_interface_options ⇒ Object



318
319
320
321
322
323
324
325
326
# File 'lib/morpheus/api/api_client.rb', line 318

def common_interface_options
  {
    url: @base_url, 
    access_token: @access_token, 
    refresh_token: @refresh_token, 
    expires_at: @expires_at, 
    client_id: @client_id
  }
end

#containers ⇒ Object



425
426
427
# File 'lib/morpheus/api/api_client.rb', line 425

def containers
  Morpheus::ContainersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#custom_instance_types ⇒ Object



541
542
543
# File 'lib/morpheus/api/api_client.rb', line 541

def custom_instance_types
  Morpheus::CustomInstanceTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#cypher ⇒ Object



699
700
701
# File 'lib/morpheus/api/api_client.rb', line 699

def cypher
  Morpheus::CypherInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#dashboard ⇒ Object



361
362
363
# File 'lib/morpheus/api/api_client.rb', line 361

def dashboard
  Morpheus::DashboardInterface.new(common_interface_options).setopts(@options)
end

#datastores ⇒ Object



397
398
399
# File 'lib/morpheus/api/api_client.rb', line 397

def datastores
  Morpheus::DatastoresInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#default_content_type ⇒ Object

set this in your interface, eg. to 'application/json' or let it it default to json when payload is present.



78
79
80
# File 'lib/morpheus/api/api_client.rb', line 78

def default_content_type
  nil
end

#default_timeout ⇒ Object

set default seconds for interface to timeout after or let it use system default? none, it should not timeout by default.. I think execute() may use 30 seconds for get by default. and it should remove timeout when method is post, put, or delete



86
87
88
# File 'lib/morpheus/api/api_client.rb', line 86

def default_timeout
  nil
end

#deploy ⇒ Object



485
486
487
# File 'lib/morpheus/api/api_client.rb', line 485

def deploy
  Morpheus::DeployInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#deployments ⇒ Object



489
490
491
# File 'lib/morpheus/api/api_client.rb', line 489

def deployments
  Morpheus::DeploymentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#doc ⇒ Object



328
329
330
# File 'lib/morpheus/api/api_client.rb', line 328

def doc
  Morpheus::DocInterface.new(common_interface_options).setopts(@options)
end

#dry ⇒ Object



64
65
66
# File 'lib/morpheus/api/api_client.rb', line 64

def dry()
  dry_run(true)
end

#dry_run(val = true) ⇒ Object



59
60
61
62
# File 'lib/morpheus/api/api_client.rb', line 59

def dry_run(val=true)
  @dry_run = !!val
  self
end

#environments ⇒ Object



723
724
725
# File 'lib/morpheus/api/api_client.rb', line 723

def environments
  Morpheus::EnvironmentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#execute(opts, options = {}) ⇒ Object

Execute an HTTP request with this client. opts - Hash of options for HTTP Request. :url - The full url :method - The default method is :get (GET) :headers - Hash of headers to include in the request. eg. => 'application/json'. :params is a special key for query parameters. :params - query parameters :payload - The body of the request. :timeout - A custom timeout in seconds for api requests. The default is 30. todo: separate timeout options options - Hash of common global options that commands parse. eg. :headers, :timeout, :dry_run, :curl, etc :headers - Extra headers to add. This expects a Hash like => 'application/json'. :timeout - A custom timeout in seconds for api requests. The default is 30. todo: separate timeout options



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/morpheus/api/api_client.rb', line 148

def execute(opts, options={})
  # ok, always prepend @base_url, let the caller specify it exactly or leave it off.
  # this allows the Interface definition be lazy and not specify the base_url in every call to execute()
    # it will be used though...
  if opts[:url]
    if !opts[:url].include?(@base_url)
      opts[:url] = "#{@base_url}#{opts[:url]}"
    end
  end
  # merge in common global @options
  if @options
    options = options.merge(@options)
  else
    options = options.clone
  end

  # determine HTTP method
  if opts[:method].nil?
    opts[:method] = :get
  else
    # convert to lowercase Symbol like :get, :post, :put, or :delete
    opts[:method] = opts[:method].to_s.downcase.to_sym
  end
  
  # could validate method here...

  # apply default headers
  opts[:headers] ||= {}

  is_multipart = (opts[:payload].is_a?(Hash) && opts[:payload][:multipart])

  # Authorization: apply our access token
  if authorization_required?
    if @access_token
      if opts[:headers][:authorization].nil? && opts[:headers]['Authorization'].nil?
        opts[:headers][:authorization] = "Bearer #{@access_token}"
      else
        # authorization header has already been set.
      end
    end
  end

  # Content-Type default is application/json
  if opts[:headers]['Content-Type'].nil? && opts[:payload] && is_multipart == false
    opts[:headers]['Content-Type'] = (default_content_type || 'application/json')
  end

  # this could be nice too..
  # if opts[:headers]['Content-Type'] == 'application/json' && opts[:payload].is_a?(Hash)
  #   opts[:payload] = opts[:payload].to_json
  # end

  # always use custom timeout eg. from --timeout option
  # or use default_timeout for GET requests only.
  if opts[:timeout].nil?
    if options[:timeout]
      opts[:timeout] = options[:timeout].to_f
    elsif default_timeout && opts[:method] == :get
      opts[:timeout] = default_timeout.to_f
    end
  end

  # add extra headers, eg. from --header option
  # headers should be a Hash and not an Array, dont make me split you here!
  if options[:headers]
    opts[:headers] = opts[:headers].merge(options[:headers])
  end

  # this is confusing, but RestClient expects :params inside the headers...?
  # move/copy params to headers.params for simplification.
  # remove this if issues arise
  # if opts[:params] && (opts[:headers][:params].nil? || opts[:headers][:params].empty?)
  #   opts[:headers][:params] = opts.delete(:params) # .delete(:params) maybe?
  # end

  # :command_options for these
  # if options[:curl]
  #   opts[:curl] = options[:curl]
  # end
  # if options.key?(:pretty_json)
  #   opts[:pretty_json] = options[:pretty_json]
  # end
  # if options.key?(:scrub)
  #   opts[:scrub] = options[:scrub]
  # end

  # @verify_ssl is not used atm
  # todo: finish this and use it instead of the global variable RestClient.ssl_verification_enabled?
  # gotta clean up all APIClient subclasses new() methods to support this
  # the CliCommand subclasses should be changed to @users_interface = @api_client.users
  # also.. Credentials.new()
  if @verify_ssl == false
    opts[:verify_ssl] = OpenSSL::SSL::VERIFY_NONE
  end

  if @dry_run
    # JD: could return a Request object instead...
    # print_dry_run needs options somehow...
    opts[:command_options] = options # trash this..we got @options with setopts now
    return opts
  end

  # uhh can't use LIST at the moment
  # fix it!
  # if opts[:method] == :list
  #   opts[:method]
  # end

  # Morpheus::Logging::DarkPrinter.puts "Morpheus::RestClient.execute(#{opts})" if Morpheus::Logging.debug?
  # instead, using ::RestClient.log = STDOUT 
  response = Morpheus::RestClient.execute(opts)
  if opts[:parse_json] != false && options[:parse_json] != false
    return JSON.parse(response.to_s)
  else
    return response
  end
end

#execute_schedules ⇒ Object



557
558
559
# File 'lib/morpheus/api/api_client.rb', line 557

def execute_schedules
  Morpheus::ExecuteSchedulesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#execution_request ⇒ Object



707
708
709
# File 'lib/morpheus/api/api_client.rb', line 707

def execution_request
  Morpheus::ExecutionRequestInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#file_copy_request ⇒ Object



711
712
713
# File 'lib/morpheus/api/api_client.rb', line 711

def file_copy_request
  Morpheus::FileCopyRequestInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#forgot ⇒ Object



345
346
347
# File 'lib/morpheus/api/api_client.rb', line 345

def forgot
  Morpheus::ForgotPasswordInterface.new(common_interface_options).setopts(@options)
end

#group_policies ⇒ Object



579
580
581
# File 'lib/morpheus/api/api_client.rb', line 579

def group_policies
  Morpheus::GroupPoliciesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#groups ⇒ Object



373
374
375
# File 'lib/morpheus/api/api_client.rb', line 373

def groups
  Morpheus::GroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#guidance ⇒ Object



759
760
761
# File 'lib/morpheus/api/api_client.rb', line 759

def guidance
  Morpheus::GuidanceInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#health ⇒ Object



747
748
749
# File 'lib/morpheus/api/api_client.rb', line 747

def health
  Morpheus::HealthInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#image_builder ⇒ Object



651
652
653
# File 'lib/morpheus/api/api_client.rb', line 651

def image_builder
  Morpheus::ImageBuilderInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#inspect ⇒ Object



55
56
57
# File 'lib/morpheus/api/api_client.rb', line 55

def inspect
  to_s
end

#instance_types ⇒ Object



429
430
431
# File 'lib/morpheus/api/api_client.rb', line 429

def instance_types
  Morpheus::InstanceTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#instances ⇒ Object



405
406
407
# File 'lib/morpheus/api/api_client.rb', line 405

def instances
  Morpheus::InstancesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#integrations ⇒ Object



433
434
435
# File 'lib/morpheus/api/api_client.rb', line 433

def integrations
  Morpheus::IntegrationsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#invoice_line_items ⇒ Object



755
756
757
# File 'lib/morpheus/api/api_client.rb', line 755

def invoice_line_items
  Morpheus::InvoiceLineItemsInterface.new(common_interface_options).setopts(@options)
end

#invoices ⇒ Object



751
752
753
# File 'lib/morpheus/api/api_client.rb', line 751

def invoices
  Morpheus::InvoicesInterface.new(common_interface_options).setopts(@options)
end

#jobs ⇒ Object



437
438
439
# File 'lib/morpheus/api/api_client.rb', line 437

def jobs
  Morpheus::JobsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#key_pairs ⇒ Object



533
534
535
# File 'lib/morpheus/api/api_client.rb', line 533

def key_pairs
  Morpheus::KeyPairsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_cluster_layouts ⇒ Object



683
684
685
# File 'lib/morpheus/api/api_client.rb', line 683

def library_cluster_layouts
  Morpheus::LibraryClusterLayoutsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_container_scripts ⇒ Object



675
676
677
# File 'lib/morpheus/api/api_client.rb', line 675

def library_container_scripts
  Morpheus::LibraryContainerScriptsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_container_templates ⇒ Object



679
680
681
# File 'lib/morpheus/api/api_client.rb', line 679

def library_container_templates
  Morpheus::LibraryContainerTemplatesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_container_types ⇒ Object



671
672
673
# File 'lib/morpheus/api/api_client.rb', line 671

def library_container_types
  Morpheus::LibraryContainerTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_container_upgrades ⇒ Object



667
668
669
# File 'lib/morpheus/api/api_client.rb', line 667

def library_container_upgrades
  Morpheus::LibraryContainerUpgradesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_instance_types ⇒ Object



659
660
661
# File 'lib/morpheus/api/api_client.rb', line 659

def library_instance_types
  Morpheus::LibraryInstanceTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_layouts ⇒ Object



663
664
665
# File 'lib/morpheus/api/api_client.rb', line 663

def library_layouts
  Morpheus::LibraryLayoutsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_spec_template_types ⇒ Object



691
692
693
# File 'lib/morpheus/api/api_client.rb', line 691

def library_spec_template_types
  Morpheus::LibrarySpecTemplateTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#library_spec_templates ⇒ Object



687
688
689
# File 'lib/morpheus/api/api_client.rb', line 687

def library_spec_templates
  Morpheus::LibrarySpecTemplatesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#license ⇒ Object



537
538
539
# File 'lib/morpheus/api/api_client.rb', line 537

def license
  Morpheus::LicenseInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#load_balancers ⇒ Object



461
462
463
# File 'lib/morpheus/api/api_client.rb', line 461

def load_balancers
  Morpheus::LoadBalancersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#log_settings ⇒ Object



731
732
733
# File 'lib/morpheus/api/api_client.rb', line 731

def log_settings
  Morpheus::LogSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#logged_in? ⇒ Boolean

Returns:

  • (Boolean)


266
267
268
# File 'lib/morpheus/api/api_client.rb', line 266

def logged_in?
  !!@access_token
end

#login(username, password, use_client_id = nil) ⇒ Object



278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/morpheus/api/api_client.rb', line 278

def (username, password, use_client_id=nil)
  if use_client_id
    self.client_id = use_client_id
  end
  @access_token, @refresh_token, @expires_at = nil, nil, nil
  response = auth.(username, password, self.client_id)
  @access_token = response['access_token']
  @refresh_token = response['refresh_token']
  if response['expires_in'] != nil
    @expires_at = Time.now + response['expires_in']
  end
  # return response
  return self
end

#logout ⇒ Object



311
312
313
314
315
316
# File 'lib/morpheus/api/api_client.rb', line 311

def logout
  @access_token = nil
  @refresh_token = nil
  @expires_at = nil
  return self
end

#logs ⇒ Object



525
526
527
# File 'lib/morpheus/api/api_client.rb', line 525

def logs
  Morpheus::LogsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#monitoring ⇒ Object



561
562
563
# File 'lib/morpheus/api/api_client.rb', line 561

def monitoring
  Morpheus::MonitoringInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_domain_records ⇒ Object



635
636
637
# File 'lib/morpheus/api/api_client.rb', line 635

def network_domain_records
  Morpheus::NetworkDomainRecordsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_domains ⇒ Object



631
632
633
# File 'lib/morpheus/api/api_client.rb', line 631

def network_domains
  Morpheus::NetworkDomainsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_groups ⇒ Object



603
604
605
# File 'lib/morpheus/api/api_client.rb', line 603

def network_groups
  Morpheus::NetworkGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_pool_ips ⇒ Object



611
612
613
# File 'lib/morpheus/api/api_client.rb', line 611

def network_pool_ips
  Morpheus::NetworkPoolIpsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_pool_servers ⇒ Object



627
628
629
# File 'lib/morpheus/api/api_client.rb', line 627

def network_pool_servers
  Morpheus::NetworkPoolServersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_pools ⇒ Object



607
608
609
# File 'lib/morpheus/api/api_client.rb', line 607

def network_pools
  Morpheus::NetworkPoolsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_proxies ⇒ Object



639
640
641
# File 'lib/morpheus/api/api_client.rb', line 639

def network_proxies
  Morpheus::NetworkProxiesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_routers ⇒ Object



615
616
617
# File 'lib/morpheus/api/api_client.rb', line 615

def network_routers
  Morpheus::NetworkRoutersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_security_servers ⇒ Object



623
624
625
# File 'lib/morpheus/api/api_client.rb', line 623

def network_security_servers
  Morpheus::NetworkSecurityServersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_services ⇒ Object



619
620
621
# File 'lib/morpheus/api/api_client.rb', line 619

def network_services
  Morpheus::NetworkServicesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#network_types ⇒ Object



591
592
593
# File 'lib/morpheus/api/api_client.rb', line 591

def network_types
  Morpheus::NetworkTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#networks ⇒ Object



587
588
589
# File 'lib/morpheus/api/api_client.rb', line 587

def networks
  Morpheus::NetworksInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#old_cypher ⇒ Object



703
704
705
# File 'lib/morpheus/api/api_client.rb', line 703

def old_cypher
  Morpheus::OldCypherInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#option_type_lists ⇒ Object



549
550
551
# File 'lib/morpheus/api/api_client.rb', line 549

def option_type_lists
  Morpheus::OptionTypeListsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#option_types ⇒ Object



545
546
547
# File 'lib/morpheus/api/api_client.rb', line 545

def option_types
  Morpheus::OptionTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#options ⇒ Object



369
370
371
# File 'lib/morpheus/api/api_client.rb', line 369

def options
  Morpheus::OptionsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#packages ⇒ Object



695
696
697
# File 'lib/morpheus/api/api_client.rb', line 695

def packages
  Morpheus::PackagesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#ping ⇒ Object



332
333
334
# File 'lib/morpheus/api/api_client.rb', line 332

def ping
  Morpheus::PingInterface.new(common_interface_options).setopts(@options)
end

#policies ⇒ Object

def incidents

Morpheus::MonitoringIncidentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)

monitoring.incidents end



575
576
577
# File 'lib/morpheus/api/api_client.rb', line 575

def policies
  Morpheus::PoliciesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#power_schedules ⇒ Object



553
554
555
# File 'lib/morpheus/api/api_client.rb', line 553

def power_schedules
  Morpheus::PowerSchedulesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#price_sets ⇒ Object



453
454
455
# File 'lib/morpheus/api/api_client.rb', line 453

def price_sets
  Morpheus::PriceSetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#prices ⇒ Object



457
458
459
# File 'lib/morpheus/api/api_client.rb', line 457

def prices
  Morpheus::PricesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#processes ⇒ Object



715
716
717
# File 'lib/morpheus/api/api_client.rb', line 715

def processes
  Morpheus::ProcessesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#projects ⇒ Object



763
764
765
# File 'lib/morpheus/api/api_client.rb', line 763

def projects
  Morpheus::ProjectsInterface.new(common_interface_options).setopts(@options)
end

#provision_types ⇒ Object



445
446
447
# File 'lib/morpheus/api/api_client.rb', line 445

def provision_types
  Morpheus::ProvisionTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#provisioning_license_types ⇒ Object



421
422
423
# File 'lib/morpheus/api/api_client.rb', line 421

def provisioning_license_types
  Morpheus::ProvisioningLicenseTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#provisioning_licenses ⇒ Object



417
418
419
# File 'lib/morpheus/api/api_client.rb', line 417

def provisioning_licenses
  Morpheus::ProvisioningLicensesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#provisioning_settings ⇒ Object



413
414
415
# File 'lib/morpheus/api/api_client.rb', line 413

def provisioning_settings
  Morpheus::ProvisioningSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#reports ⇒ Object



719
720
721
# File 'lib/morpheus/api/api_client.rb', line 719

def reports
  Morpheus::ReportsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#roles ⇒ Object



529
530
531
# File 'lib/morpheus/api/api_client.rb', line 529

def roles
  Morpheus::RolesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#search ⇒ Object



353
354
355
# File 'lib/morpheus/api/api_client.rb', line 353

def search
  Morpheus::SearchInterface.new(common_interface_options).setopts(@options)
end

#security_group_rules ⇒ Object



497
498
499
# File 'lib/morpheus/api/api_client.rb', line 497

def security_group_rules
  Morpheus::SecurityGroupRulesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#security_groups ⇒ Object



493
494
495
# File 'lib/morpheus/api/api_client.rb', line 493

def security_groups
  Morpheus::SecurityGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#server_types ⇒ Object



441
442
443
# File 'lib/morpheus/api/api_client.rb', line 441

def server_types
  Morpheus::ServerTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#servers ⇒ Object



401
402
403
# File 'lib/morpheus/api/api_client.rb', line 401

def servers
  Morpheus::ServersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#service_plans ⇒ Object



449
450
451
# File 'lib/morpheus/api/api_client.rb', line 449

def service_plans
  Morpheus::ServicePlansInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#set_ssl_verification_enabled(val) ⇒ Object



72
73
74
# File 'lib/morpheus/api/api_client.rb', line 72

def set_ssl_verification_enabled(val)
  @verify_ssl = !!val
end

#setopts(new_options) ⇒ Object Also known as: set_options

set common global @options for use with all requests meant for inline use just like dry(), set_options(dry_run:true) can be used in place of dry() Example: Prints curl -XGET .../whoami -H "Bearer" instead of actually request APIClient.new(token).whoami.setopts(curl:true).get({})

Parameters:

  • opts (Hash) —

    globally supported options like :dry_run, :json, :curl, :headers, :timeout, etc



111
112
113
114
115
116
117
# File 'lib/morpheus/api/api_client.rb', line 111

def setopts(new_options)
  @options = new_options
  if @options[:dry_run]
    dry_run(true)
  end
  self
end

#setup ⇒ Object



336
337
338
# File 'lib/morpheus/api/api_client.rb', line 336

def setup
  Morpheus::SetupInterface.new(common_interface_options).setopts(@options)
end

#ssl_verification_enabled? ⇒ Boolean

Returns:

  • (Boolean)


68
69
70
# File 'lib/morpheus/api/api_client.rb', line 68

def ssl_verification_enabled?
  @verify_ssl
end

#storage_providers ⇒ Object



655
656
657
# File 'lib/morpheus/api/api_client.rb', line 655

def storage_providers
  Morpheus::StorageProvidersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#subnet_types ⇒ Object



599
600
601
# File 'lib/morpheus/api/api_client.rb', line 599

def subnet_types
  Morpheus::SubnetTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#subnets ⇒ Object



595
596
597
# File 'lib/morpheus/api/api_client.rb', line 595

def subnets
  Morpheus::SubnetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#task_sets ⇒ Object



469
470
471
# File 'lib/morpheus/api/api_client.rb', line 469

def task_sets
  Morpheus::TaskSetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#tasks ⇒ Object



465
466
467
# File 'lib/morpheus/api/api_client.rb', line 465

def tasks
  Morpheus::TasksInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#to_s ⇒ Object



51
52
53
# File 'lib/morpheus/api/api_client.rb', line 51

def to_s
  "<##{self.class}:#{self.object_id.to_s(8)} @url=#{@base_url} @verify_ssl=#{@verify_ssl} @access_token=#{@access_token ? '************' : nil} @refresh_token=#{@access_token ? '************' : nil} @expires_at=#{@expires_at} @client_id=#{@client_id} @options=#{@options}>"
end

#url ⇒ Object



47
48
49
# File 'lib/morpheus/api/api_client.rb', line 47

def url
  @base_url
end

#usage ⇒ Object



783
784
785
# File 'lib/morpheus/api/api_client.rb', line 783

def usage
  Morpheus::UsageInterface.new(common_interface_options).setopts(@options)
end

#use_refresh_token(t = nil) ⇒ Object



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/morpheus/api/api_client.rb', line 293

def use_refresh_token(t=nil)
  if t.nil?
    t = @refresh_token
  end
  if t.nil?
    raise "#{self.class} does not currently have a refresh_token"
  end
  response = auth.use_refresh_token(t, self.client_id)
  @access_token = response['access_token']
  @refresh_token = response['refresh_token']
  if response['expires_in'] != nil
    @expires_at = Time.now + response['expires_in']
  end
  @access_token = response['access_token']
  # return response
  return self
end

#user_groups ⇒ Object



517
518
519
# File 'lib/morpheus/api/api_client.rb', line 517

def user_groups
  Morpheus::UserGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#user_settings ⇒ Object



357
358
359
# File 'lib/morpheus/api/api_client.rb', line 357

def 
  Morpheus::UserSettingsInterface.new(common_interface_options).setopts(@options)
end

#user_sources ⇒ Object



521
522
523
# File 'lib/morpheus/api/api_client.rb', line 521

def user_sources
  Morpheus::UserSourcesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#users ⇒ Object



513
514
515
# File 'lib/morpheus/api/api_client.rb', line 513

def users
  Morpheus::UsersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#virtual_images ⇒ Object



473
474
475
# File 'lib/morpheus/api/api_client.rb', line 473

def virtual_images
  Morpheus::VirtualImagesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#whitelabel_settings ⇒ Object



735
736
737
# File 'lib/morpheus/api/api_client.rb', line 735

def whitelabel_settings
  Morpheus::WhitelabelSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#whoami ⇒ Object



349
350
351
# File 'lib/morpheus/api/api_client.rb', line 349

def whoami
  Morpheus::WhoamiInterface.new(common_interface_options).setopts(@options)
end

#wiki ⇒ Object



739
740
741
# File 'lib/morpheus/api/api_client.rb', line 739

def wiki
  Morpheus::WikiInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end

#withopts(tmp_options, &block) ⇒ Object Also known as: with_options

with_options sets common global @options for the duration of the block only then returns the options to their prior values

Parameters:

  • opts (Hash) —

    globally supported options like :dry_run, :json, :curl, :headers, :timeout, etc

Returns:

  • result of block, usually the a result Hash from client.execute({})



123
124
125
126
127
128
129
130
131
132
# File 'lib/morpheus/api/api_client.rb', line 123

def withopts(tmp_options, &block)
  @_old_options = @options
  begin
    @options = tmp_options
    result = block.call()
  ensure
    @options = @_old_options
  end
  return result
end