Class: Morpheus::APIClient
- Inherits:
-
Object
- Object
- Morpheus::APIClient
show all
- Defined in:
- lib/morpheus/api/api_client.rb
Direct Known Subclasses
AccountGroupsInterface, AccountsInterface, ActivityInterface, ApplianceSettingsInterface, ApprovalsInterface, AppsInterface, ArchiveBucketsInterface, ArchiveFilesInterface, AuthInterface, BackupSettingsInterface, BlueprintsInterface, BudgetsInterface, CloudDatastoresInterface, CloudFoldersInterface, CloudPoliciesInterface, CloudResourcePoolsInterface, CloudsInterface, ClustersInterface, ContainersInterface, CustomInstanceTypesInterface, CypherInterface, DashboardInterface, DatastoresInterface, DeployInterface, DeploymentsInterface, EnvironmentsInterface, ExecuteSchedulesInterface, ExecutionRequestInterface, FileCopyRequestInterface, GroupPoliciesInterface, GroupsInterface, GuidanceInterface, HealthInterface, ImageBuilderBootScriptsInterface, ImageBuilderImageBuildsInterface, ImageBuilderInterface, ImageBuilderPreseedScriptsInterface, InstanceTypesInterface, InstancesInterface, IntegrationsInterface, InvoiceLineItemsInterface, InvoicesInterface, JobsInterface, KeyPairsInterface, LibraryClusterLayoutsInterface, LibraryContainerScriptsInterface, LibraryContainerTemplatesInterface, LibraryContainerTypesInterface, LibraryContainerUpgradesInterface, LibraryInstanceTypesInterface, LibraryLayoutsInterface, LibrarySpecTemplateTypesInterface, LibrarySpecTemplatesInterface, LicenseInterface, LoadBalancersInterface, LogSettingsInterface, LogsInterface, MonitoringAlertsInterface, MonitoringAppsInterface, MonitoringChecksInterface, MonitoringContactsInterface, MonitoringGroupsInterface, MonitoringIncidentsInterface, MonitoringInterface, NetworkDomainRecordsInterface, NetworkDomainsInterface, NetworkGroupsInterface, NetworkPoolIpsInterface, NetworkPoolServersInterface, NetworkPoolsInterface, NetworkProxiesInterface, NetworkRoutersInterface, NetworkSecurityServersInterface, NetworkServicesInterface, NetworkSubnetsInterface, NetworkTypesInterface, NetworksInterface, OptionTypeListsInterface, OptionTypesInterface, OptionsInterface, PackagesInterface, PingInterface, PoliciesInterface, PowerSchedulesInterface, PriceSetsInterface, PricesInterface, ProcessesInterface, ProjectsInterface, ProvisionTypesInterface, ProvisioningLicenseTypesInterface, ProvisioningLicensesInterface, ProvisioningSettingsInterface, ReportsInterface, RolesInterface, SecurityGroupRulesInterface, SecurityGroupsInterface, ServerTypesInterface, ServersInterface, ServicePlansInterface, SetupInterface, StorageProvidersInterface, SubnetTypesInterface, SubnetsInterface, TaskSetsInterface, TasksInterface, UserGroupsInterface, UserSettingsInterface, UserSourcesInterface, UsersInterface, VirtualImagesInterface, WhitelabelSettingsInterface, WhoamiInterface, WikiInterface
Constant Summary
collapse
- CLIENT_ID =
'morph-cli'
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#account_groups ⇒ Object
-
#accounts ⇒ Object
-
#activity ⇒ Object
-
#appliance_settings ⇒ Object
-
#approvals ⇒ Object
-
#apps ⇒ Object
-
#archive_buckets ⇒ Object
-
#archive_files ⇒ Object
-
#auth ⇒ Object
-
#authorization_required? ⇒ Boolean
Authorization is required, except for a couple commands like Ping and Setup.
-
#backup_settings ⇒ Object
-
#blueprints ⇒ Object
-
#budgets ⇒ Object
-
#cloud_datastores ⇒ Object
-
#cloud_folders ⇒ Object
-
#cloud_policies ⇒ Object
-
#cloud_resource_pools ⇒ Object
-
#clouds ⇒ Object
-
#clusters ⇒ Object
-
#common_interface_options ⇒ Object
-
#containers ⇒ Object
-
#custom_instance_types ⇒ Object
-
#cypher ⇒ Object
-
#dashboard ⇒ Object
-
#datastores ⇒ Object
-
#default_content_type ⇒ Object
set this in your interface, eg.
-
#default_timeout ⇒ Object
set default seconds for interface to timeout after or let it use system default? none, it should not timeout by default..
-
#deploy ⇒ Object
-
#deployments ⇒ Object
-
#dry ⇒ Object
-
#dry_run(val = true) ⇒ Object
-
#environments ⇒ Object
-
#execute(opts, options = {}) ⇒ Object
Execute an HTTP request with this client.
-
#execute_schedules ⇒ Object
-
#execution_request ⇒ Object
-
#file_copy_request ⇒ Object
-
#group_policies ⇒ Object
-
#groups ⇒ Object
-
#guidance ⇒ Object
-
#health ⇒ Object
-
#image_builder ⇒ Object
-
#initialize(access_token, refresh_token = nil, expires_in = nil, base_url = nil, verify_ssl = true, options = {}) ⇒ APIClient
constructor
Initialize a new APIClient client = APIClient.new(url:"https://morpheus.yourcompany.com", verify_ssl:false) This old method signature is being deprecated: client = APIClient.new(access_token, refresh_token, expires_in, base_url, verify_ssl, options={}).
-
#inspect ⇒ Object
-
#instance_types ⇒ Object
-
#instances ⇒ Object
-
#integrations ⇒ Object
-
#invoice_line_items ⇒ Object
-
#invoices ⇒ Object
-
#jobs ⇒ Object
-
#key_pairs ⇒ Object
-
#library_cluster_layouts ⇒ Object
-
#library_container_scripts ⇒ Object
-
#library_container_templates ⇒ Object
-
#library_container_types ⇒ Object
-
#library_container_upgrades ⇒ Object
-
#library_instance_types ⇒ Object
-
#library_layouts ⇒ Object
-
#library_spec_template_types ⇒ Object
-
#library_spec_templates ⇒ Object
-
#license ⇒ Object
-
#load_balancers ⇒ Object
-
#log_settings ⇒ Object
-
#logged_in? ⇒ Boolean
-
#login(username, password, use_client_id = nil) ⇒ Object
-
#logout ⇒ Object
-
#logs ⇒ Object
-
#monitoring ⇒ Object
-
#network_domain_records ⇒ Object
-
#network_domains ⇒ Object
-
#network_groups ⇒ Object
-
#network_pool_ips ⇒ Object
-
#network_pool_servers ⇒ Object
-
#network_pools ⇒ Object
-
#network_proxies ⇒ Object
-
#network_routers ⇒ Object
-
#network_security_servers ⇒ Object
-
#network_services ⇒ Object
-
#network_types ⇒ Object
-
#networks ⇒ Object
-
#old_cypher ⇒ Object
-
#option_type_lists ⇒ Object
-
#option_types ⇒ Object
-
#options ⇒ Object
-
#packages ⇒ Object
-
#ping ⇒ Object
-
#policies ⇒ Object
def incidents # Morpheus::MonitoringIncidentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options) monitoring.incidents end.
-
#power_schedules ⇒ Object
-
#price_sets ⇒ Object
-
#prices ⇒ Object
-
#processes ⇒ Object
-
#projects ⇒ Object
-
#provision_types ⇒ Object
-
#provisioning_license_types ⇒ Object
-
#provisioning_licenses ⇒ Object
-
#provisioning_settings ⇒ Object
-
#refresh_token ⇒ Object
-
#reports ⇒ Object
-
#roles ⇒ Object
-
#security_group_rules ⇒ Object
-
#security_groups ⇒ Object
-
#server_types ⇒ Object
-
#servers ⇒ Object
-
#service_plans ⇒ Object
-
#set_ssl_verification_enabled(val) ⇒ Object
-
#setopts(new_options) ⇒ Object
(also: #set_options)
set common global @options for use with all requests meant for inline use just like dry(), set_options(dry_run:true) can be used in place of dry() Example: Prints curl -XGET .../whoami -H "Bearer" instead of actually request APIClient.new(token).whoami.setopts(curl:true).get({}).
-
#setup ⇒ Object
-
#ssl_verification_enabled? ⇒ Boolean
-
#storage_providers ⇒ Object
-
#subnet_types ⇒ Object
-
#subnets ⇒ Object
-
#task_sets ⇒ Object
-
#tasks ⇒ Object
-
#to_s ⇒ Object
-
#url ⇒ Object
-
#user_groups ⇒ Object
-
#user_settings ⇒ Object
-
#user_sources ⇒ Object
-
#users ⇒ Object
-
#virtual_images ⇒ Object
-
#whitelabel_settings ⇒ Object
-
#whoami ⇒ Object
-
#wiki ⇒ Object
-
#withopts(tmp_options, &block) ⇒ Object
(also: #with_options)
with_options sets common global @options for the duration of the block only then returns the options to their prior values.
Constructor Details
#initialize(access_token, refresh_token = nil, expires_in = nil, base_url = nil, verify_ssl = true, options = {}) ⇒ APIClient
Initialize a new APIClient
client = APIClient.new(url:"https://morpheus.yourcompany.com", verify_ssl:false)
This old method signature is being deprecated:
client = APIClient.new(access_token, refresh_token, expires_in, base_url, verify_ssl, options={})
def initialize(attrs={}, options={})
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
|
# File 'lib/morpheus/api/api_client.rb', line 16
def initialize(access_token, refresh_token=nil,expires_in = nil, base_url=nil, verify_ssl=true, options={})
self.client_id = CLIENT_ID
attrs = {}
if access_token.is_a?(Hash)
attrs = access_token.clone()
access_token = attrs[:access_token]
refresh_token = attrs[:refresh_token]
base_url = attrs[:url] || attrs[:base_url]
expires_in = attrs[:expires_in]
verify_ssl = attrs.key?(:verify_ssl) ? attrs[:verify_ssl] : true
self.client_id = attrs[:client_id] ? attrs[:client_id] : CLIENT_ID
if attrs[:client_id]
self.client_id = attrs[:client_id]
end
options = refresh_token.is_a?(Hash) ? refresh_token.clone() : {}
end
@access_token = access_token
@refresh_token = refresh_token
@base_url = base_url
if @base_url.to_s.empty?
raise "#{self.class} initialized without a required option :url"
end
@base_url = @base_url.chomp("/")
if expires_in != nil
@expires_at = Time.now + expires_in
end
set_ssl_verification_enabled(verify_ssl)
setopts(options)
end
|
Instance Attribute Details
#client_id ⇒ Object
Returns the value of attribute client_id.
9
10
11
|
# File 'lib/morpheus/api/api_client.rb', line 9
def client_id
@client_id
end
|
Instance Method Details
#account_groups ⇒ Object
359
360
361
|
# File 'lib/morpheus/api/api_client.rb', line 359
def account_groups
Morpheus::AccountGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#accounts ⇒ Object
487
488
489
|
# File 'lib/morpheus/api/api_client.rb', line 487
def accounts
Morpheus::AccountsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#activity ⇒ Object
347
348
349
|
# File 'lib/morpheus/api/api_client.rb', line 347
def activity
Morpheus::ActivityInterface.new(common_interface_options).setopts(@options)
end
|
#appliance_settings ⇒ Object
391
392
393
|
# File 'lib/morpheus/api/api_client.rb', line 391
def appliance_settings
Morpheus::ApplianceSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#approvals ⇒ Object
491
492
493
|
# File 'lib/morpheus/api/api_client.rb', line 491
def approvals
Morpheus::ApprovalsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#apps ⇒ Object
459
460
461
|
# File 'lib/morpheus/api/api_client.rb', line 459
def apps
Morpheus::AppsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#archive_buckets ⇒ Object
625
626
627
|
# File 'lib/morpheus/api/api_client.rb', line 625
def archive_buckets
Morpheus::ArchiveBucketsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#archive_files ⇒ Object
629
630
631
|
# File 'lib/morpheus/api/api_client.rb', line 629
def archive_files
Morpheus::ArchiveFilesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#auth ⇒ Object
330
331
332
333
|
# File 'lib/morpheus/api/api_client.rb', line 330
def auth
Morpheus::AuthInterface.new({url: @base_url, client_id: @client_id}).setopts(@options)
end
|
#authorization_required? ⇒ Boolean
Authorization is required, except for a couple commands like Ping and Setup
91
92
93
|
# File 'lib/morpheus/api/api_client.rb', line 91
def authorization_required?
true
end
|
#backup_settings ⇒ Object
709
710
711
|
# File 'lib/morpheus/api/api_client.rb', line 709
def backup_settings
Morpheus::BackupSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#blueprints ⇒ Object
463
464
465
|
# File 'lib/morpheus/api/api_client.rb', line 463
def blueprints
Morpheus::BlueprintsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#budgets ⇒ Object
725
726
727
|
# File 'lib/morpheus/api/api_client.rb', line 725
def budgets
Morpheus::BudgetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#cloud_datastores ⇒ Object
367
368
369
|
# File 'lib/morpheus/api/api_client.rb', line 367
def cloud_datastores
Morpheus::CloudDatastoresInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#cloud_folders ⇒ Object
375
376
377
|
# File 'lib/morpheus/api/api_client.rb', line 375
def cloud_folders
Morpheus::CloudFoldersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#cloud_policies ⇒ Object
565
566
567
|
# File 'lib/morpheus/api/api_client.rb', line 565
def cloud_policies
Morpheus::CloudPoliciesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#cloud_resource_pools ⇒ Object
371
372
373
|
# File 'lib/morpheus/api/api_client.rb', line 371
def cloud_resource_pools
Morpheus::CloudResourcePoolsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#clouds ⇒ Object
363
364
365
|
# File 'lib/morpheus/api/api_client.rb', line 363
def clouds
Morpheus::CloudsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#clusters ⇒ Object
483
484
485
|
# File 'lib/morpheus/api/api_client.rb', line 483
def clusters
Morpheus::ClustersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#common_interface_options ⇒ Object
312
313
314
315
316
317
318
319
320
|
# File 'lib/morpheus/api/api_client.rb', line 312
def common_interface_options
{
url: @base_url,
access_token: @access_token,
refresh_token: @refresh_token,
expires_at: @expires_at,
client_id: @client_id
}
end
|
#containers ⇒ Object
407
408
409
|
# File 'lib/morpheus/api/api_client.rb', line 407
def containers
Morpheus::ContainersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#custom_instance_types ⇒ Object
523
524
525
|
# File 'lib/morpheus/api/api_client.rb', line 523
def custom_instance_types
Morpheus::CustomInstanceTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#cypher ⇒ Object
681
682
683
|
# File 'lib/morpheus/api/api_client.rb', line 681
def cypher
Morpheus::CypherInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#dashboard ⇒ Object
343
344
345
|
# File 'lib/morpheus/api/api_client.rb', line 343
def dashboard
Morpheus::DashboardInterface.new(common_interface_options).setopts(@options)
end
|
#datastores ⇒ Object
379
380
381
|
# File 'lib/morpheus/api/api_client.rb', line 379
def datastores
Morpheus::DatastoresInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#default_content_type ⇒ Object
set this in your interface, eg. to 'application/json'
or let it it default to json when payload is present.
78
79
80
|
# File 'lib/morpheus/api/api_client.rb', line 78
def default_content_type
nil
end
|
#default_timeout ⇒ Object
set default seconds for interface to timeout after
or let it use system default? none, it should not timeout by default..
I think execute() may use 30 seconds for get by default.
and it should remove timeout when method is post, put, or delete
86
87
88
|
# File 'lib/morpheus/api/api_client.rb', line 86
def default_timeout
nil
end
|
#deploy ⇒ Object
467
468
469
|
# File 'lib/morpheus/api/api_client.rb', line 467
def deploy
Morpheus::DeployInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#deployments ⇒ Object
471
472
473
|
# File 'lib/morpheus/api/api_client.rb', line 471
def deployments
Morpheus::DeploymentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#dry ⇒ Object
64
65
66
|
# File 'lib/morpheus/api/api_client.rb', line 64
def dry()
dry_run(true)
end
|
#dry_run(val = true) ⇒ Object
59
60
61
62
|
# File 'lib/morpheus/api/api_client.rb', line 59
def dry_run(val=true)
@dry_run = !!val
self
end
|
#environments ⇒ Object
705
706
707
|
# File 'lib/morpheus/api/api_client.rb', line 705
def environments
Morpheus::EnvironmentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#execute(opts, options = {}) ⇒ Object
Execute an HTTP request with this client.
opts - Hash of options for HTTP Request.
:url - The full url
:method - The default method is :get (GET)
:headers - Hash of headers to include in the request.
eg. => 'application/json'. :params is a special key for query parameters.
:params - query parameters
:payload - The body of the request.
:timeout - A custom timeout in seconds for api requests. The default is 30. todo: separate timeout options
options - Hash of common global options that commands parse. eg. :headers, :timeout, :dry_run, :curl, etc
:headers - Extra headers to add. This expects a Hash like => 'application/json'.
:timeout - A custom timeout in seconds for api requests. The default is 30. todo: separate timeout options
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
|
# File 'lib/morpheus/api/api_client.rb', line 148
def execute(opts, options={})
if opts[:url]
if !opts[:url].include?(@base_url)
opts[:url] = "#{@base_url}#{opts[:url]}"
end
end
if @options
options = options.merge(@options)
else
options = options.clone
end
if opts[:method].nil?
opts[:method] = :get
else
opts[:method] = opts[:method].to_s.downcase.to_sym
end
opts[:headers] ||= {}
if authorization_required?
if @access_token
if opts[:headers][:authorization].nil? && opts[:headers]['Authorization'].nil?
opts[:headers][:authorization] = "Bearer #{@access_token}"
else
end
end
end
if opts[:headers]['Content-Type'].nil? && default_content_type
opts[:headers]['Content-Type'] = default_content_type
end
if opts[:headers]['Content-Type'].nil? && options[:payload]
opts[:headers]['Content-Type'] = 'application/json'
end
if opts[:timeout].nil?
if options[:timeout]
opts[:timeout] = options[:timeout].to_f
elsif default_timeout && opts[:method] == :get
opts[:timeout] = default_timeout.to_f
end
end
if options[:headers]
opts[:headers] = opts[:headers].merge(options[:headers])
end
if opts[:params] && (opts[:headers][:params].nil? || opts[:headers][:params].empty?)
opts[:headers][:params] = opts[:params]
end
if @verify_ssl == false
opts[:verify_ssl] = OpenSSL::SSL::VERIFY_NONE
end
if @dry_run
opts[:command_options] = options
return opts
end
response = Morpheus::RestClient.execute(opts)
if opts[:parse_json] != false && options[:parse_json] != false
return JSON.parse(response.to_s)
else
return response
end
end
|
#execute_schedules ⇒ Object
539
540
541
|
# File 'lib/morpheus/api/api_client.rb', line 539
def execute_schedules
Morpheus::ExecuteSchedulesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#execution_request ⇒ Object
689
690
691
|
# File 'lib/morpheus/api/api_client.rb', line 689
def execution_request
Morpheus::ExecutionRequestInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#file_copy_request ⇒ Object
693
694
695
|
# File 'lib/morpheus/api/api_client.rb', line 693
def file_copy_request
Morpheus::FileCopyRequestInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#group_policies ⇒ Object
561
562
563
|
# File 'lib/morpheus/api/api_client.rb', line 561
def group_policies
Morpheus::GroupPoliciesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#groups ⇒ Object
355
356
357
|
# File 'lib/morpheus/api/api_client.rb', line 355
def groups
Morpheus::GroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#guidance ⇒ Object
741
742
743
|
# File 'lib/morpheus/api/api_client.rb', line 741
def guidance
Morpheus::GuidanceInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#health ⇒ Object
729
730
731
|
# File 'lib/morpheus/api/api_client.rb', line 729
def health
Morpheus::HealthInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#image_builder ⇒ Object
633
634
635
|
# File 'lib/morpheus/api/api_client.rb', line 633
def image_builder
Morpheus::ImageBuilderInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#inspect ⇒ Object
55
56
57
|
# File 'lib/morpheus/api/api_client.rb', line 55
def inspect
to_s
end
|
#instance_types ⇒ Object
411
412
413
|
# File 'lib/morpheus/api/api_client.rb', line 411
def instance_types
Morpheus::InstanceTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#instances ⇒ Object
387
388
389
|
# File 'lib/morpheus/api/api_client.rb', line 387
def instances
Morpheus::InstancesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#integrations ⇒ Object
415
416
417
|
# File 'lib/morpheus/api/api_client.rb', line 415
def integrations
Morpheus::IntegrationsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#invoice_line_items ⇒ Object
737
738
739
|
# File 'lib/morpheus/api/api_client.rb', line 737
def invoice_line_items
Morpheus::InvoiceLineItemsInterface.new(common_interface_options).setopts(@options)
end
|
#invoices ⇒ Object
733
734
735
|
# File 'lib/morpheus/api/api_client.rb', line 733
def invoices
Morpheus::InvoicesInterface.new(common_interface_options).setopts(@options)
end
|
#jobs ⇒ Object
419
420
421
|
# File 'lib/morpheus/api/api_client.rb', line 419
def jobs
Morpheus::JobsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#key_pairs ⇒ Object
515
516
517
|
# File 'lib/morpheus/api/api_client.rb', line 515
def key_pairs
Morpheus::KeyPairsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#library_cluster_layouts ⇒ Object
665
666
667
|
# File 'lib/morpheus/api/api_client.rb', line 665
def library_cluster_layouts
Morpheus::LibraryClusterLayoutsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#library_container_scripts ⇒ Object
657
658
659
|
# File 'lib/morpheus/api/api_client.rb', line 657
def library_container_scripts
Morpheus::LibraryContainerScriptsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#library_container_templates ⇒ Object
661
662
663
|
# File 'lib/morpheus/api/api_client.rb', line 661
def library_container_templates
Morpheus::LibraryContainerTemplatesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#library_container_types ⇒ Object
653
654
655
|
# File 'lib/morpheus/api/api_client.rb', line 653
def library_container_types
Morpheus::LibraryContainerTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#library_container_upgrades ⇒ Object
649
650
651
|
# File 'lib/morpheus/api/api_client.rb', line 649
def library_container_upgrades
Morpheus::LibraryContainerUpgradesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#library_instance_types ⇒ Object
641
642
643
|
# File 'lib/morpheus/api/api_client.rb', line 641
def library_instance_types
Morpheus::LibraryInstanceTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#library_layouts ⇒ Object
645
646
647
|
# File 'lib/morpheus/api/api_client.rb', line 645
def library_layouts
Morpheus::LibraryLayoutsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#library_spec_template_types ⇒ Object
673
674
675
|
# File 'lib/morpheus/api/api_client.rb', line 673
def library_spec_template_types
Morpheus::LibrarySpecTemplateTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#library_spec_templates ⇒ Object
669
670
671
|
# File 'lib/morpheus/api/api_client.rb', line 669
def library_spec_templates
Morpheus::LibrarySpecTemplatesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#license ⇒ Object
519
520
521
|
# File 'lib/morpheus/api/api_client.rb', line 519
def license
Morpheus::LicenseInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#load_balancers ⇒ Object
443
444
445
|
# File 'lib/morpheus/api/api_client.rb', line 443
def load_balancers
Morpheus::LoadBalancersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#log_settings ⇒ Object
713
714
715
|
# File 'lib/morpheus/api/api_client.rb', line 713
def log_settings
Morpheus::LogSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#logged_in? ⇒ Boolean
263
264
265
|
# File 'lib/morpheus/api/api_client.rb', line 263
def logged_in?
!!@access_token
end
|
#login(username, password, use_client_id = nil) ⇒ Object
275
276
277
278
279
280
281
282
283
284
285
286
287
288
|
# File 'lib/morpheus/api/api_client.rb', line 275
def login(username, password, use_client_id=nil)
if use_client_id
self.client_id = use_client_id
end
@access_token, @refresh_token, @expires_at = nil, nil, nil
response = auth.login(username, password, self.client_id)
@access_token = response['access_token']
@refresh_token = response['refresh_token']
if response['expires_in'] != nil
@expires_at = Time.now + response['expires_in']
end
return self
end
|
#logout ⇒ Object
305
306
307
308
309
310
|
# File 'lib/morpheus/api/api_client.rb', line 305
def logout
@access_token = nil
@refresh_token = nil
@expires_at = nil
return self
end
|
#logs ⇒ Object
507
508
509
|
# File 'lib/morpheus/api/api_client.rb', line 507
def logs
Morpheus::LogsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#monitoring ⇒ Object
543
544
545
|
# File 'lib/morpheus/api/api_client.rb', line 543
def monitoring
Morpheus::MonitoringInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_domain_records ⇒ Object
617
618
619
|
# File 'lib/morpheus/api/api_client.rb', line 617
def network_domain_records
Morpheus::NetworkDomainRecordsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_domains ⇒ Object
613
614
615
|
# File 'lib/morpheus/api/api_client.rb', line 613
def network_domains
Morpheus::NetworkDomainsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_groups ⇒ Object
585
586
587
|
# File 'lib/morpheus/api/api_client.rb', line 585
def network_groups
Morpheus::NetworkGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_pool_ips ⇒ Object
593
594
595
|
# File 'lib/morpheus/api/api_client.rb', line 593
def network_pool_ips
Morpheus::NetworkPoolIpsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_pool_servers ⇒ Object
609
610
611
|
# File 'lib/morpheus/api/api_client.rb', line 609
def network_pool_servers
Morpheus::NetworkPoolServersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_pools ⇒ Object
589
590
591
|
# File 'lib/morpheus/api/api_client.rb', line 589
def network_pools
Morpheus::NetworkPoolsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_proxies ⇒ Object
621
622
623
|
# File 'lib/morpheus/api/api_client.rb', line 621
def network_proxies
Morpheus::NetworkProxiesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_routers ⇒ Object
597
598
599
|
# File 'lib/morpheus/api/api_client.rb', line 597
def network_routers
Morpheus::NetworkRoutersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_security_servers ⇒ Object
605
606
607
|
# File 'lib/morpheus/api/api_client.rb', line 605
def network_security_servers
Morpheus::NetworkSecurityServersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_services ⇒ Object
601
602
603
|
# File 'lib/morpheus/api/api_client.rb', line 601
def network_services
Morpheus::NetworkServicesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#network_types ⇒ Object
573
574
575
|
# File 'lib/morpheus/api/api_client.rb', line 573
def network_types
Morpheus::NetworkTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#networks ⇒ Object
569
570
571
|
# File 'lib/morpheus/api/api_client.rb', line 569
def networks
Morpheus::NetworksInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#old_cypher ⇒ Object
685
686
687
|
# File 'lib/morpheus/api/api_client.rb', line 685
def old_cypher
Morpheus::OldCypherInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#option_type_lists ⇒ Object
531
532
533
|
# File 'lib/morpheus/api/api_client.rb', line 531
def option_type_lists
Morpheus::OptionTypeListsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#option_types ⇒ Object
527
528
529
|
# File 'lib/morpheus/api/api_client.rb', line 527
def option_types
Morpheus::OptionTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#options ⇒ Object
351
352
353
|
# File 'lib/morpheus/api/api_client.rb', line 351
def options
Morpheus::OptionsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#packages ⇒ Object
677
678
679
|
# File 'lib/morpheus/api/api_client.rb', line 677
def packages
Morpheus::PackagesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#ping ⇒ Object
322
323
324
|
# File 'lib/morpheus/api/api_client.rb', line 322
def ping
Morpheus::PingInterface.new(common_interface_options).setopts(@options)
end
|
#policies ⇒ Object
def incidents
Morpheus::MonitoringIncidentsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
monitoring.incidents
end
557
558
559
|
# File 'lib/morpheus/api/api_client.rb', line 557
def policies
Morpheus::PoliciesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#power_schedules ⇒ Object
535
536
537
|
# File 'lib/morpheus/api/api_client.rb', line 535
def power_schedules
Morpheus::PowerSchedulesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#price_sets ⇒ Object
435
436
437
|
# File 'lib/morpheus/api/api_client.rb', line 435
def price_sets
Morpheus::PriceSetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#prices ⇒ Object
439
440
441
|
# File 'lib/morpheus/api/api_client.rb', line 439
def prices
Morpheus::PricesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#processes ⇒ Object
697
698
699
|
# File 'lib/morpheus/api/api_client.rb', line 697
def processes
Morpheus::ProcessesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#projects ⇒ Object
745
746
747
|
# File 'lib/morpheus/api/api_client.rb', line 745
def projects
Morpheus::ProjectsInterface.new(common_interface_options).setopts(@options)
end
|
#provision_types ⇒ Object
427
428
429
|
# File 'lib/morpheus/api/api_client.rb', line 427
def provision_types
Morpheus::ProvisionTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#provisioning_license_types ⇒ Object
403
404
405
|
# File 'lib/morpheus/api/api_client.rb', line 403
def provisioning_license_types
Morpheus::ProvisioningLicenseTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#provisioning_licenses ⇒ Object
399
400
401
|
# File 'lib/morpheus/api/api_client.rb', line 399
def provisioning_licenses
Morpheus::ProvisioningLicensesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#provisioning_settings ⇒ Object
395
396
397
|
# File 'lib/morpheus/api/api_client.rb', line 395
def provisioning_settings
Morpheus::ProvisioningSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#refresh_token ⇒ Object
290
291
292
293
294
295
296
297
298
299
300
301
302
303
|
# File 'lib/morpheus/api/api_client.rb', line 290
def refresh_token()
if @refresh_token.nil?
raise "#{self.class} does not currently have a refresh_token"
end
response = auth.use_refresh_token(@refresh_token, self.client_id)
@access_token = response['access_token']
@refresh_token = response['refresh_token']
if response['expires_in'] != nil
@expires_at = Time.now + response['expires_in']
end
@access_token = response['access_token']
return self
end
|
#reports ⇒ Object
701
702
703
|
# File 'lib/morpheus/api/api_client.rb', line 701
def reports
Morpheus::ReportsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#roles ⇒ Object
511
512
513
|
# File 'lib/morpheus/api/api_client.rb', line 511
def roles
Morpheus::RolesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#security_group_rules ⇒ Object
479
480
481
|
# File 'lib/morpheus/api/api_client.rb', line 479
def security_group_rules
Morpheus::SecurityGroupRulesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#security_groups ⇒ Object
475
476
477
|
# File 'lib/morpheus/api/api_client.rb', line 475
def security_groups
Morpheus::SecurityGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#server_types ⇒ Object
423
424
425
|
# File 'lib/morpheus/api/api_client.rb', line 423
def server_types
Morpheus::ServerTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#servers ⇒ Object
383
384
385
|
# File 'lib/morpheus/api/api_client.rb', line 383
def servers
Morpheus::ServersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#service_plans ⇒ Object
431
432
433
|
# File 'lib/morpheus/api/api_client.rb', line 431
def service_plans
Morpheus::ServicePlansInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#set_ssl_verification_enabled(val) ⇒ Object
72
73
74
|
# File 'lib/morpheus/api/api_client.rb', line 72
def set_ssl_verification_enabled(val)
@verify_ssl = !!val
end
|
#setopts(new_options) ⇒ Object
Also known as:
set_options
set common global @options for use with all requests
meant for inline use just like dry(), set_options(dry_run:true) can be used in place of dry()
Example:
Prints curl -XGET .../whoami -H "Bearer" instead of actually request
APIClient.new(token).whoami.setopts(curl:true).get({})
111
112
113
114
115
116
117
|
# File 'lib/morpheus/api/api_client.rb', line 111
def setopts(new_options)
@options = new_options
if @options[:dry_run]
dry_run(true)
end
self
end
|
#setup ⇒ Object
326
327
328
|
# File 'lib/morpheus/api/api_client.rb', line 326
def setup
Morpheus::SetupInterface.new(common_interface_options).setopts(@options)
end
|
#ssl_verification_enabled? ⇒ Boolean
68
69
70
|
# File 'lib/morpheus/api/api_client.rb', line 68
def ssl_verification_enabled?
@verify_ssl
end
|
#storage_providers ⇒ Object
637
638
639
|
# File 'lib/morpheus/api/api_client.rb', line 637
def storage_providers
Morpheus::StorageProvidersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#subnet_types ⇒ Object
581
582
583
|
# File 'lib/morpheus/api/api_client.rb', line 581
def subnet_types
Morpheus::SubnetTypesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#subnets ⇒ Object
577
578
579
|
# File 'lib/morpheus/api/api_client.rb', line 577
def subnets
Morpheus::SubnetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#task_sets ⇒ Object
451
452
453
|
# File 'lib/morpheus/api/api_client.rb', line 451
def task_sets
Morpheus::TaskSetsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#tasks ⇒ Object
447
448
449
|
# File 'lib/morpheus/api/api_client.rb', line 447
def tasks
Morpheus::TasksInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#to_s ⇒ Object
51
52
53
|
# File 'lib/morpheus/api/api_client.rb', line 51
def to_s
"<##{self.class}:#{self.object_id.to_s(8)} @url=#{@base_url} @verify_ssl=#{@verify_ssl} @access_token=#{@access_token ? '************' : nil} @refresh_token=#{@access_token ? '************' : nil} @expires_at=#{@expires_at} @client_id=#{@client_id} @options=#{@options}>"
end
|
#url ⇒ Object
47
48
49
|
# File 'lib/morpheus/api/api_client.rb', line 47
def url
@base_url
end
|
#user_groups ⇒ Object
499
500
501
|
# File 'lib/morpheus/api/api_client.rb', line 499
def user_groups
Morpheus::UserGroupsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#user_settings ⇒ Object
339
340
341
|
# File 'lib/morpheus/api/api_client.rb', line 339
def user_settings
Morpheus::UserSettingsInterface.new(common_interface_options).setopts(@options)
end
|
#user_sources ⇒ Object
503
504
505
|
# File 'lib/morpheus/api/api_client.rb', line 503
def user_sources
Morpheus::UserSourcesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#users ⇒ Object
495
496
497
|
# File 'lib/morpheus/api/api_client.rb', line 495
def users
Morpheus::UsersInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#virtual_images ⇒ Object
455
456
457
|
# File 'lib/morpheus/api/api_client.rb', line 455
def virtual_images
Morpheus::VirtualImagesInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#whitelabel_settings ⇒ Object
717
718
719
|
# File 'lib/morpheus/api/api_client.rb', line 717
def whitelabel_settings
Morpheus::WhitelabelSettingsInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#whoami ⇒ Object
335
336
337
|
# File 'lib/morpheus/api/api_client.rb', line 335
def whoami
Morpheus::WhoamiInterface.new(common_interface_options).setopts(@options)
end
|
#wiki ⇒ Object
721
722
723
|
# File 'lib/morpheus/api/api_client.rb', line 721
def wiki
Morpheus::WikiInterface.new(@access_token, @refresh_token, @expires_at, @base_url).setopts(@options)
end
|
#withopts(tmp_options, &block) ⇒ Object
Also known as:
with_options
with_options sets common global @options for the duration of the block only
then returns the options to their prior values
123
124
125
126
127
128
129
130
131
132
|
# File 'lib/morpheus/api/api_client.rb', line 123
def withopts(tmp_options, &block)
@_old_options = @options
begin
@options = tmp_options
result = block.call()
ensure
@options = @_old_options
end
return result
end
|