Class: Morpheus::Cli::Accounts

Inherits:
Object
  • Object
show all
Includes:
AccountsHelper, CliCommand, Term::ANSIColor
Defined in:
lib/morpheus/cli/accounts.rb

Instance Method Summary collapse

Methods included from AccountsHelper

#find_account_by_id, #find_account_by_name, #find_account_from_options, #find_role_by_id, #find_role_by_name, #find_user_by_id, #find_user_by_username, #print_accounts_table, #print_green_success, #print_red_alert, #print_roles_table, #print_users_table

Methods included from CliCommand

accountScopeOptions, genericOptions, included

Constructor Details

#initializeAccounts

Returns a new instance of Accounts.



16
17
18
19
# File 'lib/morpheus/cli/accounts.rb', line 16

def initialize() 
	@appliance_name, @appliance_url = Morpheus::Cli::Remote.active_appliance
	#@active_groups = ::Morpheus::Cli::Groups.load_group_file
end

Instance Method Details

#add(args) ⇒ Object



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/morpheus/cli/accounts.rb', line 155

def add(args)
	usage = "Usage: morpheus accounts add [options]"
	# if args.count > 0
	# 	puts "\nUsage: morpheus accounts add [options]\n\n"
	# 	exit 1
	# end
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)

	connect(options)
	
	begin

		params = Morpheus::Cli::OptionTypes.prompt(, options[:options], @api_client, options[:params]) # options[:params] is mysterious

		#puts "parsed params is : #{params.inspect}"
		 = ['name', 'description', 'currency']
		 = params.select {|k,v| .include?(k) }
		['currency'] = ['currency'].to_s.empty? ? "USD" : ['currency'].upcase
		['instanceLimits'] = {}
		['instanceLimits']['maxStorage'] = params['instanceLimits.maxStorage'].to_i if params['instanceLimits.maxStorage'].to_s.strip != ''
		['instanceLimits']['maxMemory'] = params['instanceLimits.maxMemory'].to_i if params['instanceLimits.maxMemory'].to_s.strip != ''
		['instanceLimits']['maxCpu'] = params['instanceLimits.maxCpu'].to_i if params['instanceLimits.maxCpu'].to_s.strip != ''
		if params['role'].to_s != ''
			role = find_role_by_name(nil, params['role'])
			exit 1 if role.nil?
			['role'] = {id: role['id']}
		end
		request_payload = {account: }
		response = @accounts_interface.create(request_payload)
		
		print_green_success "Account #{['name']} added"
		
		details([["name"]])

	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end

#connect(opts) ⇒ Object



21
22
23
24
25
26
27
28
29
30
31
# File 'lib/morpheus/cli/accounts.rb', line 21

def connect(opts)
	@access_token = Morpheus::Cli::Credentials.new(@appliance_name,@appliance_url).request_credentials()
	if @access_token.empty?
		print red,bold, "\nInvalid Credentials. Unable to acquire access token. Please verify your credentials and try again.\n\n",reset
		exit 1
	end
	@api_client = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url)
	@users_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).users
	@accounts_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).accounts
	@roles_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).roles
end

#details(args) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/morpheus/cli/accounts.rb', line 90

def details(args)
	usage = "Usage: morpheus accounts details [name] [options]"
	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	name = args[0]
	options = {}
	params = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage

		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)
	connect(options)
	begin

		# todo: accounts_response = @accounts_interface.list({name: name})
		#       there may be response data outside of account that needs to be displayed

		 = nil
		if name.to_s =~ /\Aid:/
			id = name.sub('id:', '')
			 = (id)
		else
			 = (name)
		end
		exit 1 if .nil?

		if options[:json]
			print JSON.pretty_generate()
			print "\n"
		else
			print "\n" ,cyan, bold, "Account Details\n","==================", reset, "\n\n"
			print cyan
			puts "ID: #{['id']}"
			puts "Name: #{['name']}"
			puts "Description: #{['description']}"
			puts "Currency: #{['currency']}"
			# puts "# Users: #{account['usersCount']}"
			# puts "# Instances: #{account['instancesCount']}"
			puts "Date Created: #{format_local_dt(['dateCreated'])}"
			puts "Last Updated: #{format_local_dt(['lastUpdated'])}"
			status_state = nil
			if ['active']
				status_state = "#{green}ACTIVE#{cyan}"
			else
				status_state = "#{red}INACTIVE#{cyan}"
			end
			puts "Status: #{status_state}"
			print "\n" ,cyan, bold, "Account Instance Limits\n","==================", reset, "\n\n"
			print cyan
			puts "Max Storage (bytes): #{['instanceLimits'] ? ['instanceLimits']['maxStorage'] : 0}"
			puts "Max Memory (bytes): #{['instanceLimits'] ? ['instanceLimits']['maxMemory'] : 0}"
			puts "CPU Count: #{['instanceLimits'] ? ['instanceLimits']['maxCpu'] : 0}"
			print cyan
			print reset,"\n\n"
		end
	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end

#handle(args) ⇒ Object



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/morpheus/cli/accounts.rb', line 33

def handle(args)
	usage = "Usage: morpheus accounts [list,details,add,update,remove] [name]"
	if args.empty?
		puts "\n#{usage}\n\n"
		exit 1
	end

	case args[0]
		when 'list'
			list(args[1..-1])
		when 'details'
			details(args[1..-1])
		when 'add'
			add(args[1..-1])
		when 'update'
			update(args[1..-1])
		when 'remove'
			remove(args[1..-1])
		else
			puts "\n#{usage}\n\n"
			exit 127
	end
end

#list(args) ⇒ Object



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/morpheus/cli/accounts.rb', line 57

def list(args)
	options = {}
	params = {}
	optparse = OptionParser.new do|opts|
		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)
	connect(options)
	begin
		[:phrase, :offset, :max, :sort, :direction].each do |k|
			params[k] = options[k] unless options[k].nil?
		end

		json_response = @accounts_interface.list(params)
		accounts = json_response['accounts']
		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			print "\n" ,cyan, bold, "Morpheus Accounts\n","==================", reset, "\n\n"
			if accounts.empty?
				puts yellow,"No accounts found.",reset
			else
				print_accounts_table(accounts)
			end
			print reset,"\n\n"
		end
	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end

#remove(args) ⇒ Object



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/morpheus/cli/accounts.rb', line 259

def remove(args)
	usage = "Usage: morpheus accounts remove [name]"
	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	name = args[0]
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)
	connect(options)
	begin
		# allow finding by ID since name is not unique!
		 = ((name.to_s =~ /\A\d{1,}\Z/) ? (name) : (name) )
		exit 1 if .nil?
		exit unless Morpheus::Cli::OptionTypes.confirm("Are you sure you want to delete the account #{['name']}?")
		@accounts_interface.destroy(['id'])
		# list([])
		print "\n", cyan, "Account #{['name']} removed", reset, "\n\n"
	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end

#update(args) ⇒ Object



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/morpheus/cli/accounts.rb', line 200

def update(args)
	usage = "Usage: morpheus accounts update [name] [options]"
	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	name = args[0].strip
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)

	connect(options)
	
	begin

		 = nil
		if name.to_s =~ /\Aid:/
			id = name.sub('id:', '')
			 = (id)
		else
			(name)
		end
		exit 1 if .nil?

		#params = Morpheus::Cli::OptionTypes.prompt(update_account_option_types, options[:options], @api_client, options[:params]) # options[:params] is mysterious
		params = options[:options] || {}

		if params.empty?
			puts "\n#{usage}\n\n"
			option_lines = .collect {|it| "\t-O #{it['fieldName']}=\"value\"" }.join("\n")
			puts "\nAvailable Options:\n#{option_lines}\n\n"
			exit 1
		end

		#puts "parsed params is : #{params.inspect}"
		 = ['name', 'description', 'currency']
		 = params.select {|k,v| .include?(k) }
		['currency'] = ['currency'].upcase unless ['currency'].to_s.empty?
		['instanceLimits'] = {}
		['instanceLimits']['maxStorage'] = params['instanceLimits.maxStorage'].to_i if params['instanceLimits.maxStorage'].to_s.strip != ''
		['instanceLimits']['maxMemory'] = params['instanceLimits.maxMemory'].to_i if params['instanceLimits.maxMemory'].to_s.strip != ''
		['instanceLimits']['maxCpu'] = params['instanceLimits.maxCpu'].to_i if params['instanceLimits.maxCpu'].to_s.strip != ''
		if params['role'].to_s != ''
			role = find_role_by_name(nil, params['role'])
			exit 1 if role.nil?
			['role'] = {id: role['id']}
		end
		request_payload = {account: }
		response = @accounts_interface.update(['id'], request_payload)
		print "\n", cyan, "Account #{['name'] || ['name']} updated", reset, "\n\n"
	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end