Class: Morpheus::Cli::Users

Inherits:
Object
  • Object
show all
Includes:
AccountsHelper, CliCommand
Defined in:
lib/morpheus/cli/users.rb

Instance Method Summary collapse

Methods included from AccountsHelper

#find_account_by_id, #find_account_by_name, #find_account_from_options, #find_role_by_id, #find_role_by_name, #find_user_by_id, #find_user_by_username, #format_role_type, #format_user_role_names, #get_access_string, included, #print_accounts_table, #print_roles_table, #print_users_table

Methods included from CliCommand

#build_common_options, included

Constructor Details

#initializeUsers

Returns a new instance of Users.



14
15
16
17
# File 'lib/morpheus/cli/users.rb', line 14

def initialize() 
	@appliance_name, @appliance_url = Morpheus::Cli::Remote.active_appliance
	#@active_groups = ::Morpheus::Cli::Groups.load_group_file
end

Instance Method Details

#add(args) ⇒ Object



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/morpheus/cli/users.rb', line 197

def add(args)
	usage = "Usage: morpheus users add [options]"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		build_common_options(opts, options, [:account, :options, :json])
		opts.on('-h', '--help', "Prints this help" ) do
       puts opts
			puts Morpheus::Cli::OptionTypes.display_option_types_help(add_user_option_types)
       exit
     end
	end
	optparse.parse(args)

	connect(options)
	
	begin

		 = (options)
		 =  ? ['id'] : nil

		# remove role option_type, it is just for help display, the role prompt is separate down below
		prompt_option_types = add_user_option_types().reject {|it| ['role'].include?(it['fieldName']) }
		
		params = Morpheus::Cli::OptionTypes.prompt(prompt_option_types, options[:options], @api_client, options[:params])

		#puts "parsed params is : #{params.inspect}"
		user_keys = ['username', 'firstName', 'lastName', 'email', 'password', 'passwordConfirmation', 'instanceLimits']
		user_payload = params.select {|k,v| user_keys.include?(k) }
		if !user_payload['instanceLimits']
			user_payload['instanceLimits'] = {}
			user_payload['instanceLimits']['maxStorage'] = params['instanceLimits.maxStorage'].to_i if params['instanceLimits.maxStorage'].to_s.strip != ''
			user_payload['instanceLimits']['maxMemory'] = params['instanceLimits.maxMemory'].to_i if params['instanceLimits.maxMemory'].to_s.strip != ''
			user_payload['instanceLimits']['maxCpu'] = params['instanceLimits.maxCpu'].to_i if params['instanceLimits.maxCpu'].to_s.strip != ''
		end

		roles = prompt_user_roles(, nil, options)
		if !roles.empty?
			user_payload['roles'] = roles.collect {|r| {id: r['id']} }
		end

		request_payload = {user: user_payload}
		json_response = @users_interface.create(, request_payload)

		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			if 
				print_green_success "Added user #{user_payload['username']} to account #{['name']}"
			else
				print_green_success "Added user #{user_payload['username']}"
			end

			details_options = [user_payload["username"]]
			if 
				details_options.push "--account-id", ['id'].to_s
			end
			details(details_options)
		end

	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end

#connect(opts) ⇒ Object



19
20
21
22
23
24
25
26
27
28
29
30
# File 'lib/morpheus/cli/users.rb', line 19

def connect(opts)
	@access_token = Morpheus::Cli::Credentials.new(@appliance_name,@appliance_url).request_credentials()
	if @access_token.empty?
		print_red_alert "Invalid Credentials. Unable to acquire access token. Please verify your credentials and try again."
		exit 1
	end
	@api_client = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url)
	@whoami_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).whoami
	@users_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).users
	@accounts_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).accounts
	@roles_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).roles
end

#details(args) ⇒ Object



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/morpheus/cli/users.rb', line 98

def details(args)
	usage = "Usage: morpheus users details [username] [options]"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
     build_common_options(opts, options, [:account, :json])
     opts.on(nil,'--feature-access', "Display Feature Access") do |val|
			options[:include_feature_access] = true
		end
		# opts.on(nil,'--group-access', "Display Group Access") do
		# 	options[:include_group_access] = true
		# end
		# opts.on(nil,'--cloud-access', "Display Cloud Access") do
		# 	options[:include_cloud_access] = true
		# end
		# opts.on(nil,'--instance-type-access', "Display Instance Type Access") do
		# 	options[:include_instance_type_access] = true
		# end
		opts.on(nil,'--all-access', "Display All Access Lists") do
			options[:include_feature_access] = true
			options[:include_group_access] = true
			options[:include_cloud_access] = true
			options[:include_instance_type_access] = true
		end
	end
	optparse.parse(args)

	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	username = args[0]

	connect(options)
	begin
		
		 = (options)
		 =  ? ['id'] : nil

		# todo: users_response = @users_interface.list(account_id, {name: name})
		#       there may be response data outside of user that needs to be displayed
		user = find_user_by_username(, username)
		exit 1 if user.nil?

		# meh, this should just always be returned with GET /api/users/:id
		user_feature_permissions_json = nil
		user_feature_permissions = nil
		if options[:include_feature_access]
			user_feature_permissions_json = @users_interface.feature_permissions(, user['id'])
			user_feature_permissions = user_feature_permissions_json['featurePermissions']
		end

		if options[:json]
			print JSON.pretty_generate({user:user})
			print "\n"
			if (user_feature_permissions_json)
				print JSON.pretty_generate(user_feature_permissions_json)
				print "\n"
			end
		else
			print "\n" ,cyan, bold, "User Details\n","==================", reset, "\n\n"
			print cyan
			puts "ID: #{user['id']}"
			puts "Account: #{user['account'] ? user['account']['name'] : nil}"
			puts "First Name: #{user['firstName']}"
			puts "Last Name: #{user['lastName']}"
			puts "Username: #{user['username']}"
			puts "Email: #{user['email']}"
			puts "Role: #{format_user_role_names(user)}"
			puts "Date Created: #{format_local_dt(user['dateCreated'])}"
			puts "Last Updated: #{format_local_dt(user['lastUpdated'])}"
			print "\n" ,cyan, bold, "User Instance Limits\n","==================", reset, "\n\n"
			print cyan
			puts "Max Storage (bytes): #{user['instanceLimits'] ? user['instanceLimits']['maxStorage'] : 0}"
			puts "Max Memory (bytes): #{user['instanceLimits'] ? user['instanceLimits']['maxMemory'] : 0}"
			puts "CPU Count: #{user['instanceLimits'] ? user['instanceLimits']['maxCpu'] : 0}"

			if options[:include_feature_access] && user_feature_permissions
				if user_feature_permissions
					print "\n" ,cyan, bold, "Feature Permissions\n","==================", reset, "\n\n"
					print cyan
					rows = user_feature_permissions.collect do |code, access|
						{code: code, access: get_access_string(access) }
					end
					tp rows, [:code, :access]
				else
					puts yellow,"No permissions found.",reset
				end
			end

			print cyan
			print reset,"\n"
		end
	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end

#handle(args) ⇒ Object



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/morpheus/cli/users.rb', line 32

def handle(args)
	usage = "Usage: morpheus users [list,details,add,update,remove] [username]"
	if args.empty?
		puts "\n#{usage}\n\n"
		return
	end

	case args[0]
		when 'list'
			list(args[1..-1])
		when 'details'
			details(args[1..-1])
		when 'add'
			add(args[1..-1])
		when 'update'
			update(args[1..-1])
		when 'remove'
			remove(args[1..-1])
		when 'feature-permissions'
			feature_permissions(args[1..-1])
		else
			puts "\n#{usage}\n\n"
			exit 127
	end
end

#list(args) ⇒ Object



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/morpheus/cli/users.rb', line 58

def list(args)
	usage = "Usage: morpheus users list [options]"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		build_common_options(opts, options, [:account, :list, :json])
	end
	optparse.parse(args)
	connect(options)
	begin

		 = (options)
		 =  ? ['id'] : nil

		params = {}
		[:phrase, :offset, :max, :sort, :direction].each do |k|
			params[k] = options[k] unless options[k].nil?
		end
		
		json_response = @users_interface.list(, params)
		users = json_response['users']

		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			print "\n" ,cyan, bold, "Morpheus Users\n","==================", reset, "\n\n"
			if users.empty?
				puts yellow,"No users found.",reset
			else
				print_users_table(users)
			end
			print reset,"\n"
		end
	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end

#remove(args) ⇒ Object



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/morpheus/cli/users.rb', line 339

def remove(args)
	usage = "Usage: morpheus users remove [username]"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		build_common_options(opts, options, [:account, :auto_confirm, :json])
	end
	optparse.parse(args)

	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	username = args[0]

	connect(options)
	begin

		 = (options)
		 =  ? ['id'] : nil

		user = find_user_by_username(, username)
		exit 1 if user.nil?
		unless options[:yes] || Morpheus::Cli::OptionTypes.confirm("Are you sure you want to delete the user #{user['username']}?")
			exit
		end
		json_response = @users_interface.destroy(, user['id'])

		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			print_green_success "User #{username} removed"
			# list([])
		end
		
	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end

#update(args) ⇒ Object



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/morpheus/cli/users.rb', line 264

def update(args)
	usage = "Usage: morpheus users update [username] [options]"
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		build_common_options(opts, options, [:account, :options, :json])
		opts.on('-h', '--help', "Prints this help" ) do
       puts opts
			puts Morpheus::Cli::OptionTypes.display_option_types_help(update_user_option_types)
       exit
     end
	end
	optparse.parse(args)

	if args.count < 1
		puts "#{usage}\n\n"
		puts Morpheus::Cli::OptionTypes.display_option_types_help(update_user_option_types)
		exit 1
	end
	username = args[0]

	connect(options)
	
	begin

		 = (options)
		 =  ? ['id'] : nil

		user = find_user_by_username(, username)
		exit 1 if user.nil?

		#params = Morpheus::Cli::OptionTypes.prompt(update_user_option_types, options[:options], @api_client, options[:params])
		params = options[:options] || {}
		roles = prompt_user_roles(, user['id'], options.merge(no_prompt: true))
		if !roles.empty?
			params['roles'] = roles.collect {|r| {id: r['id']} }
		end
		
		if params.empty?
			puts "\n#{usage}\n\n"
			puts Morpheus::Cli::OptionTypes.display_option_types_help(update_user_option_types)
			exit 1
		end

		#puts "parsed params is : #{params.inspect}"
		user_keys = ['username', 'firstName', 'lastName', 'email', 'password', 'instanceLimits', 'roles']
		user_payload = params.select {|k,v| user_keys.include?(k) }
		if !user_payload['instanceLimits']
			user_payload['instanceLimits'] = {}
			user_payload['instanceLimits']['maxStorage'] = params['instanceLimits.maxStorage'].to_i if params['instanceLimits.maxStorage'].to_s.strip != ''
			user_payload['instanceLimits']['maxMemory'] = params['instanceLimits.maxMemory'].to_i if params['instanceLimits.maxMemory'].to_s.strip != ''
			user_payload['instanceLimits']['maxCpu'] = params['instanceLimits.maxCpu'].to_i if params['instanceLimits.maxCpu'].to_s.strip != ''
		end

		request_payload = {user: user_payload}
		json_response = @users_interface.update(, user['id'], request_payload)
		
		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			print_green_success "Updated user #{user_payload['username']}"
			details_options = [user_payload["username"] || user['username']]
			if 
				details_options.push "--account-id", ['id'].to_s
			end
			details(details_options)
		end

	rescue RestClient::Exception => e
		print_rest_exception(e, options)
		exit 1
	end
end