Class: Morpheus::Cli::Users

Inherits:
Object
  • Object
show all
Includes:
AccountsHelper, CliCommand, Term::ANSIColor
Defined in:
lib/morpheus/cli/users.rb

Instance Method Summary collapse

Methods included from AccountsHelper

#find_account_by_id, #find_account_by_name, #find_account_from_options, #find_role_by_id, #find_role_by_name, #find_user_by_id, #find_user_by_username, #print_accounts_table, #print_green_success, #print_red_alert, #print_roles_table, #print_users_table

Methods included from CliCommand

accountScopeOptions, genericOptions, included

Constructor Details

#initializeUsers

Returns a new instance of Users.



16
17
18
19
# File 'lib/morpheus/cli/users.rb', line 16

def initialize() 
	@appliance_name, @appliance_url = Morpheus::Cli::Remote.active_appliance
	#@active_groups = ::Morpheus::Cli::Groups.load_group_file
end

Instance Method Details

#add(args) ⇒ Object



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/morpheus/cli/users.rb', line 154

def add(args)
	usage = "Usage: morpheus users add [options]"
	# if args.count > 0
	# 	puts "\#{usage}\n\n"
	# 	exit 1
	# end
	options = {}
	#options['username'] = args[0] if args[0]
	 = nil
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		Morpheus::Cli::CliCommand.accountScopeOptions(opts,options)
		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)

	connect(options)
	
	begin

		 = (options)
		 =  ? ['id'] : nil

		#params = Morpheus::Cli::OptionTypes.prompt(add_user_option_types, options)
		params = Morpheus::Cli::OptionTypes.prompt(add_user_option_types, options[:options], @api_client, options[:params]) # options[:params] is mysterious

		#puts "parsed params is : #{params.inspect}"
		user_keys = ['username', 'firstName', 'lastName', 'email', 'password', 'passwordConfirmation', 'instanceLimits']
		user_payload = params.select {|k,v| user_keys.include?(k) }
		if params['role'].to_s != ''
			role = find_role_by_name(, params['role'])
			exit 1 if role.nil?
			user_payload['role'] = {id: role['id']}
		end
		request_payload = {user: user_payload}
		response = @users_interface.create(, request_payload)

		if 
			print_green_success "Added user #{user_payload['username']} to account #{['name']}"
		else
			print_green_success "Added user #{user_payload['username']}"
		end

		details_options = [user_payload["username"]]
		if 
			details_options.push "--account-id", ['id'].to_s
		end
		details(details_options)

	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end

#connect(opts) ⇒ Object



21
22
23
24
25
26
27
28
29
30
31
# File 'lib/morpheus/cli/users.rb', line 21

def connect(opts)
	@access_token = Morpheus::Cli::Credentials.new(@appliance_name,@appliance_url).request_credentials()
	if @access_token.empty?
		print red,bold, "\nInvalid Credentials. Unable to acquire access token. Please verify your credentials and try again.\n\n",reset
		exit 1
	end
	@api_client = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url)
	@users_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).users
	@accounts_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).accounts
	@roles_interface = Morpheus::APIClient.new(@access_token,nil,nil, @appliance_url).roles
end

#details(args) ⇒ Object



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/morpheus/cli/users.rb', line 99

def details(args)
	usage = "Usage: morpheus users details [username] [options]"
	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	 = nil
	username = args[0]
	options = {}
	params = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
     Morpheus::Cli::CliCommand.accountScopeOptions(opts,options)
		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)
	connect(options)
	begin
		
		 = (options)
		 =  ? ['id'] : nil

		# todo: users_response = @users_interface.list(account_id, {name: name})
		#       there may be response data outside of user that needs to be displayed
		user = find_user_by_username(, username)
		exit 1 if user.nil?

		if options[:json]
			print JSON.pretty_generate(user)
			print "\n"
		else
			print "\n" ,cyan, bold, "User Details\n","==================", reset, "\n\n"
			print cyan
			puts "ID: #{user['id']}"
			puts "Account: #{user['account'] ? user['account']['name'] : nil}"
			puts "First Name: #{user['firstName']}"
			puts "Last Name: #{user['firstName']}"
			puts "Username: #{user['username']}"
			puts "Role: #{user['role'] ? user['role']['authority'] : nil}"
			puts "Date Created: #{format_local_dt(user['dateCreated'])}"
			puts "Last Updated: #{format_local_dt(user['lastUpdated'])}"
			print "\n" ,cyan, bold, "User Instance Limits\n","==================", reset, "\n\n"
			print cyan
			puts "Max Storage (bytes): #{user['instanceLimits'] ? user['instanceLimits']['maxStorage'] : 0}"
			puts "Max Memory (bytes): #{user['instanceLimits'] ? user['instanceLimits']['maxMemory'] : 0}"
			puts "CPU Count: #{user['instanceLimits'] ? user['instanceLimits']['maxCpu'] : 0}"
			print cyan
			print reset,"\n\n"
		end
	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end

#handle(args) ⇒ Object



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/morpheus/cli/users.rb', line 33

def handle(args)
	usage = "Usage: morpheus users [list,details,add,update,remove] [username]"
	if args.empty?
		puts "\n#{usage}\n\n"
		return
	end

	case args[0]
		when 'list'
			list(args[1..-1])
		when 'details'
			details(args[1..-1])
		when 'add'
			add(args[1..-1])
		when 'update'
			update(args[1..-1])
		when 'remove'
			remove(args[1..-1])
		else
			puts "\n#{usage}\n\n"
			exit 127
	end
end

#list(args) ⇒ Object



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/morpheus/cli/users.rb', line 57

def list(args)
	usage = "Usage: morpheus users list [options]"
	options = {}
	params = {}
	 = nil
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		Morpheus::Cli::CliCommand.accountScopeOptions(opts,options)
		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)
	connect(options)
	begin

		 = (options)
		 =  ? ['id'] : nil

		[:phrase, :offset, :max, :sort, :direction].each do |k|
			params[k] = options[k] unless options[k].nil?
		end
		
		json_response = @users_interface.list(, params)
		users = json_response['users']

		if options[:json]
			print JSON.pretty_generate(json_response)
			print "\n"
		else
			print "\n" ,cyan, bold, "Morpheus Users\n","==================", reset, "\n\n"
			if users.empty?
				puts yellow,"No users found.",reset
			else
				print_users_table(users)
			end
			print reset,"\n\n"
		end
	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end

#remove(args) ⇒ Object



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/morpheus/cli/users.rb', line 271

def remove(args)
	usage = "Usage: morpheus users remove [username]"
	if args.count < 1
		puts "\n#{usage}\n"
		exit 1
	end
	 = nil
	username = args[0]
	options = {}
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		Morpheus::Cli::CliCommand.accountScopeOptions(opts,options)
		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)
	connect(options)
	begin

		 = (options)
		 =  ? ['id'] : nil

		user = find_user_by_username(, username)
		exit 1 if user.nil?
		exit unless Morpheus::Cli::OptionTypes.confirm("Are you sure you want to delete the user #{user['username']}?")
		@users_interface.destroy(, user['id'])
		# list([])
		print "\n", cyan, "User #{username} removed", reset, "\n\n"
	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end

#update(args) ⇒ Object



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/morpheus/cli/users.rb', line 209

def update(args)
	usage = "Usage: morpheus users update [username] [options]"
	if args.count < 1
		puts "\n#{usage}\n\n"
		exit 1
	end
	 = nil
	username = args[0]
	options = {}
	#options['username'] = args[0] if args[0]
	optparse = OptionParser.new do|opts|
		opts.banner = usage
		Morpheus::Cli::CliCommand.accountScopeOptions(opts,options)
		Morpheus::Cli::CliCommand.genericOptions(opts,options)
	end
	optparse.parse(args)

	connect(options)
	
	begin

		 = (options)
		 =  ? ['id'] : nil

		user = find_user_by_username(, username)
		exit 1 if user.nil?

		#params = Morpheus::Cli::OptionTypes.prompt(add_user_option_types, options[:options], @api_client, options[:params]) # options[:params] is mysterious
		params = options[:options] || {}

		if params.empty?
			puts "\n#{usage}\n"
			option_lines = update_user_option_types.collect {|it| "\t-O #{it['fieldName']}=\"value\"" }.join("\n")
			puts "\nAvailable Options:\n#{option_lines}\n\n"
			exit 1
		end

		#puts "parsed params is : #{params.inspect}"
		user_keys = ['username', 'firstName', 'lastName', 'email', 'password', 'instanceLimits']
		user_payload = params.select {|k,v| user_keys.include?(k) }
		if params['role'].to_s != ''
			role = find_role_by_name(, params['role'])
			exit 1 if role.nil?
			user_payload['role'] = {id: role['id']}
		end
		request_payload = {user: user_payload}
		response = @users_interface.update(, user['id'], request_payload)
		
		print_green_success "Updated user #{user_payload['username']}"

		details_options = [user_payload["username"] || user['username']]
		if 
			details_options.push "--account-id", ['id'].to_s
		end
		details(details_options)

	rescue RestClient::Exception => e
		::Morpheus::Cli::ErrorHandler.new.print_rest_exception(e)
		exit 1
	end
end