Class: Morpheus::Cli::VirtualSwitchesCommand
Overview
CLI command Virtual Switch management
UI is Tools: Virtual Switches
API is /api/virtual-switches and returns virtualSwitches
Instance Attribute Summary
Attributes included from CliCommand
#no_prompt
Instance Method Summary
collapse
#find_available_user_option, #find_cloud_option, #find_group_option, #find_tenant_option, #get_available_user_options, #get_cloud_options, #get_group_options, #get_tenant_options, included, #load_option_source_data, #options_interface, #parse_cloud_id_list, #parse_group_id_list, #parse_option_source_id_list, #parse_project_id_list, #parse_tenant_id_list, #parse_user_id_list
Methods included from CliCommand
#add_query_parameter, #apply_options, #build_common_options, #build_get_options, #build_list_options, #build_option_type_options, #build_standard_add_many_options, #build_standard_add_options, #build_standard_api_options, #build_standard_delete_options, #build_standard_get_options, #build_standard_list_options, #build_standard_post_options, #build_standard_put_options, #build_standard_remove_options, #build_standard_update_options, #command_description, #command_name, #confirm, #confirm!, #default_refresh_interval, #default_sigdig, #default_subcommand, #establish_remote_appliance_connection, #execute_api, #execute_api_payload, #execute_api_request, #find_all, #find_all_json, #find_by_id, #find_by_name, #find_by_name_or_id, #find_record, #find_record_json, #full_command_usage, #get_interface, #get_list_key, #get_object_key, #get_subcommand_description, #handle_each_payload, #handle_subcommand, included, #interactive?, #my_help_command, #my_terminal, #my_terminal=, #parse_array, #parse_bytes_param, #parse_get_options!, #parse_id_list, #parse_labels, #parse_list_options, #parse_list_options!, #parse_list_subtitles, #parse_options, #parse_parameter_as_resource_id!, #parse_passed_options, #parse_payload, #parse_query_options, #print, #print_error, #println, #prog_name, #puts, #puts_error, #raise_args_error, #raise_command_error, #render_response, #run_command_for_each_arg, #subcommand_aliases, #subcommand_description, #subcommand_usage, #subcommands, #usage, #validate_outfile, #verify_args!, #visible_subcommands
Instance Method Details
#_get(id, params, options) ⇒ Object
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
|
# File 'lib/morpheus/cli/commands/virtual_switches_command.rb', line 94
def _get(id, params, options)
virtual_switch = nil
if id.to_s !~ /\A\d{1,}\Z/
virtual_switch = find_virtual_switch_by_name(id)
return 1, "Virtual Switch not found for #{id}" if virtual_switch.nil?
id = virtual_switch['id']
end
@virtual_switches_interface.setopts(options)
if options[:dry_run]
print_dry_run @virtual_switches_interface.dry.get(id, params)
return
end
json_response = @virtual_switches_interface.get(id, params)
virtual_switch = json_response[virtual_switch_object_key]
render_response(json_response, options, virtual_switch_object_key) do
print_h1 "Virtual Switch Details", [], options
print cyan
columns = {
"ID" => 'id',
"Name" => 'name',
"Type" => lambda {|it| it['type']['name'] rescue it['baseType'] },
"NIC Count" => lambda {|it| it['nicCount'] },
"Network Count" => lambda {|it| it['networkCount'] },
}
print_description_list(columns, virtual_switch, options)
print reset,"\n"
end
return 0, nil
end
|
#add(args) ⇒ Object
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
|
# File 'lib/morpheus/cli/commands/virtual_switches_command.rb', line 126
def add(args)
options = {}
params = {}
optparse = Morpheus::Cli::OptionParser.new do |opts|
opts.banner = subcommand_usage("[name] [options]")
build_option_type_options(opts, options, add_virtual_switch_option_types)
build_standard_add_options(opts, options)
opts. = <<-EOT
Create a new Virtual Switch.
EOT
end
optparse.parse!(args)
verify_args!(args:args, optparse:optparse, min:0, max:1)
options[:options]['name'] = args[0] if args[0]
if options[:options]['logo']
options[:options]['iconPath'] = 'custom'
end
connect(options)
payload = {}
if options[:payload]
payload = options[:payload]
payload.deep_merge!({virtual_switch_object_key => parse_passed_options(options)})
else
params.deep_merge!(parse_passed_options(options))
option_types = add_virtual_switch_option_types
v_prompt = Morpheus::Cli::OptionTypes.prompt(option_types, options[:options], @api_client, options[:params])
params.deep_merge!(v_prompt)
params.booleanize!
payload.deep_merge!({virtual_switch_object_key => params})
end
@virtual_switches_interface.setopts(options)
if options[:dry_run]
print_dry_run @virtual_switches_interface.dry.create(payload)
return 0, nil
end
json_response = @virtual_switches_interface.create(payload)
virtual_switch = json_response[virtual_switch_object_key]
render_response(json_response, options, virtual_switch_object_key) do
print_green_success "Added virtual switch #{virtual_switch['name']}"
return _get(virtual_switch["id"], {}, options)
end
return 0, nil
end
|
#connect(opts) ⇒ Object
15
16
17
18
19
20
21
22
|
# File 'lib/morpheus/cli/commands/virtual_switches_command.rb', line 15
def connect(opts)
@api_client = establish_remote_appliance_connection(opts)
@virtual_switches_interface = @api_client.virtual_switches
@clusters_interface = @api_client.clusters
@networks_interface = @api_client.networks
@options_interface = @api_client.options
end
|
#get(args) ⇒ Object
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
|
# File 'lib/morpheus/cli/commands/virtual_switches_command.rb', line 73
def get(args)
params = {}
options = {}
optparse = Morpheus::Cli::OptionParser.new do |opts|
opts.banner = subcommand_usage("[switch]")
build_standard_get_options(opts, options)
opts. = <<-EOT
Get details about a specific Virtual Switch.
[switch] is required. This is the name or id of a Virtual Switch.
EOT
end
optparse.parse!(args)
verify_args!(args:args, optparse:optparse, min:1)
connect(options)
params.merge!(parse_query_options(options))
id_list = parse_id_list(args)
return run_command_for_each_arg(id_list) do |arg|
_get(arg, params, options)
end
end
|
#handle(args) ⇒ Object
24
25
26
|
# File 'lib/morpheus/cli/commands/virtual_switches_command.rb', line 24
def handle(args)
handle_subcommand(args)
end
|
#list(args) ⇒ Object
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
|
# File 'lib/morpheus/cli/commands/virtual_switches_command.rb', line 28
def list(args)
options = {}
params = {}
ref_ids = []
optparse = Morpheus::Cli::OptionParser.new do |opts|
opts.banner = subcommand_usage("[search]")
opts.on( '--enabled [on|off]', String, "Filter by enabled" ) do |val|
params['enabled'] = (val.to_s != 'false' && val.to_s != 'off')
end
build_standard_list_options(opts, options)
opts. = "List Virtual Switches."
end
optparse.parse!(args)
connect(options)
if args.count > 0
options[:phrase] = args.join(" ")
end
params.merge!(parse_list_options(options))
@virtual_switches_interface.setopts(options)
if options[:dry_run]
print_dry_run @virtual_switches_interface.dry.list(params)
return
end
json_response = @virtual_switches_interface.list(params)
render_response(json_response, options, virtual_switch_list_key) do
virtual_switches = json_response[virtual_switch_list_key]
print_h1 "Morpheus Virtual Switches", parse_list_subtitles(options), options
if virtual_switches.empty?
print cyan,"No Virtual Switches found.",reset,"\n"
else
columns = {
"ID" => 'id',
"Name" => 'name',
"Type" => lambda {|it| it['type']['name'] rescue it['baseType'] },
"NIC Count" => lambda {|it| it['nicCount'] },
"Network Count" => lambda {|it| it['networkCount'] },
}
print as_pretty_table(virtual_switches, columns.upcase_keys!, options)
(json_response)
end
print reset,"\n"
end
return 0, nil
end
|
#remove(args) ⇒ Object
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
|
# File 'lib/morpheus/cli/commands/virtual_switches_command.rb', line 230
def remove(args)
options = {}
params = {}
optparse = Morpheus::Cli::OptionParser.new do |opts|
opts.banner = subcommand_usage("[switch] [options]")
build_standard_remove_options(opts, options)
opts. = <<-EOT
Delete a virtual switch.
[switch] is required. This is the name or id of a virtual switch.
EOT
end
optparse.parse!(args)
verify_args!(args:args, optparse:optparse, count:1)
connect(options)
virtual_switch = find_virtual_switch_by_name_or_id(args[0])
return 1 if virtual_switch.nil?
@virtual_switches_interface.setopts(options)
if options[:dry_run]
print_dry_run @virtual_switches_interface.dry.destroy(virtual_switch['id'], params)
return
end
unless options[:yes] || Morpheus::Cli::OptionTypes.confirm("Are you sure you want to delete the virtual switch #{virtual_switch['name']}?")
return 9, "aborted command"
end
json_response = @virtual_switches_interface.destroy(virtual_switch['id'], params)
render_response(json_response, options) do
print_green_success "Removed virtual switch #{virtual_switch['name']}"
end
return 0, nil
end
|
#update(args) ⇒ Object
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
|
# File 'lib/morpheus/cli/commands/virtual_switches_command.rb', line 175
def update(args)
options = {}
params = {}
payload = {}
optparse = Morpheus::Cli::OptionParser.new do |opts|
opts.banner = subcommand_usage("[switch] [options]")
build_option_type_options(opts, options, update_virtual_switch_option_types)
build_standard_update_options(opts, options)
opts. = <<-EOT
Update a virtual switch.
[switch] is required. This is the name or id of a virtual switch.
EOT
end
optparse.parse!(args)
verify_args!(args:args, optparse:optparse, count:1)
if options[:options]['logo']
options[:options]['iconPath'] = 'custom'
end
connect(options)
virtual_switch = find_virtual_switch_by_name_or_id(args[0])
return 1 if virtual_switch.nil?
payload = {}
if options[:payload]
payload = options[:payload]
payload.deep_merge!({virtual_switch_object_key => parse_passed_options(options)})
else
params.deep_merge!(parse_passed_options(options))
v_prompt = Morpheus::Cli::OptionTypes.no_prompt(update_virtual_switch_option_types, options[:options], @api_client, options[:params])
v_prompt.deep_compact!
params.deep_merge!(v_prompt)
params.booleanize!
payload.deep_merge!({virtual_switch_object_key => params})
if payload[virtual_switch_object_key].empty? raise_command_error "Specify at least one option to update.\n#{optparse}"
end
end
@virtual_switches_interface.setopts(options)
if options[:dry_run]
print_dry_run @virtual_switches_interface.dry.update(virtual_switch['id'], payload)
return
end
json_response = @virtual_switches_interface.update(virtual_switch['id'], payload)
virtual_switch = json_response[virtual_switch_object_key]
render_response(json_response, options, virtual_switch_object_key) do
print_green_success "Updated virtual switch #{virtual_switch['name']}"
return _get(virtual_switch["id"], {}, options)
end
return 0, nil
end
|